#
# spec file for package loki
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global loki_datadir /var/lib/loki
%global loki_logdir /var/log/loki
%global promtail_datadir /var/lib/promtail

Name:           loki
Version:        3.4.2
Release:        1.1
Summary:        Loki: like Prometheus, but for logs
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://grafana.com/loki
Source:         %{name}-%{version}.tar.xz
Source1:        loki.service
Source2:        promtail.service
Source3:        sysconfig.loki
Source4:        sysconfig.promtail
Source99:       series
Patch0:         proper-data-directories.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  golang-packaging
BuildRequires:  systemd-devel
BuildRequires:  golang(API) = 1.23
Requires:       logcli = %{version}
Requires(pre):  group(loki)
Requires(pre):  user(loki)
Requires:       group(loki)
Requires:       user(loki)
Requires(post): %fillup_prereq
%systemd_ordering

%description
Loki is a horizontally-scalable, highly-available, multi-tenant log aggregation
system inspired by Prometheus.

This package contains the Loki server.

%package -n promtail
Summary:        Promtail Client
Group:          System/Monitoring

%description -n promtail
Loki is a horizontally-scalable, highly-available, multi-tenant log aggregation
system inspired by Prometheus.

This package contains the Promtail client.

%package -n logcli
Summary:        LogCLI tool
Group:          System/Monitoring

%description -n logcli
Loki is a horizontally-scalable, highly-available, multi-tenant log aggregation
system inspired by Prometheus.

This package contains the LogCLI command-line tool.

%package -n lokitool
Summary:        A command-line tool to manage Loki
Group:          System/Monitoring

%description -n lokitool
Loki is a horizontally-scalable, highly-available, multi-tenant log aggregation
system inspired by Prometheus.

This package contains the lokitool command-line tool.

%prep
%autosetup -p1 %{name}-%{version}

%build
%define buildpkg github.com/grafana/loki/pkg/build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

%ifarch %{ix86} s390 s390x armv7l armv7hl armv7l:armv6l:armv5tel riscv64
    export CGO_ENABLED=1
%else
    export CGO_ENABLED=0
%endif

export GOFLAGS="-mod=vendor -buildmode=pie -tags=netgo"
export GOLDFLAGS="-X %{buildpkg}.Version=%{version} \
                  -X %{buildpkg}.Revision=v%{version} \
                  -X %{buildpkg}.Branch=main \
                  -X %{buildpkg}.BuildUser=openSUSE \
                  -X %{buildpkg}.BuildDate=${BUILD_DATE}"

go build -ldflags="$GOLDFLAGS" ./cmd/loki
go build -ldflags="$GOLDFLAGS" ./cmd/logcli
go build -ldflags="$GOLDFLAGS" ./cmd/lokitool
CGO_ENABLED=1 go build -ldflags="$GOLDFLAGS" --tags=promtail_journal_enabled ./clients/cmd/promtail

%install

# Service files for Loki and promtail
install -Dm644 %{SOURCE1} %{buildroot}%{_unitdir}/loki.service
install -Dm644 %{SOURCE2} %{buildroot}%{_unitdir}/promtail.service
install -Dm644 %{SOURCE3} %{buildroot}%{_fillupdir}/sysconfig.loki
install -Dm644 %{SOURCE4} %{buildroot}%{_fillupdir}/sysconfig.promtail
install -dm755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcloki
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcpromtail

# Config files
install -Dm640 cmd/loki/loki-local-config.yaml \
    %{buildroot}%{_sysconfdir}/loki/loki.yaml
install -Dm640 clients/cmd/promtail/promtail-local-config.yaml \
    %{buildroot}%{_sysconfdir}/loki/promtail.yaml

# Binaries
install -dm755 %{buildroot}%{_bindir}
install -Dm755 loki %{buildroot}%{_bindir}
install -Dm755 lokitool %{buildroot}%{_bindir}
install -Dm755 promtail %{buildroot}%{_bindir}
install -Dm755 logcli %{buildroot}%{_bindir}

install -D -d -m 0750 %{buildroot}%{promtail_datadir} %{buildroot}%{loki_datadir} %{buildroot}%{loki_logdir}

%pre
%service_add_pre loki.service

%post
%fillup_only
%service_add_post loki.service

%preun
%service_del_preun loki.service

%postun
%service_del_postun loki.service promtail.service

%pre -n promtail
%service_add_pre promtail.service

%post -n promtail
%fillup_only -n promtail
%service_add_post promtail.service

%preun -n promtail
%service_del_preun promtail.service

%postun -n promtail
%service_del_postun promtail.service

%files
%license LICENSE
%doc README.md
%{_unitdir}/loki.service
%{_fillupdir}/sysconfig.loki
%{_bindir}/loki
%dir %{_sysconfdir}/loki
%config(noreplace) %attr(-,root,loki) %{_sysconfdir}/loki/loki.yaml
%{_sbindir}/rcloki
%dir %attr(-,loki,loki) %{loki_datadir}/
%dir %attr(-,loki,loki) %{loki_logdir}/

%files -n promtail
%{_unitdir}/promtail.service
%{_fillupdir}/sysconfig.promtail
%{_bindir}/promtail
%dir %{_sysconfdir}/loki
%config(noreplace) %{_sysconfdir}/loki/promtail.yaml
%{_sbindir}/rcpromtail
%dir %{promtail_datadir}/

%files -n logcli
%{_bindir}/logcli

%files -n lokitool
%{_bindir}/lokitool

%changelog
* Fri Feb 14 2025 mrueckert@suse.de
- Update to version 3.4.2:
  * fix(ci): do not disable CGO in Makefile (backport
    release-3.4.x) (#16272)
  * fix(blooms): Initialize bloom gateway client only once
    (backport release-3.4.x) (#16268)
  * docs: Updates Loki release notes for 3.3.3 (backport
    release-3.4.x) (#16249)
  * chore(release-3.4.x): release 3.4.1 (#16226)
- Update to version 3.4.1:
  * docs: adding Promtail deprecation banners (backport
    release-3.4.x) (#16228)
  * fix: build info in docker images (#16225)
  * ci: Move IMAGE_TAG Dockerfile ARG into build phase (backport
    k239) (#16212)
  * chore(k239): release 3.4.0 (#16102)
* Wed Feb 12 2025 Marcus Rueckert <mrueckert@suse.de>
- refresh proper-data-directories.patch
* Wed Feb 12 2025 mrueckert@suse.de
- Update to version 3.4.0:
  * BREAKING CHANGES
  - Remove wget from Promtail docker image (#15101)
  * Features
  - Add a metric ingestion time SM sanitization (#15222)
    (e9d0c3e)
  - add kafka development environment (#15603) (226e9f1)
  - add lines skipped metric to pattern ingesters (#14997)
    (dea5d78)
  - Add objstore support for Swift using thanos.io/objstore
    (#11672) (44523e0)
  - add opt-in support for ProxyFroomEnvironment in logcli
    (#11742) (#14950) (c56b95d)
  - Add otlp attribute deployment.environment.name to list of
    default labels (#14747) (2d407bd)
  - add per-tenant time sharding for long out-of-order ingestion
    (#14711) (0d6d68d)
  - add phase to log lines in kafka_consumer.go (#15176)
    (0a12cab)
  - Add Rule Name and Type to Query Tags (#15055) (b272573)
  - Add TLS config to the analytics client (#15227) (2c5eabd)
  - added support for overrides exporter (#15630) (db72164)
  - api: Support Parquet as a query response format. (#15408)
    (d0c11a6)
  - Block scheduler scaffolding (#15198) (a10140d)
  - block-scheduler: adds service and basic planner support for
    scheduler (#15200) (ad322c0)
  - block-scheduler: introduce job lease and requeue expired jobs
    (#15560) (558080c)
  - block-scheduler: job tracking & offset commits (#15338)
    (f2bff77)
  - block-scheduler: status page shows completed jobs (#15580)
    (10194f7)
  - blockbuilder component (#14621) (cbdd36a)
  - blockbuilder: consolidate on record counting planner (#15247)
    (532bdbc)
  - blockbuilder: grpc transport (#15218) (339ba1a)
  - blockbuilder: priority queue for job dispatching (#15245)
    (0981273)
  - blooms: Add task timining and sizing metrics (#15032)
    (79cccfd)
  - blooms: Apply task timeout in bloom builder (#14988)
    (f92dde0)
  - blooms: disk-backed queue for the bloom-planner (#14874)
    (b646861)
  - blooms: Prefetch bloom blocks as soon as they are built
    (#15050) (b406015)
  - build the Docker Driver for arm64 (#9247) (e950251)
  - Detect fields based on per-tenant configuration and put them
    into structured metadata at ingest time (#15188) (7033091)
  - expose topologySpreadConstraints for admin-api pods (#14995)
    (1b93086)
  - expose topologySpreadConstraints for distributed deployment
    (#14853) (d075107)
  - helm: Compute ConfigMap/Secret checksum only over .data
    content (#15177) (990f71c)
  - helm: Do not explicitly template managed-by, as it should be
    set at install time by the installation manager. (#14763)
    (10b7478)
  - Introduce shardable probabilistic topk for instant queries.
    (#14243) (7b53f20)
  - lambda-promtail: add relabeling support for log entries
    (#15600) (c41a8b4)
  - lambda-promtail: Add terraform variable for s3 bucket
    notification filter prefix (#15381) (3dd8d7d)
  - line_format bypass template execution if possible (#15411)
    (2150fbc)
  - logcli: Include common labels (#15611) (639ac74)
  - loki/docker compose: enable feature toggle (#14858) (8f243ee)
  - operator: Add support for managed GCP WorkloadIdentity
    (#14752) (7635a5c)
  - present DF bytes values in queryable format (#15272)
    (f5d62bd)
  - remove target lag and keep just maximum lag (#15120)
    (12386a2)
  - sanitize structured metadata during ingestion in the
    distributor (#15141) (be4f17e)
  - scheduler: implement and register block builder rpc service
    (#15248) (c519ab6)
  - Skip writeback for chunks fetched by queriers older than a
    duration (#15605) (3b8d993)
  - Support config timeout for AlibabaCloud OSS requests (#14856)
    (ac2e21f)
  - thanos: add new metric to track status codes (#14937)
    (a629212)
  - thanos: add support for aliyun oss and baidu bos (#14891)
    (fb6789d)
  - thanos: make use of the new function IterWithAttributes
    (#14793) (cfc3819)
  - TSDB: allow tsdb index creation in memory only (#14732)
    (831c0d5)
  - update blockbuilder to use scheduler for fetching jobs
    (#15224) (0d67831)
  - Use context propagation to call the same ingester in
    GetChunksID as Query (#15186) (70d9587)
  * Bug Fixes
  - Add flags for path & configure kafka for non-memberlist kv
    store (#14850) (f2da621)
  - aggregated_metrics: Fix the IsError method causing retries
    (#15296) (7a7b3b1)
  - allow comparison against zero bytes (#15217) (17f1972)
  - azureblob: Return error if Azure returns no service principal
    token (#13195) (e98a86b)
  - block-builder: return from Process call early if max offset
    is reached (#15073) (13ea254)
  - block-scheduler: init record planner correctly (#15390)
    (117869f)
  - block-scheduler: one job per partition (local branch copy)
    (#15579) (b2f46de)
  - blockbuilder: copy entries returned by record decoder
    (#15549) (52d745f)
  - blockbuilder: min job size (#15617) (c43aa56)
  - blockbuilder: use index path prefix in objectclient for tsdb
    creation (#15614) (55f2dd8)
  - blooms: Copy chunks from ForSeries (#14863) (bfc2890)
  - blooms: Do not restart builders when planner disconnects
    (#14783) (7669385)
  - blooms: Enable metas cache on backend when running in ssd
    mode (#15275) (4cce207)
  - blooms: Fix check for skipping most recent data when
    filtering blooms (#15300) (78d3c44)
  - blooms: Fix strategy logger and add task test (#14857)
    (ab2721d)
  - blooms: Fix tenants slice on loadTenantTables (#14900)
    (a8f7851)
  - blooms: Match series to newest block only (#15481) (5846ea2)
  - blooms: Skip multi-tenant TSDBs during bloom planning
    (#14770) (76d35cc)
  - bytes unit detection in detected fields (#15525) (8e260fe)
  - ci: Fix test compile error (#15404) (db2b6db)
  - ci: Remove submodule once and for all (#15495) (80e8e60)
  - ci: Revert "fixed Publish Rendered Helm Chart Diff workflow"
    (#15506) (6c49cc0)
  - ci: transform TestChunkSize into a benchmark (#15361)
    (fed43db)
  - ci: Update Python version for Helm CI (#15420) (bdbb009)
  - correct S3 bucket owner label key to prevent retrieval errors
    (#14913) (85aaf63)
  - correct typo in architecture name (amr64 -> arm64) (#15707)
    (068f81d)
  - Correctly propagate index stats to metrics.go log line
    (#14941) (ff111dc)
  - data race / nil channel read in pattern aggregation push
    (#15410) (5d8220c)
  - data race in bloombuild tests (#15360) (aa7b849)
  - data race in chunk client hedging tests (#15466) (fad06ee)
  - data race in distributor tests (#15423) (b8168a8)
  - data race in ingester test (#15465) (04f621e)
  - Disable Helm test pod when test.enabled=false (#15346)
    (1fb4e2b)
  - do not retain copy of chunk while indexing a new chunk in
    tsdb while processing delete requests (#15541) (ff19955)
  - enable metric aggregation in loki-local-config.yaml (#15302)
    (c96b750)
  - Ensure partition-reader starts up correctly (#14845)
    (b2f3d2e)
  - Ensure successive WAL replays don't overwrite each other
    (#14848) (ec95ed1)
  - Fix goroutine leak in queryrange downstreamer (#15665)
    (5f476a3)
  - Fix loki ruler generator url left parameter url encoding
    (#15601) (e347eb7)
  - helm/loki: Add namespace to Loki templates for ruler and
    index-gateway (#14838) (733d99f)
  - helm/loki: Allow prefixing of rollout-group value and
    ingester name (#15063) (f4accc1)
  - helm: add appProtocol: tcp to headless backend grpc ports
    (#14507) (400f5af)
  - helm: Add conditional to include ruler config only when
    enabled (#15385) (3badbb3)
  - helm: add default wal dir to ruler config (#14920) (1a6751f)
  - helm: Fix statefulset templates to not show diffs in ArgoCD
    (#15192) (3c71c83)
  - helm: Split ingester HPA when zoneAwareReplication is enabled
    (#14565) (80e46f7)
  - helm: yaml templates incorrectly annotated (#15207) (acd4d11)
  - Improve docs for min and max table offsets (#14890) (fd9d332)
  - incorrect error check in autoCommitLoop (#15149) (4b5925a)
  - kafka: Read from beginning if no committed offset (#14865)
    (1b6da11)
  - Keep the service_name label after discovery in
    push.ParseLokiRequest before calculating retention and
    passing to the usage tracker (#14960) (71d4d6a)
  - lambda-promtail: Remove s3 bucket ownership verification
    (#15383) (bf73014)
  - legacy label endpoint route (#14933) (8ce321e)
  - logcli: Check for errors before checking for exists when
    fetching data (#14780) (9e7d2f2)
  - memberlist: Respect interface names config for advertise
    address (#13940) (751324c)
  - metric_aggregation: Fix duplicate metrics registration
    (#15142) (215f994)
  - Mitigate ingester race between Query & GetChunkIDs (#15178)
    (bd46e4c)
  - operator: Add log attribute for level to structured metadata
    (#14776) (036c131)
  - operator: Fix maximum OpenShift version (#14764) (cc496c6)
  - operator: Fix operator release pipeline warnings (#14817)
    (e707a3d)
  - operator: Fix RBAC permission for poddisruptionbudgets
    (#15107) (f00d07a)
  - operator: Publish images on docker hub upon release (#14786)
    (126ebed)
  - operator: update kube-rbac-proxy to upstream registry
    (#14809) (568d22f)
  - otlp: Write protobuf status on error (#15097) (63a2442)
  - partition-ingester: Add stream creation error logging
    (#15640) (f63c16f)
  - promtail: Fix API level node filtering of Kubernetes SD to
    only fetch pod metadata for pods of the current node (#14267)
    (d2b6fd8)
  - querier: show correct setting in error message (#14842)
    (f5ae015)
  - remove enabled field in loki-local-config.yaml (#15059)
    (7410f10)
  - remove unsafe pkg usage from util.mempool (#15428) (e6d82b9)
  - Return error 422 (Unprocessable Content) when push request
    does not contain any streams (#13706) (17bf32b)
  - Shut down delete client on local rule-evaluator (#15345)
    (42469cc)
  - structured metadata not always passed down for processing
    deletes (#15526) (a3808b6)
  - typo: Change "did received" to "did receive" in NOTES.txt
    (#15584) (9191eaf)
  - use KafkaEndOffset instead of -1 (#15099) (2113526)
  - Use separate variable to track the consume offset (#15095)
    (161a192)
  * Performance Improvements
  - approx_topk: Reduce memory usage of HyperLogLog in
    approx_topk. (#15559) (bef2043)
  - bloom: Compute chunkrefs for series right before sending task
    to builder (#14808) (66e6b1c)
  - blooms: Replace JSON lib for encoding/decoding metas (#14767)
    (57f16a0)
  - Improve approx_topk performance by reducing allocations.
    (#15450) (04994ca)
  * Reverts
  - "perf(bloom): Compute chunkrefs for series right before
    sending task to builder" (#14839) (4bfa380)
  * Miscellaneous Chores
  - Remove wget from Promtail docker image (#15101) (2eea546)
  * Dependency updates
    Please see the release notes
    https://github.com/grafana/loki/releases/tag/v3.4.0
* Wed Dec 18 2024 mrueckert@suse.de
- Update to version 3.3.2: (pulls in fix for CVE-2024-45337)
  * fix: fix the docker driver build (backport release-3.3.x) (#15478)
  * docs: fix admonition, line spacing (#15462) (#15480)
  * docs: add exception to spelling rule (backport release-3.3.x) (#15473)
  * docs: fixing broken command (backport release-3.3.x) (#15470)
  * docs: add URL to Log entry deletion page (backport release-3.3.x) (#15461)
  * docs: adding exceptions to Vale rule (backport release-3.3.x) (#15446)
  * docs: fix docs for bloom filters query acceleration hyperlink (backport release-3.3.x) (#15445)
  * docs: Update LogCLI topic (#15376) (#15413)
  * fix(deps): backport update module golang.org/x/crypto to v0.31.0 (#15394)
  * docs: removed compactor options from minIO deployment (backport release-3.3.x) (#15375)
  * docs: Logcli tutorial and sandbox (backport release-3.3.x) (#15369)
  * docs: sandbox fix for quickstart (backport release-3.3.x) (#15363)
  * ci: fix docker driver pipeline
  * docs: Fixing some Vale linter errors (backport release-3.3.x) (#15350)
  * chore: Document `approx_topk` keyword. (backport release-3.3.x) (#15347)
  * ci: fix docker driver publishing
  * feat: present DF bytes values in queryable format (backport release-3.3.x) (#15320)
  * fix: enable metric aggregation in `loki-local-config.yaml` (backport release-3.3.x) (#15319)
  * docs: correct dates in 2.9.x release notes (backport release-3.3.x) (#15303)
  * docs: Release notes for 2.9.11 (backport release-3.3.x) (#15289)
  * docs: Release notes for 3.3.2 (backport release-3.3.x) (#15286)
  * docs: Release notes for 3.2.2 (backport release-3.3.x) (#15282)
  * chore(release-3.3.x): release 3.3.1 (#15148)
* Mon Dec 16 2024 Andreas Schwab <schwab@suse.de>
- Enable cgo on riscv64
* Mon Dec  9 2024 Marcus Rueckert <mrueckert@suse.de>
- use golang(API) to force the proper version
* Mon Dec  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.3.1:
  * BREAKING CHANGES
  - promtail: Remove wget from Promtail docker image (backport
    release-3.3.x) (#15146)
  * Miscellaneous Chores
  - promtail: Switch Promtail base image from Debian to Ubuntu to
    fix critical security issues (#15195).
  - docker: Move from base-nossl to static. This PR removes the
    inclusion of glibc into most of the Docker images created by
    the Loki build system. (#15203).
* Mon Dec  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.3.0:
  * BREAKING CHANGES
  - blooms: Introduce a new block schema (V3) (#14038)
  - blooms: Index structured metadata into blooms (#14061)
  * Features
  - ability to log stream selectors before service name detection
    (#14154) (d7ff426)
  - add app_name as a service label (#13660) (f2a16f4)
  - add backoff mechanism to the retention process (#14182)
    (3136880)
  - add functions to common.libsonnet for warpstream (#14123)
    (2bde071)
  - add gauge loki_ingest_storage_reader_phase (#14679) (f5b0fb6)
  - add gauge to track the partition_id (#14713) (a142b3d)
  - add missing cluster label to mixins (#12870) (547ca70)
  - add query user and query source to "executing query" log
    lines (#14320) (4d69929)
  - add retries for s3 ObjectExists calls (#14062) (73cbbb0)
  - add structured metadata to the promtail push API (#14153)
    (66cffcb)
  - Add support for partition ingester in dashboards (#14498)
    (70deebf)
  - Allows to configure client_max_body_size (#12924) (809a024)
  - Apply patterns line length limit to json message key (#14296)
    (41fafd8)
  - blooms: Add bloom planner and bloom builder to backend target
    (#13997) (bf60455)
  - blooms: disk-backed queue for the bloom-planner (backport
    k227) (#14927) (1f6828b)
  - blooms: Index structured metadata into blooms (#14061)
    (a2fbaa8)
  - blooms: Only write key and key=value to blooms (#14686)
    (3af0004)
  - Configurable list of json fields to mine patterns (#14528)
    (7050897)
  - detected field values (#14350) (7983f94)
  - distributors: Use a pool of worker to push to ingesters.
    (#14245) (f80d68a)
  - Do not add empty blooms to offsets (#14577) (51c42e8)
  - Extract task computing into a strategy interface (#13690)
    (ab5e6ea)
  - fluentd-plugin-datadog-loki: support custom http headers
    (#14299) (e59035e)
  - helm: add additional service annotations for components in
    distributed mode (#14131) (5978f13)
  - helm: add configurable extraEnvFrom to admin-api and
    enterprisegw (#14533) (5d78a3a)
  - helm: Add kubeVersionOverride for Helm chart (#14434)
    (0935d77)
  - helm: Add persistence option to memcached on Helm chart
    (#13619) (ef1df0e)
  - helm: add tolerations to pattern-ingester statefulset
    (#13605) (09530c0)
  - helm: Allow setting node attributes to tokengen and
    provisioner (#14311) (c708ae6)
  - helm: Replace bloom compactor with bloom planner and builder
    (#14003) (08e61ca)
  - helm: update chart with loki version 3.2.0 (#14281) (11b92ee)
  - Helm: Update Loki Helm chart for restricted environments
    (#14440) (adc7538)
  - implement IsRetryableErr for S3ObjectClient (#14174)
    (fc90a63)
  - Implement owned streams calculation using Partition Ring
    (#14282) (3c36ba9)
  - Implement WAL segment ingestion via Kafka with partition ring
    (#14043) (d178f4c)
  - Improve pattern ingester tracing (#14707) (80aec25)
  - ingester: implement partition shuffle sharding for ingester
    (#14304) (1a4436c)
  - Introduce new ObjectExistsWithSize API to (#14268) (ac422b3)
  - Introduce shardable probabilistic topk for instant queries.
    (backport k227) (#14765) (02eb024)
  - jsonnet: Allow to name prefix zoned ingesters (#14260)
    (fac3177)
  - kafka: Add Ingestion from Kafka in Ingesters (#14192)
    (b6e9945)
  - kafka: Add support for SASL auth to Kafka (#14487) (e2a209c)
  - kafka: Enable querier to optionally query partition ingesters
    (#14418) (633bb5e)
  - kafka: enqueue commit offset only once per batch process
    (#14278) (beca6f3)
  - kafka: Implement limiter using partition ring for Kafka
    (#14359) (5cbb239)
  - kafka: Remove rate limits for kafka ingestion (#14460)
    (83a8893)
  - kafka: Replay kafka from last commit before allowing
    ingesters to become ready (#14330) (39b57ec)
* Mon Dec  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.2.2:
  * BREAKING CHANGES
  - promtail: Remove wget from Promtail docker image (backport
    release-3.2.x) (#15145)
  * Bug Fixes
  - logql: Updated JSONExpressionParser not to unescape extracted
    values if it is JSON object. (#14499).
  - storage: Have GetObject check for canceled context.
    S3ObjectClient.GetObject incorrectly returned nil, 0, nil
    when the provided context is already canceled (#14420).
  * Miscellaneous Chores
  - promtail: Switch Promtail base image from Debian to Ubuntu to
    fix critical security issues (#15195).
  - docker: Move from base-nossl to static. This PR removes the
    inclusion of glibc into most of the Docker images created by
    the Loki build system. (#15203).
- convert to obs_scm
- add %%if condition to build using CGO_ENABLED=1 on s390x, armv7l
  and i586
* Thu Oct 17 2024 mrueckert@suse.de
- Update to version 3.2.1:
  * ci: fix logql analyzer (backport release-3.2.x) [manual backport] (#14518)
  * fix(logql): updated JSONExpressionParser not to unescape extracted values if it is JSON object. (backport release-3.2.x) (#14502)
  * docs: update sample result on loki setup page (backport release-3.2.x) (#14493)
  * docs: Updated Fluent Bit docs to use official plugin + Sandbox (backport release-3.2.x) (#14490)
  * docs: Small update to install docs (backport release-3.2.x) (#14479)
  * docs: Update Promtail installation (backport release-3.2.x) (#14474)
  * docs: update Helm installation topics (backport release-3.2.x) (#14471)
  * docs: corrected result for the `flags` field in the examples (backport release-3.2.x) (#14468)
  * docs: Update alloy-otel-logs.md to correct a typo (backport release-3.2.x) (#14459)
  * docs: Revise the LogQL Analyzer topic (backport release-3.2.x) (#14454)
  * docs: remove reference to Agent Flow (backport release-3.2.x) (#14450)
  * docs: Updated Promtail to Alloy (backport release-3.2.x) (#14429)
  * fix(storage/chunk/client/aws): have GetObject check for canceled context (backport release-3.2.x) (#14422)
  * fix: Revert build image to Debian Bullseye to fix libc version issue in Promtail (#14386)
  * docs: OpenTelemetry Collector Sandbox Tutorial (backport release-3.2.x) (#14380)
  * fix(config): Copy Alibaba and IBM object storage configuration from common (#14315)
  * docs: fix broken links (backport release-3.2.x) (#14363)
  * docs: Reorganize Query Templates page (backport release-3.2.x) (#14335)
  * chore: [release-3.2.x] docs: Fix link bracket for query-acceleration-blooms (#14265)
  * chore: [release-3.2.x] docs: Fix typo in query-acceleration-blooms (#14251)
  * chore: [release-3.2.x] docs: add additional clarification for single binary helm installation (#14236)
  * chore: [release-3.2.x] docs: added video to components (#14232)
  * chore: [release-3.2.x] docs: Replace shortcodes on Storage topic (#14229)
  * chore: [release-3.2.x] docs: Added new Query best practices page (#14224)
  * chore: [release-3.2.x] fix: Add additional validation for timeout while retrieving headers (#14220)
  * chore: [release-3.2.x] docs: Explore Logs GA (#14219)
  * chore: [release-3.2.x] docs: Fix awkwardly worded line about fluent-cli (#14205)
  * chore: [release-3.2.x] docs: Update Loki components page with new bloom components (#14200)
  * chore: [release-3.2.x] ci: Update workflows to use actions that don't need organization secrets (#14195)
  * docs: Loki 3.2 Release Notes (#14194)
  * ci: use app token for release
  * chore(k218): release 3.2.0 (#14088)
* Fri Oct 11 2024 Marcus Rueckert <mrueckert@suse.de>
- refresh patches:
  harden_promtail.service.patch
  proper-data-directories.patch
- use the source epoch as build date
- since we only package releases we can also just use the version
  from the tag instead of a verbose version string
- no longer strip the binaries
- Update to version 3.2.0:
  * chore: [k218] docs: add `X-Scope-OrgID` header to Grafana datasource if multi-tenancy is enabled (#14172)
  * feat: add structured metadata to the promtail push API (#14153) (#14155)
  * chore: [k218] fix(blooms): Fix panic in initialisation of the bloom planner and builder (#14113)
  * chore: [k218] feat(blooms): Add bloom planner and bloom builder to `backend` target (#14092)
  * chore: [k218] chore(deps): Downgrade fake-gcs-server (#14085)
  * chore: [k218] feat(max-allowed-line-length): add config to set `max-allowed-line-length` in pattern ingester (#14076)
  * chore: [k218] fix: downgrade grpc to fix regression (#14075)
  * chore: [k218] fix: correct _extracted logic in detected fields (#14073)
  * chore: [k218] fix: enable service detection for otlp endoint (#14052)
  * chore: [k218] fix(`detected_fields`): return parsed labels when parsers are passed (#14050)
  * fix: do not retain span logger created with index set initialized at query time (#14027)
  * chore: [k218] chore(ci): fix failing arm builds (#14023)
  * feat: Add initial support for a kafka-based ingest path (#13992)
  * fix(detected_labels): Add matchers to get labels from store" (#14012)
  * feat: add _extracted suffix to detected fields conflicts (#13993)
  * fix: Propagate headers/warnings/stats from quantile downstreams (#13881)
  * chore: update dskit and thanos/objstore (#13998)
  * fix(deps): update module github.com/efficientgo/core to v1.0.0-rc.3 (#14001)
  * fix(deps): update module github.com/hashicorp/consul/api to v1.29.4 (#14002)
  * chore(deps): update anchore/sbom-action action to v0.17.2 (#13985)
  * fix(deps): update module github.com/baidubce/bce-sdk-go to v0.9.188 (#14000)
  * chore: Update nginx-unprivileged (#13978)
  * chore(blooms)!: Remove bloom compactor component (#13969)
  * docs: Update HTTP API docs for  limit (#13987)
  * fix: sanatize structured metadata at query time (#13983)
  * chore: Rename `HeapIterator` to `MergeEntryIterator` (#13975)
  * perf: Avoid looking up unnecessary TSDB symbols during Volume API (#13960)
  * chore: Update kiwigrid/k8s-sidecar (#13979)
  * chore(jsonnet)!: convert read statefulset into deployment for loki-simple-scalable (#13977)
  * chore(jsonnet): Add backend component to loki-simple-scalable jsonnet (#13976)
  * chore(docs): Rewrite query acceleration docs (#13965)
  * fix(deps): update module github.com/gorilla/websocket to v1.5.3 (#13873)
  * fix(detected labels): response when store label values are empty (#13970)
  * feat: Limit to block ingestion until configured date (#13958)
  * chore(deps): update terraform aws to v5 (#13961)
  * feat: ability to ignore cache for volume queries (#13945)
  * chore(deps): update terraform google to v5 (#13962)
  * fix(deps): update module github.com/ncw/swift to v2 (#13951)
  * fix(deps): update module github.com/tonistiigi/fifo to v1 (#13952)
  * chore(deps): update fluent/fluent-bit docker tag (#13843)
  * fix: Read full buffer from storage when fetching a range (#13948)
  * fix(deps): update module github.com/fsouza/fake-gcs-server to v1.47.7 (#13935)
  * chore(deps): update chunks/segments inspect dependencies (#13936)
  * fix(cloud-mixin): Attribute OTLP route correctly to write path (#13943)
  * chore: make mixin range interval configurable (#13925)
  * chore(deps): lamba-promtail, move back to al2, update krb5-libs (#13939)
  * chore(deps): LambdaPromtail - Bump to AmazonLinux 2023 (#13938)
  * fix(deps): update module github.com/baidubce/bce-sdk-go to v0.9.187 (#13933)
  * fix(deps): update module github.com/oschwald/geoip2-golang to v1.11.0 (#13934)
  * fix: record datasample queries are limited query type (#13930)
  * chore: log the query from the request when we're unable to get a result from the results cache (#13915)
  * fix: Improve execution speed for queries with label filters (#13922)
  * chore(deps): update dskit 20240819 (#13924)
  * feat(operator): Enable leader-election (#13760)
  * fix: split the error and agg metric cases for clarity (#13913)
  * chore(deps): Update dependencies, build version, and go version for lambda-promtail (#13904)
  * feat: aggregate byte and count metrics (#13731)
  * chore: Update to labeler v5 (#13911)
  * fix(deps): update module golang.org/x/time to v0.6.0 (#13910)
  * chore(deps): update terraform random to v3.6.2 (#13909)
  * chore(deps): update dependabot/fetch-metadata action to v2 (#13908)
  * chore(deps): update ruby docker tag to v3.3.4 (#13907)
  * fix(deps): update module github.com/ibm/go-sdk-core/v5 to v5.17.4 (#13892)
  * fix(deps): update module github.com/ibm/ibm-cos-sdk-go to v1.11.0 (#13893)
  * fix: Adjust tailer loop criteria so it is actually re-tested (#13906)
  * chore: remove unused pattern tokenization form Loki (#13783)
  * chore(deps): update anchore/sbom-action action to v0.17.1 (#13895)
  * fix: Read "404" as object not exist (#13901)
  * chore(deps): Revert "chore(deps): update actions/labeler action to v5" (#13899)
  * chore(deps): update actions/labeler action to v5 (#13894)
  * chore(deps): update azure/setup-helm action to v4 (#13890)
  * fix(deps): update module github.com/mattn/go-ieproxy to v0.0.12 (#13876)
  * chore(deps): update actions/setup-python action to v5 (#13889)
  * chore(deps): update actions/checkout action to v4 (#13888)
  * fix(deps): update module github.com/workiva/go-datastructures to v1.1.5 (#13885)
  * chore(deps): update terraform aws to ~> 4.67.0 (#13886)
  * feat(lambda-promtail): build lambda with zip file (#13787)
  * fix(deps): update module github.com/schollz/progressbar/v3 to v3.14.6 (#13884)
  * fix: Handle EOF when reading from some obj stores (#13868)
  * fix(deps): update module github.com/klauspost/pgzip to v1.2.6 (#13874)
  * chore(deps): update alpine docker tag to v3.20.2 (#13882)
  * fix: flaky test blockPlansForGaps (#13743)
  * fix(deps): update module github.com/azure/go-autorest/autorest/adal to v0.9.24 (#13862)
  * docs: Recommended quickstart changes + Upgrade (#13747)
  * chore: fix some comments (#13830)
  * fix(deps): update module github.com/docker/docker to v27.1.2+incompatible (#13872)
  * fix(deps): update module github.com/gogo/googleapis to v1.4.1 (#13871)
  * fix(deps): update module github.com/felixge/fgprof to v0.9.4 (#13870)
  * fix(deps): update module github.com/azure/go-autorest/autorest/azure/auth to v0.5.13 (#13863)
  * fix(deps): update module github.com/datadog/sketches-go to v1.4.6 (#13865)
  * chore: remove initial metric aggregation experiment (#13729)
  * fix(deps): update module github.com/baidubce/bce-sdk-go to v0.9.186 (#13864)
  * fix(deps): update module github.com/aliyun/aliyun-oss-go-sdk to v2.2.10+incompatible (#13861)
  * chore(deps): update grafana/loki-build-image docker tag to v0.33.6 (#13859)
  * chore(deps): update helm/chart-testing-action action to v2.6.1 (#13855)
  * chore(deps): update grafana/promtail docker tag to v1.6.1 (#13851)
  * chore(deps): update grafana/promtail docker tag to v2.9.10 (#13854)
  * chore(deps): update dependency go to v1.22.6 (#13842)
  * chore: Update loki build image to go 1.22.6 (#13857)
  * chore:  manual changelog backport (#13852)
  * chore(deps): update grafana/loki docker tag to v2.9.10 (#13848)
  * chore(deps): update golang docker tag to v1.22.6 (#13847)
  * chore(deps): update grafana/loki-build-image docker tag to v0.33.5 (#13849)
  * chore(ci): Update yaml file `./production/helm/loki/values.yaml` (+1 other) (#13832)
  * chore: [main] chore(release-3.1.x): release 3.1.1 (#13817)
  * fix(deps): update github.com/grafana/jsonparser digest to ea80629 (#13814)
  * fix(ci): fixed release-please manifest (#13810)
  * fix(deps): update github.com/c2h5oh/datasize digest to aa82cc1 (#13807)
  * fix(deps): update github.com/docker/go-plugins-helpers digest to 45e2431 (#13808)
  * fix(deps): update github.com/axiomhq/hyperloglog digest to af9851f (#13806)
  * chore(deps): update github.com/grafana/regexp digest to a468a5b (#13805)
  * chore: Turn off renovate on non-main branches (#13803)
  * fix(ci): add cleanup step into job `dist` (#13801)
  * chore: Add metastore client as dep for rf1 querier & ignore auth for ListBlocks (#13786)
  * fix(deps): update module golang.org/x/text to v0.17.0 (main) (#13794)
  * fix(operator): Don't overwrite annotations for LokiStack ingress resources (#13708)
  * fix: panic when parsing and extracting JSON key values (#13790)
  * feat(loki):  add ability to disable AWS S3 dualstack endpoints usage  (#13785)
  * fix(helm): fixed memcached and provisioner templates (#13788)
  * chore: Remove unused stream index from RF1 ingester (#13758)
  * fix: Include whitespaces in extracted tokens (#13738)
  * chore(deps): update module golang.org/x/net to v0.23.0 [security] (main) (#13763)
  * fix(deps): update module github.com/docker/docker to v27.1.1+incompatible [security] (main) (#13762)
  * feat: upgrade prometheus (#13671)
  * fix(break): helm: Fix how we set imagePullSecrets for enterprise-gateway and admin-api. (#13761)
  * chore(helm-chart): added SSE config into AWS storage config (#13746)
  * fix: try reading chunks which have incorrect offset for blocks (#13720)
  * docs: Update the Visualize topic (#13742)
  * feat: Introduce wal segment read path. (#13695)
  * build: Update loki-build-image to Alpine 3.20.2 (#13744)
  * fix: ast left cycular reference result in oom (#13501)
  * docs: fix broken links due to Alloy docs reorg (#13715)
  * docs: rewrite quickstart with Killercoda metadata (#13234)
  * chore: fix some comments (#13724)
  * feat(blooms): Add series & chunks per block metrics (#13721)
  * fix: Use elements match in gapsBetweenTSDBsAndMetas test (#13722)
  * feat: Ingester Stream Limit Improvements (#13532)
  * chore: add service_name label earlier in the ingestion pipeline (#13702)
  * fix: protect ruler remote-write overrides map with a mutex when creating new appenders (#13676)
  * docs: Late review comments and linting (#13714)
  * docs: Update Observability topic (#13323)
  * chore(lint-error): remove unused `stepCount` in `engine.go` (#13709)
  * chore: add congestion control to AWS (#13691)
  * chore: log stats around chunks being flushed (#13699)
  * chore: treat datasample queries the same as limited queries (#13700)
  * fix: fixed typo in ruler URL (#13692)
  * chore: Use boltdb Batch API for metastore writes (#13693)
  * feat(operator): Add alert for discarded samples (#13512)
  * fix(blooms): Ship chunkrefs in task payload (#13677)
  * chore: use native histogram for metastore_request_duration_seconds (#13680)
  * feat: instrument failed chunk encoding/decoding (#13684)
  * docs: State limitations of bloom filters (#13673)
  * fix: add missing flush op timeout (#13679)
  * fix: Handle block offset exceeding chunk length in memchunk.go (#13661)
  * feat: Ignore empty streams in distributor if all entries fail validation (#13674)
  * fix: fix a bug where AppendRequest with no entries triggers flush (#13672)
  * docs: Fixed link test (#13666)
  * fix: special case the return values from a sharded first/last_over_time query (#13578)
  * fix(blooms): Improve error wrap to make ignoreNotFound work when fetching blocks (#13656)
  * docs: Send Data Alloy page + Interactive Examples (#13367)
  * chore(helm): fix comment in values.yml (#13638)
  * chore: Remove client header interceptors from metastore client (#13659)
  * feat: add loki_ingester_rf1_segment_age_seconds metric (#13653)
  * feat(detected-labels): remove cardinality filter (#13652)
  * fix(helm): removed helm test (#13651)
  * chore: move timestamps into SegmentWriter (#13644)
  * feat: Implement GetObjectRange for all storage providers (#13650)
  * fix: remove trailing backtick in verify-config for Loki 3.0 (#13640)
  * fix: remove limit middleware for `detected_labels` (#13643)
  * feat: Add baseline rf1 querier implementation (#13639)
  * feat: remove mutexes from wal.SegmentWriter (#13641)
  * feat(rf1): Add query path for the metastore (#13636)
  * feat: Calculate the age of a WAL segment (#13637)
  * feat(lambda-promtail): Adding S3 log parser support for AWS GuardDuty (#13148)
  * fix(helm): fix imagePullSecrets for statefulset-results-cache (#13051)
  * feat(rf1): Store index ref in metastore (#13613)
  * fix(loki-mixin): Fix latency panel for Index Gateway (#13629)
  * fix(blooms): Use correct key to populate blockscache at startup (#13624)
  * fix: Keep blocks referenced by newer metas (#13614)
  * fix(blooms): Cleanup temp blockdir in bloom compactor (#13622)
  * chore(deps): update nginx docker tag to v1.27 (main) (#13620)
  * fix(deps): update module github.com/gorilla/mux to v1.8.1 (main) (#13618)
  * chore(deps): update confluentinc/cp-kafka docker tag to v6.2.15 (main) (#11283)
  * docs: small update to doc loki-http-api.md (#13594)
  * fix(deps): update module github.com/cespare/xxhash/v2 to v2.3.0 (main) (#13615)
  * feat(structured-metadata-api): add structured metadata to `/detected_fields` API (#13604)
  * fix: remove retries on the stats handlers because they already retry (#13608)
  * feat: Instrument rf1 write path with tracing (#13599)
  * feat: Instrument metastore GRPC calls (#13598)
  * chore: Remove excessive logging from bloom gateway (#13603)
  * docs: add docs comparing native otlp ingestion vs loki exporter (#13574)
  * fix: fix retry code to handle grpc status codes. updated newer stats retries to be wrapped with spans (#13592)
  * fix: add a retry middleware to all the stats handlers (#13584)
  * docs: added video for fluentd and fluent bit (#13579)
  * feat: lambda-promtail; ensure messages to Kinesis are usable by refactoring parsing of KinesisEvent to match parsing of CWEvents + code cleanup (#13098)
  * chore: do not shard log queries with empty filter (#13568)
  * chore: shard limited queries with a fixed sharding factor (#13576)
  * chore: replace pkg/errors with errors (#13583)
  * chore: replace pkg/errors with errors (#13582)
  * chore: replace pkg/errors with errors (#13581)
  * feat: Bootstrap metastore for wal segments (#13550)
  * fix(deps): update module github.com/docker/docker to v25.0.5+incompatible [security] (main) (#12279)
  * fix(blooms): Fix eviction of multiple blockcache items (#13573)
  * feat: Track when builders are doing work with a gauge (#13570)
  * docs: Deprecated Notice for Grafana Agent + Updated Helm Concepts (#13461)
  * fix: incorrect pod matcher for compactor in mixin when using ssd mode (#12846)
  * build: Loki build and Docker updates (#13325)
  * fix(operator): Set object storage for delete requests when using retention (#13562)
  * feat: Update doc-validator version (#13558)
  * fix: Dedup pattern tokens on output (#13534)
  * fix: Retain original values in logfmt pattern tokenizer (#13535)
  * fix: Fix panic in ingester.go (#13557)
  * chore: Rename PendingItem to PendingSegment and clean up flush.go (#13554)
  * chore: Remove redundant comments (#13553)
  * chore: Use filesystem backed writer for blooms (#13522)
  * fix: Fix log line for fingerprint not found (#13555)
  * feat: Add CLI to inspect RF=1 WAL segments (#13552)
  * chore: Clean up old streams periodically in RF-1 ingester (#13511)
  * chore: refactor WAL Manager (#13551)
  * chore: Clean up manager_test.go (#13549)
  * chore: Use github.com/coder/quartz instead of time (#13542)
  * chore(deps): update module github.com/azure/azure-sdk-for-go/sdk/azidentity to v1.6.0 [security] (main) (#13434)
  * chore: Remove unused const (#13544)
  * chore: Remove size and duration logs now we have metrics (#13547)
  * chore: Fix not ready error message in RF-1 Ingester (#13546)
  * fix: Fixes span name of serializeRounTripper (#13541)
  * chore: Use pool of bytes.Buffer instead of io.Pipe (#13543)
  * feat: Remove flush loop and queue from Ingester RF-1 (#13538)
  * fix(helm): Update yaml file `./production/helm/loki/Chart.yaml` (+1 other) (#13392)
  * feat(helm): Support alibabacloud oss in helm chart (#13441)
  * fix(helm): Update yaml file `./production/helm/loki/values.yaml` (+1 other) (#13426)
  * test: Add logging for empty blooms (#13537)
  * fix(operator): Allow structured metadata only if V13 schema provided (#13463)
  * feat: Add metrics for Ingester RF-1 (#13510)
  * feat: WAL Manager configuration options (#13531)
  * build(deps): bump golang.org/x/net from 0.22.0 to 0.23.0 in /cmd/chunks-inspect (#13433)
  * docs: Add Explore Logs to Release Notes (#13529)
  * fix: detected fields incorrect type bug (#13515)
  * fix(blooms): Remove backoff from notify planner (#13506)
  * fix(operator): Remove duplicate conditions from status (#13497)
  * feat: improve placeholder replacement of byte sizes (#13508)
  * chore: Improve test coverage of WAL Manager (#13498)
  * chore: Remove unused metrics from Ingester-RF1 (#13499)
  * fix: add logging to empty bloom (#13502)
  * fix(blooms): skip empty blooms on reads (#13500)
  * perf(blooms): Avoid tiny string allocations for insert cache (#13487)
  * feat: downsample aggregated metrics (#13449)
  * chore: Remove un-used errors from WAL Manager (#13496)
  * chore: Small fixes to comments and ErrFull in manager.go (#13494)
  * feat: Add metrics to WAL Manager (#13490)
  * feat: Use WAL Manager (#13491)
  * fix: Return empty vector instead of nil for empty evaluator. (#13485)
  * fix(operator): Skip updating annotations for serviceaccounts (#13450)
  * fix: Fix HPA ingester typo (#13158)
  * refactor(blooms): Apply retention in planner (#13484)
  * feat: WAL Manager (#13428)
  * fix(query engine): Include lines with ts equal to end timestamp of the query range when executing range aggregations (#13448)
  * docs: fix broken link (#13480)
  * fix: Update Loki v3 Helm statefulset-ingester.yaml template (#13118)
  * fix(operator): Support v3.1.0 in OpenShift dashboards (#13430)
  * docs: Fix broken link (#13470)
  * feat: RF1 improves replication stategy to support 1 replica (#13469)
  * fix: Properly reset wal segment writer (#13468)
  * feat(exporter): include boolean values in limit exporter (#13466)
  * feat: Pattern ingesters add a limiter for high eviction rate (#13464)
  * test: Add range aggregation test for instant queries (#13447)
  * fix: Fix panic in BloomStore initialisation (#13457)
  * docs: doc/promtail/journal: adds available labels paragraph (#11888)
  * fix: Fixes pattern pruning stability (#13429)
  * refactor(blooms): Improve task progress logging in builder (#13394)
  * fix(gateway client): Fix nil pointer dereference panic when using ruler in ring mode (#13436)
  * chore: Convert iterators in pattern module to `v2.Iterator` interface (#13407)
  * docs: Add workaround instructions in upgrade guide for API changes (#13439)
  * fix(log results cache): include pipeline wrapper disabled in cache key (#13328)
  * feat(chunks-inspect): support structured metadata  (#11506)
  * feat(api)!: Fail log queries when executed on instant query endpoint (#13421)
  * feat(operator): Update Loki operand to v3.1.0 (#13422)
  * chore: Set memberlist func for ingester-rf1 init (#13424)
  * fix: Remove query size limit for detected fields (#13423)
  * chore: Refactor storage interface for rf1 (#13415)
  * fix(operator): Watch for CredentialsRequests on CCOAuthEnv only (#13299)
  * chore: use read-only index store for ingester RF1 (#13419)
  * chore: Update CHANGELOG.md (#13417)
  * feat: Drain uses different tokenizer based on log format (#13384)
  * test: Fix flaky congestion test (#13410)
  * feat(loki): Do not enforce max-query-bytes-read and max-querier-bytes-read in limited tripperware (#13406)
  * chore: Improve performance of structured metadata (#13404)
  * docs: update _index.md to reflect config file name and location change (#13390)
  * fix: querier address in SingleBinary mode (#13297)
  * feat: Use prefixed WAL storage path in Object Storage (#13377)
  * chore: adjusted SegmentWriter to the reader conversion (#13342)
  * feat: Ingester RF-1 (#13365)
  * chore: Update Docker images to Go 1.22.5 (#13398)
  * feat: exclude  in pattern tokens (#13397)
  * build: Update Loki build image to 0.33.4 (#13396)
  * feat: exclude  and  from creating new tokens in patterns (#13395)
  * perf: Limit tokens per pattern to 128 (#13376)
  * fix(blooms): Delete outdated metas during planning (#13363)
  * chore: Make dedicated iterator package (#13273)
  * fix(blooms): Suppress error from resolving server addresses for blocks (#13385)
  * feat(operator): Add support for the volume API (#13369)
  * docs: Loki 3.1 release notes (#13386)
  * docs: update Promtail doc (#13330)
  * docs: fix broken link and add alt text  (#13322)
  * docs: More Alloy updates (#13336)
  * perf: Gather aggregate per-line and per-tenant metrics for Drain patterns (#13368)
  * chore(deps): update module github.com/azure/azure-sdk-for-go/sdk/azidentity to v1.6.0 [security] (main) (#13199)
  * fix(blooms): ensure tokenizer cache is reset between series (#13370)
  * chore(deps): update module github.com/hashicorp/go-retryablehttp to v0.7.7 [security] (main) (#13304)
  * refactor(blooms): Better task naming (#13361)
  * docs: Updated bucket names and added warning (#13347)
  * refactor(blooms): Fix and improve build metrics (#13360)
  * fix(sharding): use without() grouping when merging `avg_over_time` shard results (#12176)
  * fix(retry): fix retries when using protobuf encoding (#13316)
  * docs: Label filter expression: Change unit suffix suffix to proper case whe… (#13344)
  * fix: support multi-zone ingesters when converting global to local limits for streams in limiter.go (#13321)
  * perf: Prune unused pattern branches (#13329)
  * fix(blooms): Remove unused arg (#13343)
  * feat: convert WalSegmentWriter to io.ReadSeeker (#13340)
  * fix(blooms): Minor fixes and improvements for testing in dev (#13341)
  * fix: stream ownership check (#13314)
  * refactor: Introduce context cause to our code (#13224)
  * refactor(blooms): more easily testable day partitioning (#13331)
  * chore(blooms): Various minor code cleanups (#13332)
  * feat: Collect duplicate log line metrics (#13084)
  * fix: Lint issues after merge to main (#13326)
  * refactor(blooms): Implement retry in builder (#13306)
  * refactor(blooms): Do not use sleeps on integration test (#13308)
  * docs: Clarify Unit Requirement for Duration Comparison in Label Values (#13318)
  * chore(mempool): Wait for buffer instead of returning error (#13298)
  * docs: Update configuration.md (#13309)
  * docs: Replace instances of k6.io/docs with grafana.com/docs/k6 (#13302)
  * fix(blooms): Fix panic in bloom gateway (#13303)
  * perf(blooms): always return bloom pages to allocator (#13288)
  * refactor(blooms): Bloom building integration test (#13296)
  * feat(wal): Benchmark and improve WAL writes using Reset. (#13272)
  * feat(helm): Make gateway container port configurable. (#13294)
  * perf(mempool): Replace `sync.Mutex` with `sync.Once` (#13293)
  * fix(blooms): ignores bloom filtering errors in bounded shard query planning (#13285)
  * perf(blooms): mempool no longer zeroes out buffers unnecessarily (#13282)
  * fix(blooms): improves mempool metrics (#13283)
  * refactor: Remove unnecessary spanlogger usage (#13255)
  * feat: Add settings for cpu/mutex/block profiling options (#13278)
  * chore(index-gateway): Improve instrumentation of index download/sync (#13194)
  * feat(ingester): Smooth out chunk flush operations (#9994)
  * chore(index-gateway): Download then extract in separate steps (#13202)
  * feat(wal): Add sizing information to writer and reader. (#13267)
  * fix: remove tenant label tagging from profiles to reduce cardinality (#13270)
  * docs: Fix typos and style (#13230)
  * chore: Update upgrade docs for -ruler.alertmanager-use-v2 (#13264)
  * docs: fix typo causing broken link (#13258)
  * perf: Re-introduce fixed size memory pool for bloom querier (#13172)
  * refactor(blooms): Add metrics for per-tenant tasks progress to planner (#13078)
  * feat: Introduce a new Object Storage WAL format. (#13253)
  * feat: collect and serve pre-aggregated bytes and counts (#13020)
  * chore: Change default version to Alertmanager APIv2 (#13263)
  * feat: flush not owned streams (#13254)
  * fix(mixin): various latency panels in operational dashboard should have ms unit type instead of seconds (#13260)
  * feat: improve Owned Streams feature observability  (#13232)
  * fix(helm): fix extraObjects (#13107)
  * fix: update fixed limit once streams ownership re-checked (#13231)
  * fix: separates directory creation from permission checks (#13248)
  * feat: Added getting started video for ingesting Otel logs (#13226)
  * fix: Redo ingester profile tagging (#13239)
  * docs: Update timestamp topic (#13207)
  * docs: Update OTLP endpoint (#13235)
  * ci: fix accidentally skipped package failures (#13240)
  * chore: Checkin missing etcd.io/bbolt vendor files (#13228)
  * chore: Update go.etcd.io/bbolt to v1.3.8 (#13227)
  * fix: Init internal server log along with loki's server instance (#13221)
* Mon Sep 16 2024 Michal Hrusecky <michal.hrusecky@opensuse.org>
- Add lokitool subpackage
- Remove harden_promtail.service.patch as we are using service file shipped separately
* Mon Sep 16 2024 michal.hrusecky@opensuse.org
- Update to version 3.1.1+git.1723126694.89fe788d:
  * chore: [release-3.1.x] fix(ci): fixed release-please manifest (#13811)
  * chore: [release-3.1.x] fix(ci): add cleanup step into job `dist` (#13802)
  * chore: [release-3.1.x] feat(loki):  add ability to disable AWS S3 dualstack endpoints usage  (#13795)
  * chore: [release-3.1.x] feat: Update doc-validator version (#13796)
  * fix(deps): bumped dependencies versions to resolve CVEs (#13789)
  * chore: [release-3.1.x] docs: Update the Visualize topic (#13750)
  * chore: [release-3.1.x] docs: fix broken links due to Alloy docs reorg (#13740)
  * chore: [release-3.1.x] docs: rewrite quickstart with Killercoda metadata (#13737)
  * chore: [release-3.1.x] chore: fix some comments (#13728)
  * chore: [release-3.1.x] docs: Late review comments and linting (#13716)
  * docs: Update Observability topic (#13323) (#13712)
  * chore: [release-3.1.x] fix: fixed typo in ruler URL (#13697)
  * chore: [release-3.1.x] docs: State limitations of bloom filters (#13682)
  * chore: [release-3.1.x] docs: Fixed link test (#13669)
  * chore: [release-3.1.x] docs: Send Data Alloy page + Interactive Examples (#13664)
  * chore: [release-3.1.x] fix: remove trailing backtick in verify-config for Loki 3.0 (#13648)
  * chore: [release-3.1.x] docs: small update to doc loki-http-api.md (#13617)
  * chore: [release-3.1.x] docs: add docs comparing native otlp ingestion vs loki exporter (#13597)
  * chore: [release-3.1.x] docs: added video for fluentd and fluent bit (#13587)
  * chore: [release-3.1.x] docs: Add Explore Logs to Release Notes (#13530)
  * chore: [release-3.1.x] docs: fix broken link (#13481)
  * chore: [release-3.1.x] docs: fix typo causing broken link (#13477)
  * chore: [release-3.1.x] docs: Fix broken link (#13472)
  * chore: [release-3.1.x] docs: doc/promtail/journal: adds available labels paragraph (#13452)
  * chore: [release-3.1.x] docs: Loki 3.1 release notes (#13403)
  * chore: [k207] chore(deps): update module github.com/hashicorp/go-retryablehttp to v0.7.7 [security] (main) (#13375)
  * chore: [k207] fix(blooms): ensure tokenizer cache is reset between series (#13373)
  * chore: [k207] feat: Add settings for cpu/mutex/block profiling options (#13281)
  * chore: [k207] chore(index-gateway): Improve instrumentation of index download/sync (#13280)
  * chore: [k207] chore: download then extract in separate steps (#13279)
  * chore: [k207] fix: remove tenant label tagging from profiles to reduce cardinality (#13271)
  * chore: [k207] fix: separates directory creation from permission checks (#13257)
  * chore: [k207] fix: Init internal server log along with loki's server instance (#13256)
  * chore: [k207] fix: Redo ingester profile tagging (#13246)
  * feat: Optimize log parsing performance by using unsafe package (#13223)
  * docs(helm): Fix broken `Values.yaml` link in the examples docs (#13219)
  * fix: add detected_level info when the info word appears on log message (#13218)
  * feat: add recalculateOwnedStreams to check stream ownership if the ring is changed (#13103)
  * docs: remove redundant backticks from http api documentation (#13212)
  * docs: fix query example for labels and values (#13213)
  * fix(operator): add alertmanager client config to ruler template (#13182)
  * feat: Update Loki monitoring docs to new meta monitoring helm (#13176)
  * docs: Update Get-Started Labels (#13188)
  * fix: Fix duplicate enqueue item problem in bloom download queue when do sync download (#13114)
  * fix: errors reported by the race detector (#13174)
  * chore(blooms): Some boom gateway cleanups (#13165)
  * feat: Add backoff to flush op (#13140)
  * fix(otel): Map 500 errors to 503 (#13173)
  * fix: Correctly encode step when translating proto to http internally (#13171)
  * fix: properly return http status codes from ingester to querier for RPC function calls (#13134)
  * fix: add retry middleware to the "limited" query roundtripper (#13161)
  * feat: Add new Drain tokenizer that splits on most punctuation (#13143)
  * fix(orFilters): fix multiple or filters would get wrong filtertype (#13169)
  * fix: Fix bloom deleter PR after merge (#13167)
  * refactor(blooms): Delete outdated metas (#13153)
  * feat(blooms): Blooms/v2 encoding multipart series (#13093)
  * docs: Loki landing page (#13127)
  * fix(regression):  reverts grafana/loki#13039 to prevent use-after-free corruptions (#13162)
  * fix: Fix indentation of query range values in helm (#12577)
  * docs: Remove unnecessary whitespaces in YAML Helm installs templates (#13147)
  * perf: Introduce fixed size memory pool for bloom querier (#13039)
  * fix: Add copyString function to symbolizer to avoid retaining  memory (#13146)
  * feat: Updated SS and microservices deployment docs (#13083)
  * refactor(blooms): Limit task retries in bloom planner (#13139)
  * feat: Tune Patterns query drain instance (#13137)
  * refactor(blooms): Forward created metas from builder to planner (#13133)
  * fix(blooms): bloomshipper no longer returns empty metas on fetch (#13130)
  * refactor(blooms): Implement retry mechanisms in planner (#13064)
  * fix(mixins): Align loki-writes mixins with loki-reads (#13022)
  * feat(promtail): Support of RFC3164 aka BSD Syslog (#12810)
  * feat(detected-labels): include labels with cardinality > 1 (#13128)
  * fix(operator): Improve API documentation for schema version (#13122)
  * chore(operator): update the release-please config for next release (#13120)
  * fix: Do not filter out chunks for store when `From==Through` and `From==start`  (#13117)
  * feat: Support negative numbers in LogQL (#13091)
  * refactor(blooms): Build new metas and blocks (#13074)
  * feat: Introduce `index audit` to `lokitool` (#13008)
  * feat(canary): Add test to check query results with and without cache. (#13104)
  * feat: API: Expose optional label matcher for label names API (#11982)
  * docs: Fix link in examples (#13094)
  * chore( operator): community release 0.6.1 (#12593)
  * chore(operator): prepare community release v0.6.1 (#13105)
  * fix(operator): Use a minimum value for replay memory ceiling (#13066)
  * feat: add profile tagging to ingester (#13068)
  * feat: Add utf8 support to Pattern Lexer to support utf8 chars (#13085)
  * docs: Republish the sizing calculator but don't list it in the table of contents and don't index it (#13070)
  * fix: Update expected patterns when pruning (#13079)
  * feat: Add tokenizer interface for Drain Training (#13069)
  * fix: Introduce feature flag for [last|first]_over_time sharding. (#13067)
  * fix: Fix incorrect sorting of chunks in bloom-filtered response since `ChunkRef.Cmp` method is used in reverse (#12999)
  * refactor(blooms): Builder retrieves tasks from planner (#13046)
  * feat: Add ingester_chunks_flush_failures_total (#12925)
  * feat: Increase drain max depth from 8 -> 30 (#13063)
  * fix: temporarily moving from alloy -> alloy dev (#13062)
  * docs: Update Grafana Agent to Grafana Alloy (#12602)
  * docs: update otlp ingestion docs to correct some info and add more details (#12969)
  * fix(helm): fix query-frontend and ruler targetPort 'http-metrics' in Service template (#13024)
  * feat(blooms): Add counter metric for blocks that are not available at query time (#12968)
  * feat: Added video and updated Grafana Agent -> Alloy (#13032)
  * fix: Fix panic on requesting out-of-order Pattern samples (#13010)
  * refactor(blooms): Add RPC service for bloom-planner (#13015)
  * fix: not owned stream count (#13030)
  * fix(helm): fix queryScheduler servicemonitor (#12753)
  * fix: change log level since this is a known case (#13029)
  * feat(helm): Support for PVC Annotations for Non-Distributed Modes (#12023)
  * feat: Added Interactive Sandbox to Quickstart tutorial (#12701)
  * feat: new stream count limiter (#13006)
  * fix: allow cluster label override in bloom dashboards (#13012)
  * fix: upgrade old plugin for the loki-operational dashboard. (#13016)
  * fix: remove unneccessary disk panels for ssd read path (#13014)
  * fix: Mixins - Add missing log datasource on loki-deletion (#13011)
  * refactor(blooms): Add queue to bloom planner and enqueue tasks (#13005)
  * docs: update otlp ingestion with correct endpoint and add endpoint to reference api docs (#12996)
  * refactor(bloom planner): Compute gaps and build tasks from metas and TSDBs  (#12994)
  * feat: loki/main.go: Log which config file path is used on startup (#12985)
  * chore: remove duplicate imports (#13001)
  * fix(indexstats): do not collect stats from "IndexStats" lookups for other query types (#12978)
  * feat: Added getting started video (#12975)
  * feat(blooms): Separate page buffer pools for series pages and bloom pages (#12992)
  * docs: Fix broken link in the release notes (#12990)
  * docs(install-monolithic): add quotation marks (#12982)
  * feat: Boilerplate for new bloom build planner and worker components. (#12989)
  * feat(cache): Add `Cache-Control: no-cache` support for Loki instant queries. (#12896)
  * fix: Track bytes discarded by ingester. (#12981)
  * feat(reporting): Report cpu usage (#12970)
  * perf: Replace channel check with atomic bool in tailer.send() (#12976)
  * perf: Improve Detected labels API (#12816)
  * feat: Add metrics for number of patterns detected & evicted (#12918)
  * feat(bloom): Skip attempts to filter chunks for which blooms have not been built (#12961)
  * fix(blooms): Disable metas cache on bloom gateway (#12959)
  * fix: fix parsing of default per tenant otlp config (#12836)
  * feat: improve performance of `first_over_time` and `last_over_time` queries by sharding them (#11605)
  * docs: Update _index.md (#12814)
  * docs: update NixOS wiki link (#12940)
  * docs: fix typo ? (#12898)
  * test: Added more test data for pattern detection tests (#12920)
  * fix: Fix for how the loop sync is done (#12941)
  * fix: panics when ingester response is nil (#12946)
  * chore(logging): Add entry's timestamp when rejected with `too far behind` (#12933)
  * fix(helm): fixed ingress paths mapping (#12932)
  * fix: Defer closing blocks iter after checking error from loadWorkForGap (#12934)
  * fix: Optimize regular initialization (#12926)
  * fix(promtail): Fix bug with Promtail config reloading getting stuck indefinitely (#12795)
  * test: First pass at unregistering metrics so that we can run multiple tests (#12927)
  * style: fix function names (#12817)
  * docs: Don't allow running new and old querier worker grpc clients (#12916)
  * fix(helm): Fix GEL image tag, bucket name and proxy URLs (#12878)
  * chore: Call `shardstreams.Config` by value instead of by reference (#12915)
  * feat(detectedFields): Support multiple parsers to be returned for a single field (#12899)
  * fix: Use an intermediate env variable in GH workflow (#12905)
  * fix: Invalidate caches when pipeline wrappers are disabled (#12903)
  * ci: force one time run of helm release for 5.48 (#12888)
  * fix(blooms): Clean block directories recursively on startup (#12895)
  * fix(blooms): Fix `partitionSeriesByDay` function (#12900)
  * chore(blooms): records more bloom iteration stats (#12889)
  * feat: Querier: Split gRPC client into two. (#12726)
  * fix: Fix log level detection (#12651)
  * fix(spans): corrects early-close for a few spans (#12887)
  * docs: add GEL install to the Helm page (#12860)
  * docs: Update release notes for 2.9.8 (#12881)
  * chore(operator): Update Loki operand to v2.9.8 (#12874)
  * chore(instrumentation): reintroduce span propagation across scheduler boundaries (#12880)
  * fix: `codec` not initialized in downstream roundtripper (#12873)
  * docs: Update logcli command reference (#12850)
  * feat(detectedFields): add parser to response (#12872)
  * docs: Consistent quoting in Template functions docs (#12833)
  * chore: Add dashboards for Bloom Compactor and Gateway (#12855)
  * docs(helm): Improve the helm's NOTES.txt (#12744)
  * ci: make renovate commits come in as fixes (#12867)
  * ci: [CI/CD] Update yaml file `./production/helm/loki/values.yaml` (+1 other) (#12868)
  * fix(packaging): Require online network in systemd unit file for Loki and Promtail (#12741)
  * chore(blooms): additional spans for bloom read path (#12866)
  * chore: reduces span footprint + double recording (#12864)
  * feat(blooms): ignore individual bloom-gw failures (#12863)
  * feat(blooms): Add in-memory LRU cache for meta files (#12862)
  * docs: Update docker installation topic (#12770)
  * fix: Ensure Drain patterns are valid for LogQL pattern match filter (#12815)
  * docs: update the lokitool docs (#12805)
  * fix(blooms): Handle not found metas gracefully (#12853)
  * docs: Update template_functions.md (#12841)
  * chore(blooms): Remove ID field from task struct (#12851)
  * feat(blooms): ingester aware bounded impl (#12840)
  * fix: Fix compactor matcher in the loki-deletion dashboard (#12790)
  * chore: Add notes about promtail being feature complete  (#12827)
  * fix: Add missing Helm helper loki.hpa.apiVersion (#12755)
  * fix(blooms): Do not fail requests when fetching metas from cache fails (#12838)
  * fix: Fixes read & backend replicas settings (#12828)
  * fix(blooms): Fully deduplicate chunks from FilterChunkRef responses (#12807)
  * fix(blooms): dont break iterator conventions (#12808)
  * feat(helm): Allow extraObject items as multiline strings (#12397)
  * ci: Add lokitool to the dist target (#12830)
  * feat(blooms): compute chunks once (#12664)
  * docs: hint on line and timestamp functions in docs for line_format stage (#12740)
  * docs: Add info about step param for Patterns API (#12803)
  * feat: parameterise the MaximumEventAgeInSeconds, LogGroupName, and IAMRoleName for lambda-promtail CloudFormation template (#12728)
  * fix: loki-operational.libsonnet (#12789)
  * docs: Fix typo in structured-metadata.md (#12818)
  * fix(ksonnet): Do not generate rbac for consul if you are using memberlist (#12688)
  * feat(blooms): limit bloom size during creation (#12796)
  * fix(promtail): Handle docker logs when a log is split in multiple frames (#12374)
  * fix(blooms): Reset error on LazyBloomIter.Seek (#12806)
  * feat: Generic logline placeholder replacement and tokenization (#12799)
  * fix: add missing parentheses in meta monitoring dashboards (#12802)
  * fix: remove unused parameter causing lint error (#12801)
  * feat: Add a version of the mixin dashboards for meta monitoring (#12700)
  * feat: Add step param to Patterns Query API (#12703)
  * fix(blooms): Deduplicate filtered series and chunks (#12791)
  * chore(loki-mixin): Fixes for `loki-reads` dashboard (#12788)
  * test: Add mutex and setter/getter for addresses in test (#12793)
  * chore(blooms): Instrument source bytes added to blooms directly (#12782)
  * fix: promtail; clean up metrics generated from logs after a config reload. (#11882)
  * docs: Helm: Don't show defaults for `loki` section (#12747)
  * docs: update release docs (#12511)
  * docs: order configuration template fileds alphabetically (#12771)
  * feat: Updated best practises for labels (#12749)
  * ci: release workflows get build image from makefile (#12778)
  * docs: Update storage topics (v3.0) (#12768)
  * chore(blooms): adds more instrumentation to block building (#12779)
  * fix(blooms): Fix a regression introduced with #12774 (#12776)
  * fix(blooms): Correctly return unfiltered chunks for series that are not mapped to any block (#12774)
  * feat: Update getting started demo to Loki 3.0 (#12723)
  * fix(workflows): don't run metric collector on forks (#12687)
  * fix(nix): lambda-promtail vendor hash (#12763)
  * ci: add a github workflow to verify that the release workflows are correct (#12603)
  * fix(docs): Move promtail configuration to the correct doc (#12737)
  * feat: add detected-fields command to logcli (#12739)
  * feat: Detected labels from store (#12441)
  * docs: fix broken link (#12757)
  * docs: Update supported and deprecated type in Manage > Storage (#12742)
  * test: Data race updates for memchunk tests (#12752)
  * fix: helm: Set compactor addr for distributed mode. (#12748)
  * chore(deps): bump golang.org/x/net from 0.17.0 to 0.23.0 in /pkg/push (#12694)
  * chore(deps): bump golang.org/x/net from 0.17.0 to 0.23.0 in /tools/lambda-promtail (#12696)
  * chore(deps): bump golang.org/x/net from 0.21.0 to 0.23.0 in /operator (#12698)
  * chore(deps): bump golang.org/x/net from 0.22.0 to 0.23.0 (#12699)
  * perf(blooms): Resolve bloom blocks on index gateway and shard by block address (#12720)
  * fix(promtail): Fix UDP receiver on syslog transport (#10708)
  * fix(docs): broken link in getting started readme (#12736)
  * fix: update to build image 0.33.2, fixes bug with promtail windows DNS resolution (#12732)
  * docs: Add Azure example configuration snippets (#12725)
  * docs: Fix mangled admonition block in alerting/recording rule docs (#12733)
  * ci: update drone image version to 0.33.2 (#12730)
  * fix: Add missing OTLP endpoint to nginx config (#12709)
  * chore(operator) Revert "feat(operator): Add support for Swift TLS CA configuration" (#12693)
  * chore(helm): set Singlebinary as trigger for replicas (#12590)
  * fix: updated all dockerfiles go1.22 (#12708)
  * fix: make detected fields work for both json and proto (#12682)
  * ci: update build image to use newer versions of jsonnet and other related tools (#12706)
  * fix(mixin): dashboards $__auto fix (#12707)
  * fix: mixin generation when cluster label is changed (#12613)
  * feat: area/promtail: Added support to install wget on promtail docker image to support docker healthcheck (#11711)
  * fix: Missing password for Loki-Canary when loki.auth_enabled is true (#12411)
  * fix: Ingester zoneAwareReplication (#12659)
  * ci: Update yaml file `./production/helm/loki/values.yaml` (+1 other) (#12605)
  * fix: Remove Hardcoded Bucket Name from EventBridge Example CloudFormation Template (#12609)
  * feat: add toleration for bloom components (#12653)
  * docs: unhide compactor GRPC config (#12587)
  * feat: Enable log volume endpoint by default in helm (#12690)
  * test: Add new tests for Drain pattern matching (#12655)
  * operator: Add support for Swift TLS CA configuration (#11708)
  * chore(helm): various helm fixes (#12675)
  * perf: TSDB: Add fast-path to `inversePostingsForMatcher` (#12679)
  * feat: Add pattern ingester support in SSD mode (#12685)
  * fix: promtail race fixes (#12656)
  * fix: Use to the proper config names in warning messages (#12114)
  * fix: crrect initialization of a few slices (#12674)
  * chore(operator): Update skipRange for next OpenShift release (#12676)
  * ci: Fix promtail windows test github action (#12671)
  * docs: fix mal formed link (#12677)
  * chore(promtail): Update Promtail base image to Debian 12.5 (#12672)
  * fix: Fix the lokitool imports (#12673)
  * feat: add lokitool (#12166)
  * fix: Updated Loki Otlp Ingest Configuration (#12648)
  * fix(helm): Removed duplicate bucketNames from documentation and fixed key name `deploymentMode` (#12641)
  * chore: Update reads and reads resources dashs (#12654)
  * docs: add labels expressions to categories (#12607)
  * fix: Add a missing `continue` in fuse which may cause incorrect bloom test result (#12650)
  * docs: fix doc-validate errors due to config move (#12662)
  * feat: split detected fields queries (#12491)
  * docs: Add Promtail's `file_sd_configs` scrap_configs example (#11791)
  * fix: incorrect compactor matcher in loki-deletion dashboard mixin (#12567)
  * feat(blooms): record time spent resolving shards (#12636)
  * fix(blooms): Fix findGaps when ownership goes to MaxUInt64 and that is covered by existing meta (#12558)
  * chore: Restructure `indexgateway` component package (#12630)
  * ci: add a github action for linting jsonnet (#12527)
  * docs: add play link, correct errors to visualization instructions (#12604)
  * docs: correct typo on api param (#12631)
  * fix: fix setting of info log level when trying to detect level from log lines (#12635)
  * feat: Enable log volume endpoint by default (#12628)
  * docs: clarify upgrade behavior (#12578)
  * docs: hide the sizing calculator until updated (#12598)
  * fix: lambda-promtail, update s3 filename regex to allow finding of log files from AWS GovCloud regions (#12482)
  * docs: helm: Update monolithic guide. (#12591)
  * docs: Update publish-technical-documentation-next.yml (#12617)
  * test: Fix deadlock in table_manager relating to Stop/SyncTables (#12597)
  * docs: delete microservices reference (#12600)
  * fix(query sharding): Generalize avg -> sum/count sharding using existing binop mapper (#12599)
  * chore(operator): set release-as to avoid commit done in #12348 (#12596)
  * feat: add warnings to metadata context directly (#12579)
  * docs: add missing aliases for moved pages (#12580)
  * test: 2 data race fixes (#12584)
  * docs: Update 3.0 Release Notes (#12565)
  * docs(operator): improved docs to run using kind (#12576)
  * docs: Update CHANGELOG (#12564)
  * chore: helm: Add headless service to bloom-gateway (#12562)
  * feat: improve syntax parser for pattern (#12489)
  * chore(operator): correct branch name on release-please workflows (#12573)
  * docs: Refactor Loki configuration to be included via docs/shared (#12556)
  * ci: Update publishing workflows (#12543)
  * chore(operator): cleanup changelog for release-please (#12568)
  * chore(operator): adds the workflow for release-please (#12450)
  * chore: allow make docs to be run in container (#12563)
  * docs: update release notes for 2.9.7 (#12560)
  * chore(blooms): Remove noisy log line in index gateways (#12555)
  * docs: Rename API file to support publishing in GEL docs (#12493)
  * fix(operator): Bump golang builder to 1.21.9 (#12503)
  * chore: [main] chore(release-2.9.x): release 2.9.7 (#12553)
  * fix(operator): Configure Loki to use virtual-host-style URLs for S3 AWS endpoints (#12469)
  * fix(helm): only default bucket names when using minio (#12548)
  * docs: update page weights and menutitle (#12541)
  * docs: fix changelog (#12544)
  * docs: Correct release date for loki v3 (#12533)
  * ci: Revert "ci: create build image version with go 1.21.9 and golangci 1.51.2" (#12485)
  * docs: Update Release Notes page wweights (#12530)
  * fix: make the tsdb filenames correctly reproducible from the identifier (#12536)
  * docs: Minor fixes to zone-ingesters documentation (#10716)
  * docs: Fix up storage page front matter (#12532)
  * fix: close res body (#12444)
  * docs: Loki 3.0 Release Notes (#12508)
  * feat: include the stream we failed to create in the stream limit error message (#12437)
  * docs: remove whitespace in links (#12525)
  * ci: remove 3.0 release off main (#12522)
  * feat!: update helm chart to support distributed mode and 3.0 (#12067)
  * docs: proper fix for #12510 (#12516)
  * chore: [main] chore(release-3.0.x): release 3.0.0 (#12518)
  * docs: document service_name label in upgrade guide (#12517)
  * fix: loki version prefix in Makefile (#12514)
  * docs: Attempt to fix whatever broke the docs builds (#12510)
  * ci: remove previous attempt at workflow that's outdated (#12405)
  * docs: re-arrange upgrade guide (#12504)
* Thu Apr  4 2024 michal.hrusecky@opensuse.org
- Update to version 2.8.11+git.1711098663.aa89d817:
  * chore(deps): update module go.opentelemetry.io/contrib/instrumentation/net/http/otelhttp to v0.44.0 [security] (release-2.8.x) (#12000)
  * ci: add test-integration make target (#12280)
  * fix: update google.golang.org/protobuf to v1.33.0 (#12276)
  * ci: remove canary boringcrypto from 2.8.x (#12274)
  * ci: pin release to loki-2.8.x tag in loki-release (#12271)
* Tue Mar 19 2024 Michal Hrusecky <michal.hrusecky@opensuse.org>
- Enable journald parsing in promtail
- Small changes to _service file
  * change tarball compression method to xz
  * use "manual" service mode instead of "disabled"
* Tue Mar 19 2024 michal.hrusecky@opensuse.org
- Update to version 2.8.10+git.1709154536.536e9cd7:
  * chore(release-2.8.x): release 2.8.10 (#12076)
  * ci: fix version (#12085)
  * fix: image tag from env and pin release to v1.11.5 (#12073)
  * ci: revert release to using classic PAT (#12070)
  * ci: fix docker image names (#12062)
  * ci: bump release pipeline to 1.11.4 (#12060)
  * chore(release-2.8.x): release 2.8.9 (#12052)
  * ci: pin release to 1.11.2 (#12051)
  * chore: release 2.8.9 (#12043)
  * ci: pin release code to v1.11.0 (#12046)
  * ci: fix 2.8 release config again (#12042)
  * ci: allow release-please to accept manifest in config mode (#12040)
  * fix: bump alpine base image and go to fix CVEs (#12026)
  * chore: bring in new release automation to 2.8.x (#12014)
  * [release-2.8.x] fix(background cache): increment queue size exactly once (#11779)
  * Update patch versions in docs and YAML files to v2.8.8 (#11761)
  * Release loki v2.8.8 (#11707)
  * Update golang.org/x/crypto for v2.8.x (#11743)
  * [release-2.8.x] Cache: correctly check background cache size (#11655)
  * [release-2.8.x] Ruler: catering for another data race in tenant config (#11715)
  * [release-2.8.x] fix(log results cache): compose empty response based on the request (#11658)
  * [release-2.8.x] Ruler: protect overrides map with mutex when accessing tenant configs (#11602)
  * upgrade dependencies to fix CVEs (#11461)
  * Fixing links (#11401)
  * Fix broken Promtail link (#11327)
  * [release-2.8.x] fix: respect query matcher in ingester when getting label values (#10375) (#11057)
  * fix(deps): update github.com/grafana/loki digest to 7fa2f6e [security] (release-2.8.x) (#10823)
  * [release-2.8.x] add release notes for 2.8.6 (#10935)
  * [release-2.8.x] update changelog for v2.8.6 (#10930)
  * [release-2.8.x] update build image to use go1.20.10 (#10928)
  * chore(deps): update module golang.org/x/net to v0.17.0 [security] (release-2.8.x) (#10891)
  * [release-2.8.x] upgrade to go 1.20.10 (#10889)
  * [release-2.8.x] upgrade go-grpc to v1.56.3 (#10887)
  * [release-2.8.x] fix failing test  (#10890)
  * drone(docker-driver): Fetch tags before pushing image during release (#10670)
  * [Docs] Fix 404s/broken links in 2.8 branch (#10555)
  * Add 2.8.5 references (#10593)
  * Update alpine versions (#10573) (#10578)
  * Rewrite duplicate headings for SEO. (#10275)
  * Update GitHub URLs from master to main (#10289)
  * Update changelog and release notes for 2.8.4 (#10235)
  * Update changelog and release notes for 2.8.3 (#10234)
  * Backport security fixes 2.8 (#10217)
  * Backporting #9870 to latest (#10150)
  * Remove recommendation for Tanak installation. (#10075)
* Wed Jul 26 2023 ecsos@opensuse.org
- Update to version 2.8.3+git.1689949088.0d81144c:
  * Backport go 1.20.6 to 2.8 (#9944)
  * Docs : fix promtal typo (#9951) (#9965)
  * Remove ./tools/fetch-tags invocation from Makefile (#8854) (#9946)
  * [release-2.8.x] Adding 3 existing maintainers, and our newest one: Ashwanth! (#9744)
  * query-scheduler: fix query distribution in SSD mode (#9471) (#9637)
  * [release-2.8.x] Fix Ruler remote write panic (#9695)
  * [release-2.8.x] prepare changelog for 2.8 release (#8818)
  * [release-2.8.x] Fix duplicate label values from ingester streams (#9631)
  * [release-2.8.x] Querier: configurable writeback queue bytes size (#9605)
  * [release-2.8.x] docs: add memberlist section to the configuration page (#9453)
  * Promtail: Break on iterate journal failure (#9155) (#9403)
  * [release-2.8.x] Promtail: Prevent logging errors on normal shutdown (#9402)
  * Add missing release notes for 2.8.2 (#9389) (#9390)
* Wed Jul 26 2023 ecsos@opensuse.org
- Update to version 2.8.2+git.1683111662.9f809eda:
  * Pin manifest plugin version (#9381)
  * Revert "Bump dskit from 528d8a7 to 1725bcc (#9184) (#9250)" (#9382)
  * Add signature missing to drone pipeline (#9377)
  * Upgrade to latest security release: go1.20.4 (#9370) (#9375)
  * [release-2.8.x] Promtail: Add `decompression` configuration (#9350)
  * Bump dskit from 528d8a7 to 1725bcc (#9184) (#9250)
  * [release-2.8.x] Mark template as draft to unpublish. (#9286)
  * Finalize 2.8.1 changelog and release notes (#9269)
* Wed Jul 26 2023 ecsos@opensuse.org
- Update to version 2.8.1+git.1682367724.dd763dcf:
  * [release-2.8.x] Upgrade alpine 3.16.4 -> 3.16.5 (#9268)
  * Update CHANGELOG and release notes (#9241)
  * [release-2.8.x] Prevent redis client from incorrectly choosing cluster mode with local address (#9187)
  * [release-2.8.x] Update helm and jsonnet for 2.8 release (#9003) (#9145)
  * [release-2.8.x] expiration: do not drop index if period is a zero value (#9158)
  * [release-2.8.x] Bump go from 1.20.1 -> 1.20.3 (#9106) (#9116)
  * [release-2.8.x] Add journald support to Promtail amd64 binary builds (#9104)
  * Fix CHANGELOG link (#9054)
  * [release-2.8.x] These features did not make the release (#9043)
  * [release-2.8.x] add 2.8 release date (#9017)
  * [release-2.8.x] Add 2.8 release notes (#9014)
  * [release-2.8.x] Align common instance_addr with memberlist advertise_addr (#9006)
* Wed Apr 12 2023 ecsos@opensuse.org
- Update to version 2.8.0+git.1680557182.90888a0c:
  * [release-2.8.x] Change loki version in docs for 2.8 release (#8985) (#9000)
  * [release-2.8.x] index-gateway: fix failure in initializing index gateway when boltdb-shipper is not being used (#8997)
  * [release-2.8.x] Adding release cadence docs (#8980)
  * [release-2.8.x] Fix fetched chunk from store size in metric (#8974)
  * [release-2.8.x] Expose optional label matcher for label values handler (#8824) (#8960)
  * [release-2.8.x] (chore): remove incorrect cache config preample (#8865)
  * [release-2.8.x] Revert query optimizations (#8862)
  * [release-2.8.x] json parser: fix panic when processing empty line (#8839)
  * [release-2.8.x] fix to-string for noop label filters (#8801)
  * Revert "Implement hierarchical queues for query scheduler (#8691)" (#8794)
  * Impose per-request limit on label queries. (#8777)
  * Loki: Add new logql template functions `bytes`, `duration`, `unixEpochMillis`, `unixEpochNanos`, `toDateInZone`, `b64Enc`, and `b64Dec` (#8774)
  * Loki: add lines processed to metrics.go (#8764)
  * Loki: remove `subqueries` from metrics.go logging and replace it with separate split and shard counters (#8761)
  * Remove print statements introduced by #8727. (#8775)
  * Loki: Change the behavior of the 0 value for retention_period to disable retention. (#8753)
  * Changes from linter (#8769)
  * Expand `which-release.sh` to cover weekly builds as well (#8768)
  * Add initial implementation of per-query limits (#8727)
  * Fix distributor latency panel (#8760)
  * Modify debug loki build to work on any architecture, including ARM (#8758)
  * Change severity of PromtailFileMissing alert to warning (#8757)
  * Use changed metric in operational dashboard (#8749)
  * Reimplement Unpack in terms of jsonparser rather than jsoniter (#8739)
  * Reimplement JsonExpressionParser in terms of jsonparser  (#8734)
  * Implement hierarchical queues for query scheduler (#8691)
  * deletion: fix issue in processing delete requests with tsdb index (#8665)
  * operator: Bump golang.org/x/net from 0.0.0-20220722155237-a158d28d115b to 0.7.0 (#8726)
  * Loki-Mixin: Remove query-readiness panel (#8735)
  * Fixing broken link (404) (#8688)
  * Tools: add tool to determine which release (if any) a commit appears in (#8706)
  * Promtail: Stop ticker to avoid leaking (#8695)
  * operator: Fix gateway's nodeSelector and tolerations (#8707)
  * Update retention_support.md (#8342)
  * Make Loki Overrides public. (#8696)
  * Use Line Filters in StringLabelFilter (#8659)
  * Loki: Stop running tickers on deletes (#8697)
  * Allow passing of context to query related limits functions (#8689)
  * doc(best-practices): Update default value of `max_chunk_age`. (#8685)
  * Loki Getting Started: Fix example query that was not working (#8668)
  * Querier/Ruler: add histogram to track fetched chunk size distribution (#8682)
  * WAL: store pointers in record pool (#8667)
  * Optimize .+ regex line filter (#8646)
  * operator: Fix version inconsistency in generated OpenShift bundle (#8666)
  * Clean up scheduler code to prepare upcoming changes (#8643)
  * Optimize Promtail wal writer to batch both series and entries record (#8489)
  * [CI/CD] Update yaml file `./production/helm/loki/values.yaml` (+1 other) (#8655)
  * LID: Improve scheduler to control QoS across users within a tenant (#8585)
  * S3: add support for s3 session token (#8474)
  * Ruler: do not keep appending logger keys (#8650)
  * Update CHANGELOG.md (#8633)
  * [logcli] set default instead of error for parallel-max-workers validation (#8641)
  * added missed binaries required to run `./tools/image-tag` script (#8640)
  * Fixing broken link and removing out of date blog post. (#8632)
  * Loki cloud integration instructions (and necessary mixin changes) (#8492)
  * Helm: fix enterprise-logs license secret name (#8498)
  * Helm chart auto update (#8331)
  * Helm: update changelog CI comment (#8603)
  * Helm: update changelog with changes from PR #8467 (#8601)
  * Bump golang.org/x/net from 0.4.0 to 0.7.0 in /pkg/push (#8562)
  * Bump golang.org/x/net from 0.5.0 to 0.7.0 (#8563)
  * production: Add missing string formatter token to nginx.conf config map (#8580)
  * Update prometheus/prometheus from 2.41 to 2.42 (#8571)
  * chore: Fix typos in Helm documentation (#8593)
  * chore: Cleanup label extraction expression (#8596)
  * Iterators: re-implement entrySortIterator using loserTree for performance (#8351)
  * Define Container for Codespaces (#8561)
  * Helm enterprise-logs: update kubernetes secrets creation (#8467)
  * Use 0.28.1 build image and update go and alpine versions (#8583)
  * Bump golang.org/x/text from 0.3.7 to 0.3.8 in /operator (#8597)
  * Clean up CHANGELOG (#8595)
  * operator: Refactor status update to reduce API calls (#8578)
  * operator: Store gateway tenant information in secret instead of configmap (#8577)
  * Revert "Loki: Fix memchunk headblock filter" (#8594)
  * Add logfmt selective label extraction (#6675)
  * Loki: Fix memchunk headblock filter (#8591)
  * operator: Remove deprecated field querier.engine.timeout (#8579)
  * Fix ruler deadlock (#8486)
  * Use golangci-lint v1.51.2 in build image (#8587)
  * [RFR] fix vector() function produces wrong timestamp on instant query (#8370)
  * feature: geoip stage in promtail (#3493)
  * Update build image to go 1 20 1 and alpine 3 16 4 (#8575)
  * Lambda-promtail: Add support for processing SQS messages, add promtailClient Type, add logger, upgrade dependencies and fix unexpected flushing behaviors (#8231)
  * Promtail: Add ready endoint to loki-push-api server (#8552)
  * helm: make multi tenant easy: use tenant id from nginx $remote_user (#8404)
  * Replace deprecated inet.af/netaddr (#8560)
  * lambda-promtail: Various Terraform fixes (#8549)
  * Bump golang.org/x/net from 0.5.0 to 0.7.0 in /tools/lambda-promtail (#8556)
  * fix(promtail): Make `cri` tags streams aware. (#8497)
  * Document memcached configuration for caching. (#8373)
  * Fix logcli parallel download deadlock. (#8553)
  * S3 Storage Class Configuration (#8532)
  * lambda-promtail: Add option to omit extra labels prefix `__extra_` (#8548)
  * Fix regression in lambda-promtail tool that yields incorrect label names (#8547)
  * logcli: Add parallel flags (#8518)
  * Fixed XSS on LogQL Analyzer page (#8521)
  * Fetch all entries with logcli if limit==0. (#8537)
  * operator: Update Promtail and LogCLI addons to v2.7.3 (#8536)
  * fix panics when cloning a special query (#8531)
  * operator: Provide community operator bundle (#7308)
  * Fix missing braces for service stanza (#8510)
  * Helm: Remove unreleased setting from Helm chart configuration file (#8515)
  * operator: update assume-no-moving-gc to fix go 1.20 (#8507)
  * helm: azure config: don't set use_federated_token if false (#8513)
  * DynamoDB: Accept a KMS key for DynamoDB tables (#8469)
  * Temporarily unpublish Analyzer page. (#8503)
  * Helm: add sleep argument to helm makefile on local development (#8502)
  * helm: values to override read/write/backend paths in gateway config (#8490)
  * Loki Documentation: corrected config example for loki.storage (#8277)
  * correctly calculate max shards (#8494)
  * Helm: add debug option to helm command for verbose output on local development (#8479)
  * Loki: set a maximum number of shards for "limited" queries instead of fixed number (#8487)
  * Loki: Process "Limited" queries sequentially and not in parallel (#8482)
  * [new] chunk backend: Integrate Alibaba Cloud oss (#8410)
  * Updated CONTRIBUTING file for docs. (#8431)
  * [helm] Fix read-only /tmp in 3 targets mode (#8477)
  * [helm] Bump to Loki 2.7.3 (#8445)
  * Swift: Allow to configure swift with the internal endpoint (#8438)
  * More precise sharding logic for `on|ignoring` (#8461)
  * Fix parsing of vector expression (#8448)
  * logs sharding astmapperware to spans in addition to logs (#8457)
  * [helm] set compactor address (#8427)
  * add section to prom operator instructions about necessary label (#8379)
  * Put instance_addr in proper place in loki-local-config (#6106) (#8364)
  * Usage stats reporter: fix to remove duplicate if block (#8392)
  * [Helm] Allow to configure publishNotReadyAddresses on memberlist service (#8446)
  * Improve installation instructions (#8454)
  * Helm: Add podlabels to backend (#8398)
  * Fix namespace rendering in provisioner job (#8449)
  * Correct sizing tool unit in help text. (#8441)
  * Fix reading logs from remote Docker daemon with TLS (#6909)
  * [jsonnet] fix import ordering in loki.libsonnet (#8442)
  * Promtail: Add event log message stage (#8382)
  * Fix flaky `TestMicroServicesDeleteRequest` integration test (#8436)
  * Fix broken cross-reference in Helm installation. (#8430)
  * Update publishing workflows to use organization secret (#8435)
  * Add OVHcloud to sizing tool (#8423)
  * Fix numbering issue in second procedure. (#8429)
  * operator: Add missing release section into the changelog (#8412)
  * Promtail WAL support: Implement writer side (#8267)
  * Bump version of `fluent-plugin-grafana-loki` to 1.2.20 (#8426)
  * operator: Bump bundle OCP max version property to 4.15 (#8411)
  * [helm] Single binary object storage (#8284)
  * Update fluent-plugin-grafana-loki to Ruby 3.2 (#8421)
  * Skip image validation (#8425)
  * operator: Update operand Loki to v2.7.3 (#8397)
  * LogQL: [optimization] syntax: Replace "panic" in "/pkg/logql/syntax" with "error" (#7208)
  * [LogCLI] Load tenant-specific schema config file when using `--remote-schema` (#8413)
  * Fix open "/tmp/*" the system cannot find the path specified on windows (#8170)
  * Use portable output redirection (#8417)
  * Bump docker/build-push-action from 2 to 4 (#8416)
  * Bump google.golang.org/api from 0.108.0 to 0.109.0 (#8395)
  * Upstream additional multi-zone ingester jsonnet  (#8360)
  * docs(monitor-and-alert): Fix typo in ServiceMonitor spelling (#7693)
  * [Mixin] Update clusterlabel usage (#8247)
  * Jsonnet: Allows gateway tenant ID to be configured (#7624)
  * Re-stablish tailing websocket connection if it's closed unexpectedly. (#8374)
  * Fix the ruler alertmanager_client documentation (#7474)
  * Promtail: Add custom headers on push requests (#7470) (#7472)
  * feat(promtail): add more complex options of dropping logs at the drop stage (#6371)
  * Bump github.com/fatih/color from 1.13.0 to 1.14.1 (#8385)
  * Fix comparison in a delete request integration test (#8389)
  * Add table of Loki versions in helm chart (#8383)
  * Pin windows build Go version (#8387)
  * Update GEL plugin in k3d env to latest (#8378)
  * Snyk Workflow add (#8375)
  * Reflect release 2.7.3 on main branch (#8372)
  * Loki: Add the ability to wait on SIGTERM before shutting down (#8371)
  * Clarify query performance in sizing tool. (#8327)
  * Bump github.com/bmatcuk/doublestar from 1.2.2 to 1.3.4 (#8368)
  * chore: Vendor `runtimeconfig` package patch (#8366)
  * Cosmetic lint warning fixes (#8363)
  * operator: Cleanup ruler resources when disabled (#8308)
  * Helm: Align ingress timeout and size limits. (#8352)
  * Display Memory request in sizing tool. (#8326)
  * Sizing tool: Display units. (#8333)
  * Docs: Improve/update examples page (#8338)
  * Bump github.com/go-logfmt/logfmt from 0.5.1 to 0.6.0 (#8350)
  * Bump cloud.google.com/go/pubsub from 1.27.1 to 1.28.0 (#8349)
  * Sizing Tool: Set the minimum replias to 3. (#8329)
  * Update index metrics (#8316)
  * fix dashboard helper to use regex (#8319)
  * Re-license and export `pkg/ingester` WAL code to be used in Promtail's WAL (#8315)
  * Ensure a delete request interval of at least a second (#8340)
  * operator: Update operand Loki to v2.7.2 (#8336)
  * Only report test coverage when it changes (#8339)
  * Zone aware ingesters (#7923)
  * Loki: only log "executing query" once per query in the frontend (#8337)
  * deletion: fix log deletion with line filters (#8151)
  * Bump google.golang.org/grpc from 1.52.0 to 1.52.3 (#8335)
  * Bump github.com/drone/envsubst from 1.0.2 to 1.0.3 (#8334)
  * Bump golangci/golangci-lint-action from 3.3.1 to 3.4.0 (#8332)
  * Use organization ISSUE_COMMANDS_TOKEN with reduced scope (#8325)
  * Helm Chart release automation (step 1) (#8323)
  * update helm for GEL 1.6.1 (#8304)
  * [chore] update pkg/push version (#8312)
  * Bump github.com/cristalhq/hedgedhttp from 0.7.0 to 0.7.2 (#8310)
  * Bump github.com/Azure/go-autorest/autorest/azure/auth from 0.5.11 to 0.5.12 (#8309)
  * Reduce distributor code duplication (#8293)
  * LID: Remote Rule Evaluation (#8129)
  * Loki: add apache2 license to newly refactored push module (#8305)
  * Logproto: Extract push.proto from logproto package to the separate module (#8259)
  * Reflect release 2.7.2 on main branch (#8299)
  * retry+backoff querier->qf response (#8285)
  * [helm] Fix helm dashboards (#8261)
  * Bump github.com/felixge/fgprof from 0.9.2 to 0.9.3 (#8289)
  * Bump github.com/aws/aws-sdk-go from 1.44.156 to 1.44.187 (#8288)
  * Update Prometheus to v2.41, plus dependencies (#8290)
  * Ruler: implement rule-based and shuffle sharding (#8092)
  * Retry getting logs from pubsub forever (#8283)
  * Use Loki build image 0.27.1 in CI (#8279)
  * Helm: ensure valid label values when version has digest (#8260)
  * Fix pubsub pull target (#8281)
  * Update golang to 1.19.5 (#8278)
  * Loki: Fix version info issue that shows wrong version (#7669, #8055) (#8232)
  * logql: Support `urlencode` and `urldecode` template functions (#8271)
  * Test docs build on PRs (#8274)
  * Bump google.golang.org/api from 0.102.0 to 0.108.0 (#8275)
  * promtail: Add `max-line-size-truncate` (#8233)
  * Bump cloud.google.com/go/storage from 1.27.0 to 1.29.0 (#8276)
  * Corrected typo (#8237)
  * operator: Add watch on the Alertmanager in openshift-monitoring and decouple it from the user-workload AM (#8253)
  * operator: Use gRPC instead of http for compactor communications (#8265)
  * Helm: Default grafana dashboard label (#8188)
  * Helm: Generalize enableStatefulSetAutoDeletePVC (#8193)
  * fix remaining docs issues (#8263)
  * [helm] add local k3d loki cluster (#8218)
  * logs more metadata when failing to recover head from WAL in TSDB (#8250)
  * enable responsive table (#7890)
  * Make secret job fail when not logged in (#8215)
  * Helm: Add selector to backend's volumeClaimTemplates (#8235)
  * fixed logql-analyzer (#8258)
  * Bump github.com/baidubce/bce-sdk-go from 0.9.111 to 0.9.141 (#8255)
  * Setting Julie Stickler as codeowner for docs (#8257)
  * index-store: fix indexing of chunks overlapping multiple schemas (#8251)
  * Only print logger error when required (#8256)
  * tsdb docs first pass (#8048)
  * Change tests to bump sarama dependency (#8249)
  * [Docs] Adding context to Istio installation. (#8248)
  * Benchmark_store_SelectSample: stop accumulating results (#8242)
  * Enalbe multi tenant queries on Helm test chart. (#8228)
  * Helm: Add initContainers to write, backend, singleBinary templates (#8236)
  * stores/series: always return entries to pool (#8245)
  * Loki: Log hashed queries emitted by `metrics.go` (#8244)
  * Do not exit when using `stream_lag_labels` setting (#8243)
  * Match version flag using regex (#8241)
  * Fix documentation linter errors (#8229)
  * Docker compose: Update loki and promtail version tags to 2.7.1 (#8230)
  * Remove dependency on thanos-io/thanos (#8227)
  * Loki: Remove validation of matchers when performing label values lookup. (#8224)
  * [loki-canary] Support passing loki address as environment variable (#8205)
  * distributor: Fix `loki_mutated_bytes_total` metric increment (#8223)
  * Bump github.com/mitchellh/go-wordwrap from 1.0.0 to 1.0.1 (#8222)
  * ingester: Add `ingester_memory_streams_labels_bytes` metric (#8212)
  * Update doc-validator to latest release (#8221)
  * Docs fix: add missing sections on index.template file (#8216)
  * place canary docs in their own package and fix links+description (#8217)
  * Remove template alias from Helm chart reference (#8213)
  * updating troubleshooting and upgrade changelog (#8206)
  * Removing duplicated limits file and refactored references (#8210)
  * Bump github.com/heroku/x from 0.0.50 to 0.0.55 (#8209)
  * Use latest release of doc-validator image (#8211)
  * Docs: Add doc-validator tool to lint technical documentation (#6569)
  * promtail: Add doc for `max-line-size` flag. (#8202)
  * promtail: Fix title and image path on `logrotation` doc (#8208)
  * Helm - Loki: Introduce runtimeConfig (#8179)
  * Helm: Fix components notes (#8194)
  * [docs] Clarify for what version the Helm chart docs are applicable (#8172)
  * Helm: Add ingester config in helm values (#7733)
  * Helm chart: Add enableServiceLinks (#7129)
  * Remove the stream lag metric. (#6324)
  * Revert "fix(logql): remove __error_details__ label on drop __error__ or other way around" (#8200)
  * doc(promtail): Doc about how log rotate works with promtail. (#8096)
  * Helm: Add Table Manager support to Loki helm chart (#8098)
  * [helm] Fix self-monitoring tenant secret (#8198)
  * support single & double hyphen arguments in version printing (#8199)
  * [docs] fix dead link in the docker client documentation (#8196)
  * fix(logql): remove __error_details__ label on drop __error__ or other way around (#8150)
  * Bump github.com/spf13/afero from 1.9.2 to 1.9.3 (#8191)
  * Do not run release stage when check stage fails (#8175)
  * operator: Add watch on the Alertmanager in OCP's user-workload-monitoring namespace (#8038)
  * limits: add tenant to log lines for per-stream rate-limited and out-of-order errors (#8177)
  * Display replicas, cores and nodes in sizing tool. (#8088)
  * fix broken drone image for arm builds (#8186)
  * operator: Remove custom webhook cert mounts for OLM-based deployment (#8173)
  * [helm] allow provisioned tokens to be created in different namespaces (#8081)
  * Revert "[loki-canary] Support passing loki address as environment variable (#8024)" (#8183)
  * Alerts: Exclude '/schedulerpb.SchedulerForQuerier/QuerierLoop' route in LokiRequestLatency alert (#8138)
  * Bump github.com/imdario/mergo from 0.3.12 to 0.3.13 (#8176)
  * Minor LID fixes (#8167)
  * promtail: Add `max-line-size` limit to drop on client side  (#8153)
  * doc(distributor): Clarify `distributor.max-line-size` flag. (#8165)
  * Removing "replace" directive for line-buffered logger (#8162)
  * Bump golang.org/x/time from 0.1.0 to 0.3.0 (#8161)
  * Emit help message when check-mod fails (#8157)
  * Bump github.com/Masterminds/sprig/v3 from 3.2.2 to 3.2.3 (#8159)
  * Fix link to CONTRIUTING.md in PR template (#8156)
  * Update vendored dskit (#8155)
  * lambda-promtail-: fix parse kinesis timestamp (#7158)
  * fixes bug with queryIngesterWithin logic in asyncStore ingester stats… (#8145)
  * run 'make doc' and commit the changes (#8142)
  * Update README.md (#7799)
  * Helm: Use image tag for version labels in kubernetes resources (#8135)
  * operator: Fix docs for OpenShift Data Foundation storage uses bucketnames instead of bucketname (#8139)
  * Documentation: Add installation instructions for Istio (#4812)
  * Move to fork github.com/grafana/cloudflare-go (#8133)
  * Bump github.com/prometheus/common from 0.38.0 to 0.39.0 (#8134)
  * lambda-promtail: remove duplicate key in terraform config sample (#8137)
  * [jsonnet] port some common jsonnet for statefulset and ingester creation (#7039)
  * Loki: Add support for Azure Workload Identity authentication (#7540)
  * resolves #5950 (input header error) (#7829)
  * Docs: fix helm ssd typo (#7959)
  * skip compacting tables that do not fit in start and end date of desired schema config (#8127)
  * Cross build Promtail for ARM with journald support. (#8131)
  * Fix labels for alerts (#7886)
  * Update README.md (#8132)
  * Fix logentry drop to more intuitively match numeric fields (fixes #7011) (#7292)
  * Fixing test regression (#8130)
  * Correct template and LID (#8128)
  * Improve the JSON parser performance. (#7723)
  * helm: Add `appProtocol: tcp` to headless grpc ports (#7990)
  * Helm: fix ruler config storage regression (#8071)
  * chore(go.mod): Remove unnecessary grpc contraints from `weaveworks/common` (#8125)
  * Go mod tidy (#8126)
  * helm: fix autoscaling/v2 template (#8043)
  * feat(logql): Support drop labels in logql pipeline (#7975)
  * Promtail: Improve LabelsMap CPU performance (#7882)
  * Bump helm/kind-action from 1.4.0 to 1.5.0 (#7970)
  * update local docker-compose file to provision the Loki data source (#7869)
  * Minor fixups to LIDs (#8124)
  * Helm: Add missing azure check (#8113)
  * Loki Improvement Documents (LIDs) (#8056)
  * Remove flaky helm test (#8122)
  * operator: Add API validation to Alertmanager header auth config (#8001)
  * Bump go modules GitHub.com prometheus alertmanager 0.25.0 (#8100)
  * operator: Fix docs minio storage uses bucketnames instead of bucketname (#8116)
  * Remove public key used for signing helm charts as we are removing chart signing (#8104)
  * Bump github.com/alicebob/miniredis/v2 from 2.22.0 to 2.30.0 (#8119)
  * scheduler: fix panic on hitting /scheduler/ring when ring is disabled (#8120)
  * Bump golangci/golangci-lint-action from 3.2.0 to 3.3.1 (#7689)
  * Install build dependencies to cross build promtail. (#8111)
  * Bump actions/checkout from 3.1.0 to 3.3.0 (#8070)
  * Enhance sizing tool documentation. (#8079)
  * Add toggle for persistence disk in single-binary mode (#7778)
  * Promtail Docs: Clarifiy labels and timestamps set by cri stage (#7521)
  * Add dependabot.yml to ignore ieproxy dependency version (#7643)
  * Fix json stage fields in example (#7654)
  * Fixed a typo and made a small edit to the Helm monolithic setup doc.  (#8109)
  * [helm] add third scalable target `backend` (#7920)
  * lambda-promtail: Add support for VPC flow Logs to lambda-promtail (#7868)
  * Change delimiter in  test  "sed" command to ':' (#8108)
  * [helm] fix race between minio bucket job and enterprise tokengen job (#8064)
  * Promtail: Add configuration to drop batches when rate limited by Loki (#7973)
  * Update publishing workflows to use PATs with fine-grained access control (#8062)
  * operator: Fix status not updating when state of pods changes (#8087)
  * Add drone env vars to test output to distinguish the 2 unit test runs. (#8093)
  * Helm: Remove signing of helm charts (#8099)
  * Bump github.com/prometheus/exporter-toolkit from 0.7.1 to 0.7.3 in /operator (#8089)
  * Promtail: Remove noisy error message when cleaning up filesystem watches which are already removed. (#8086)
  * Lambda-promtail: Add skip tls verify option (#8059)
  * Use GiB and bytes for sizing tool. (#8078)
  * Fixed typo in Helm values docs (#8075)
  * Add config for optional pod labels (#7594)
  * [Helm] Add the ability to add extraObjects (#8004)
  * Helm: add support for memcached client addresses (#7995)
  * [Docs] Remove outdated canary logo (#8035)
  * Bump golang.org/x/oauth2 from 0.1.0 to 0.4.0 (#8045)
  * Add stream sharding docs (#7901)
  * [helm] Add a flag to enable/disable persistentVolumeClaimRetentionPolicy feature (#7640)
  * Add docker-driver pipeline (#8083)
  * Use new build image everywhere (#8063)
  * Helm: Fix loki helm chart podLog relabelings template nindent (#8080)
  * config_wrapper: Add support for named stores (#7946)
  * ksonnet/loki: Hide keys that reference loki image (#6633)
  * Add loki-operator multi-arch image manifest (#8073)
  * [DOC] Fix broken links in docs (#8065)
  * chore: fix drone drift (#8072)
  * operator: Use lokistack-gateway replicas from size table (#8068)
  * dashboards: add k8s resource requests to CPU and memory panels (#8047)
  * chore(ci): Remove CircleCI (#8061)
  * Avoid failing tests on gRPC server shutdown errors (#8060)
  * [loki-canary] Fix changelog (#8052)
  * Loki: add a 'since' query parameter for easier querying using relative time (#7964)
  * Add empty k3d cluster for testing helm chart (#7984)
  * [loki-canary] Support passing loki address as environment variable (#8024)
  * [Helm] Add the ability to specify container lifecycle (#8010)
  * Docs: Fix promtail installation doc (#8007)
  * Docs: Removed unnecessary s3 value from example (#8017)
  * Fix Issue 6929 - Duplicate log lines querying Loki (#8019)
  * Fix chunks-inspect reports zstd compressed chunks as lz4-256k (#8028)
  * fix(logql): fix caseinsensitive search in filter (#8037)
  * Helm: Use stable autoscaling/v2 if possible (#7416)
  * [new feature] logql:support sort and sort_desc (#7989)
  * fix bugs in logs results caching and its tests (#7925)
  * Update build image and use in drone yaml (#8029)
  * Improve comments on sample timestamp validation errors (#8018)
  * Use gotestsum to run unit tests (#8022)
  * Shut down query frontend gracefully (#7978)
  * chore(promtail): Make `batchwait` and `batchsize` config explicit with yaml tags. (#8027)
  * make query-frontend service grpc lb friendly (#8025)
  * updated versions to the latest release v2.7.1 (#7940)
  * Update log queries regex documentation (#8002)
  * Add count to template functions (#7951)
  * store: write overlapping chunks to multiple stores (#7988)
  * Fix various linter errors
  * fix(promtail): Fix cri tags extra new lines. (#7997)
  * Revert "Update Ingester Rate Calculations (#7652)" (#7991)
  * Add missing period_config root block to doc generator (#7981)
  * Add README file to doc-generator tool (#7983)
  * Add store & cache download statistics (#7982)
  * Fix links to configuration page (#7164)
  * operator: Configure Alertmanager per-tenant (#7839)
  * fix query-frontend request load balancing when using k8s service (#7966)
  * Fix typo (#7956)
  * Fix min and max aggregations when using instant queries. (#7957)
  * fix error helm install monolithic path (#7948)
  * Show help tooltip on hover in sizing tool. (#7919)
  * Fix validation for pattern and rexexp parsers to they don't panic in query-frontend (#7926)
  * [helm] control order provisioner and tokengen jobs run in (#7939)
  * Add CI step to check generated documentation to check pipeline (#7938)
  * Deprecate CLI flag -ruler.wal-cleaer.period in favor of CLI flag -ruler.wal-cleaner.period (#7937)
  * feat(logql): Supporting prettifying LogQL expressions (#7906)
  * Flush buffered logger on exit. (#7924)
  * Move to fork github.com/grafana/gomemcache (#7936)
  * Move to fork github.com/grafana/tail (#7931)
  * Fix documentation typos from #7916 (#7934)
  * Add configuration documentation generation tool (#7916)
  * doc(api): Default value for `delete_ring_tokens` on `/ingester/shutdown` endpoint (#7921)
  * Helm: Decouple the Canary from self-monitoring (#7757)
  * [Jsonnet] Fix memberlist when using a stateful ruler (#6662)
  * Add 3rd target (`backend`) to SSD/Scalable mode (#7650)
  * Remove duplicate sizing tool (#7917)
  * Fix sizing tool. (#7899)
  * Bump azure/setup-helm from 1 to 3 (#7608)
  * Fix typo in helm install monolithic docs (#7909)
  * Update dskit to latest commit
  * operator: Update Loki operand to v2.7.1 (#7910)
  * promtail: ratelimiting by label (#7597)
  * Prepare changelog and release notes for 2.7.1 (#7895)
  * Introduce sizing tool to documentation page. (#7830)
  * build(deps): bump golang.org/x/crypto from 0.1.0 to 0.4.0 (#7883)
  * consider range and offset in queries while looking for schema config for query sharding (#7880)
  * [helm] Release 3.6.1 to reintroduce PrometheusRule alerts (#7873)
  * build(deps): bump cloud.google.com/go/bigtable from 1.3.0 to 1.18.1 (#7850)
  * Promtail: Fix broken promtail-debug docker image (#7852)
  * fix small typo (#7874)
  * Fixing a typo in configuration.md (#7878)
  * Update v2-7.md (#7857)
  * Fix broken canary loki alerts (#7860)
  * Fix alertmanager per tenant override config behavior (#7805)
  * Loki: Add one additional bucket to `rate_store_stream_shards` (#7856)
  * Update Prometheus dependency to latest release (v2.40.4) (#7826)
  * rerun make drone so the newest build image is used (#7849)
  * Update build image references to 0.25.0 (#7848)
  * loki-build-image: update faillint (#7841)
  * Revert "Make some stream shard metrics per-tenant (#7838)" (#7842)
  * [helm] Bump helm Loki and GEL version (#7760)
  * Make some stream shard metrics per-tenant (#7838)
  * Log query string on retry alongside the error (#7834)
  * fix(memcached): use `default` branch avoid writing to closed chan (#7833)
  * guard against divide by 0 when splitting parallelism (#7831)
  * Loki: Modified heroku drain target to make any url query parameters available as labels (#7619)
  * Improve ratestore performance (#7810)
  * [bugfix] scheduler: Gracefully shutdown querier when using query-scheduler (#7735)
  * fix(memcached): panic on `send on closed channel`. (#7817)
  * Better error message for empty selector queries (#6936)
  * operator: Apply delete client changes for compat with release-2.7.x (#7815)
  * [Helm] Remove unused value and set default values explicitly (#7576)
  * fix lint issues from PR 7804 (#7814)
  * [Helm] Add support for azure blob storage (#7500)
  * use grpc for communicating with compactor for query time filtering of data requested for deletion (#7804)
  * promtail: Handle nil error on target Details() call (#7771)
  * loki-canary: respect `useTLS` flag when `push` mode is enabled. (#7701)
  * operator: Fix alert unit tests (#7812)
  * Remove hardwired '127.0.0.1' values in default addresses (#7784)
  * operator: Fix histogram-based alerting rules (#7809)
  * operator: Replace fifocache usage by embedded_cache (#7808)
  * Loki: Add new sharding metrics (histogram based) (#7762)
  * Provide Terraform script for setting up S3 and document role based access. (#7656)
  * [performance] metrics query: range vector support streaming agg when no overlap (#7380)
  * fluent-bit: Update the Fluent Bit plugin README with correct golang minimum version (#7302)
  * operator: Check for mandatory CA configmap name in ObjectStorageTLS spec (#7753)
  * helm/loki: Allow to override default loki `target` (#7791)
  * Log rule changes through API. (#7790)
  * Docs - Move PR's in CHANGELOG.md that weren't actually implemented in 2.7.x (#7690)
  * fifocache config is deprecated. use embedded-cache instead (#7800)
  * Update Ingester Rate Calculations (#7652)
  * docs(embedded-cache): config uses embedded_cache (#7797)
  * Completing step 2 of updating loki-build-image (#7796)
  * Improvements to loki-build-image build & release process (#7795)
  * Update delve version to be compatible with Go 1.19 (#7793)
  * [Docs] Typo: Fix build path of promtail binary (#7776)
  * [Docs] Fix helm loki examples links (#7779)
  * Promtail: Add tenant label to client drop metrics and logs (#7593)
  * Querier/Ruler: query blocker (#7785)
  * [docs] removed static URL to LogQL Analyzer API (#7773)
  * Add closing code block backticks (#7772)
  * Split parallelism across Period Configs (#7769)
  * chore(tools): Update promtail image version (#7770)
  * operator: Fix docs AWS storage uses bucketnames (#7767)
  * Loki: Fix multitenant querying (#7708)
  * [CI/CD] fixed step `deploy` (#7715)
  * [helm] Fix incorrect ingress paths when using single binary deployment (#7530)
  * Return error on JSON serialization error. (#7745)
  * Fix label selector for gateway service in operational dashboard
  * Update release instructions (#7663)
  * Only release Helm Chart when version changed. (#7747)
  * config: Improve error message loading config with ENV variables. (#7759)
  * [loki-mixin] Make "Success Rate" panels in operational dashboard more accurate (#7756)
  * Only check mixin on file changes. (#7755)
  * fix logs deletion integration test to properly validate deleted data (#7751)
  * operator: Move Loki TLS configuration into ConfigMap (#7738)
  * Improve error logs query in operational dashboard
  * Examples: Add healthckecks in docker example (#7731)
  * [helm] Fix read-only /tmp in single-binary mode (#7695)
  * Refactor nix to make it easier to import into other projects (#7635)
  * helm/loki: Remove extra `/` if `registry` or `repository` is empty (#7746)
  * operator: Fix object storage TLS spec CAKey descriptor (#7744)
  * helm/loki: Allow to provide selector for Loki persistence volume (#7743)
  * operator: Fix handling of Request requeues (#7740)
  * Correct Helm documentation aliases. (#7537)
  * Make the `test` stage depend on `check-generated-files`
  * Remove redundant replaces from go.mod (#7697)
  * Just remove some spaces (#7681)
  * fix bugs in processing delete requests with line filters and add proper tests (#7720)
  * Serialize query JSON response in a stream. (#7721)
  * operator: Fix api doc generation (#7718)
  * operator: Migrate API docs generation tool (#7716)
  * operator: Fix LokiStackController watches for cluster-scoped resources (#7710)
  * operator: Refactor proxy env variables (#7682)
  * docs(v2.7.0): Minor tweaks on 2.7 release notes (#7672)
  * operator: Remove default value from replicationFactor field (#7711)
  * operator: Fix broken links in README.md (#7702)
  * docs(embedded-cache): Add missing docs on config page. (#7684)
  * operator: Add provision for the user to set proxy env variables in the loki pods (#7384)
  * Docs: Fix typo in helm scalable installation documentation, object storage section (#7676)
  * docs/upgrading: Add a note about windows event log fix (#7668)
  * Add 2.7 release notes (#7661)
  * Add config changes to upgrade guide (#7662)
  * Loki: Add querier config to loki helm (#7627)
  * Promtail: Exclude event message (#7462)
  * [helm] Ignore single binary headless service from service-monitor (#7638)
  * Promtail docs: Fix docker stage code example (#7653)
  * operator: Modify ingestionRate for respective shirt size (#7617)
  * adds Dropbox to the adopters list (#7651)
  * Bump github.com/pierrec/lz4/v4 from 4.1.12 to 4.1.17 (#7628)
  * Update maintainers of documentation. (#7646)
  * lambda-promtail: Add kinesis data stream to use in terraform  (#7632)
  * Documentation: Add a more complex template example (#7634)
  * Bump new version 1.2.19 of fluentd-plugin-grafana-loki
  * Add make target for building and pushing the fluentd plugin
  * Replace person with team for documentation reviews (#7645)
  * Bump helm/kind-action from 1.2.0 to 1.4.0 (#7550)
  * fix: Hide this error message when ctx timeout occurs in s3.getObject (#6360)
  * Promtail: Add go build tag promtail_journal_enabled (#7587)
  * [Helm] Updating tokgen job imagePullSecret templating (#7524)
  * modify usage stat metric unit to match definition (#7588)
  * Mention default port in docs (#7637)
  * promtail/server: Disable profiling by default (#5400)
  * [Helm] Create metricsInstance only if available (#7535)
  * Swap direction in "The label identifier is always on the right side of the operation." sentence (#7631)
  * Loki: Implement timeouts migration (#7555)
  * [bugfix] add Promtail cloudflare close  (#7394)
  * [fix]  cassandra: reconnection when k8s cassandra pods restart (#6725)
  * batchRetries to countersWithHost (#7392)
  * fix ingester: grpc method=/logproto.Querier/Query fail. (#5970)
  * fluent-bit: clarify docs, use 1.9.9 (#6464)
  * Docs: Add missing changelog entry for stream sharding (#7622)
  * updated chart version to 3.3.2 to release merged changes (#7618)
  * Docs: troubleshooting generation cache errors (#7600)
  * [Helm] fix typos in parameter descriptions (#7527)
  * Add docs for jsonnet SSD example (#6908)
  * operator: Increase lint timeout to 5m0s (#7612)
  * loki helm chart: fix indentation in single-binary pdb template (#7266)
  * Loki: implement decolorize filter (#7602)
  * use fifocache.duration instead of fifocache.interval in warn deprecated (#7609)
  * added empty changelog section for the next release (#7606)
  * Querier: remove expensive & low-value debug log line (#7532)
  * Promtail: Fix collecting userdata field from Windows Event Log (#7461)
  * Improve CRI format documentation (#7582)
  * Loki: Fix index_set log message (#7538)
  * Bump github.com/sony/gobreaker from 0.4.1 to 0.5.0 (#7565)
  * [Docs] Typo on Helm Install Loki in Scaleable mode (#7604)
  * Keep rates in the ratestore for 10 minutes  (#7599)
  * operator: Update API docs generation using gen-crd-api-reference-docs (#7592)
  * operator: Add TLS support for compactor client (#7448)
  * Add single compactor http client for delete and gennumber clients (#7453)
  * operator: Fix lookup CA Bundle options on fresh install (#7596)
  * Improves performance of json responses (#7522)
  * operator: Add support for built-in-cert-rotation for all internal lokistack encryption (#7064)
  * Reduce number of locks and partition by tenant and stream hash (#7583)
  * [helm] Document helm migration from `loki-distributed` (#7514)
  * add user-id transformer for logs results cache (#7581)
  * Fix Hugo build for docs (#7580)
  * Retry pr (#7579)
  * Fix Promtail GCP Logs diagram route (#7577)
  * Remove CTA per @grafanawriter. (#7559)
  * Track rates per stream and per tenant (#7564)
  * [Helm] Add toggle for MetricsInstance (#7525)
  * Bump helm/chart-testing-action from 2.1.0 to 2.3.1 (#7551)
  * [CI] improvement of code coverage check (#7428)
  * Bump cachix/install-nix-action from 15 to 18 (#7439)
  * Bump cloud.google.com/go/storage from 1.22.1 to 1.27.0 (#7233)
  * Bump actions/setup-python from 2 to 4 (#7552)
  * fix(loki-canary): Send to Loki after updating `totalEntries`. (#7211)
  * Fixing a typo in CONTRIBUTING.md (#7547)
  * Remove CTA per @grafanawriter. (#7557)
  * Adds extra docs to flehs out ParseLabels implementation (#7562)
  * Add terraform snippets to Promtail GCP Logs documentation (#7526)
  * Remove CTA per @grafanawriter. (#7558)
  * Shard streams round-robin rather in batches.  (#7560)
  * Add way to override userId for caching (#7542)
  * Prevent IndexShipper from leaking mutex accesses. (#7548)
  * promtail: register reload metrics after running options (#7561)
  * Ensure labels on sharded streams are sorted before they're sent anywhere (#7556)
  * [Helm] Fix invalid ruler config when filesystem storage is used (#7528)
  * Hardcode ring.WriteNoExtend for distributor push operations (#7517)
  * Document new Helm Charts (#7034)
  * Improves performance of distributor validations (#7534)
  * Add GCP Logs push target Promtail docs (#7511)
  * [helm] Fix included rules (#7430)
  * Fix drone signature (#7512)
  * Loki: Remove the bypass for "limited" queries  (#7510)
  * Add 2.7.0 section to upgrading doc (#7457)
  * Few small changelog changes (#7460)
  * Make 2.7.0 section (#7456)
  * Remove prometheus CRDs (#7499)
  * [helm] Add a loki canary test to the helm chart (#7229)
  * Helm: Allow users to define remote write for metrics. (#7399)
  * [mixin] Add cortex-gw-internal to dashboards (#7481)
  * tsdb post compaction cleanup (#7502)
  * Loki: log when a query starts in the logql engine (#7469)
  * Index gw lock bugfix (#7497)
  * Improve rate store refresh latency (#7492)
  * Add how to connect to Azure using Service Principal (#7485)
  * Remove groupcache (#7126)
  * [Helm] Add flags needed for migration from distributed (#7331)
  * Loki: Remove RatelimitedStream proto (#7235)
  * Docs: Add max_streams to Promtail configuration doc (#7489)
  * [helm] Mimic loki service account with canary account (#7236)
  * Helm: Replace incorrect key loki.authEnabled in example override values (#7432)
  * Ruler: enable Loki to configure Alertmanagers per tenant (#7359)
  * Revert "fluentd: Add un-escaping of control characters in JSON" (#7468)
  * Update helm chart version (#7484)
  * Add envFrom to the tokengen job (#7479)
  * operator: Expose and migrate query_timeout in limits config (#7471)
  * Loki: Implement random entries assignment when sharding (#7427)
  * Update MAINTAINERS.md (#7467)
  * Change `master` to `main` and include `.md` ext.
  * Promtail: Add additional fields for cloudflare (#7463)
  * operator: Upgrade operator-sdk to v1.24.1 (#7449)
  * Promtail: Add basic tracing support (#7414)
  * Update Prometheus dependency to latest release (v2.39.1) (#7425)
  * Add compactor delete client tls client config (#7426)
  * Add remote schema option (#7442)
  * operator: Fix Custom TLS profile setting for LokiStack on OpenShift (#7437)
- Rebase proper-data-directories.patch
* Tue Apr 11 2023 ecsos@opensuse.org
- Update to version 2.7.4+git.1677258260.98421b0c:
  * Docs: Add release notes for 2.7.4 (#8629)
  * Docs: Update references from 2.7.{2,3} to 2.7.4 (#8626)
  * [release-2.7.x] Use 0.28.1 build image and update go and alpine versions (#8583) (#8623)
  * [release-2.7.x] Use golangci-lint v1.51.2 in build image (#8587) (#8622)
  * [release-2.7.x]  Update build image to go 1 20 1 and alpine 3 16 4 (#8575) (#8619)
  * Helm chart auto update (#8331) (#8618)
  * [release-2.7.x] fix panics when cloning a special query (#8607)
  * [release-2.7.x] fix(promtail): Make `cri` tags streams aware. (#8497) (#8614)
  * [release-2.7.x] [RFR] fix vector() function produces wrong timestamp on instant query (#8602)
  * [release-2.7.x] scheduler: fix panic on hitting /scheduler/ring when ring is disabled (#8609)
  * [release-2.7.x] store: write overlapping chunks to multiple stores (#8610)
  * [release-2.7.x] fix bugs in logs results caching and its tests (#8608)
  * [release-2.7.x] promtail: Handle nil error on target Details() call (#8604)
  * [release-2.7.x] Promtail: Fix collecting userdata field from Windows Event Log (#8605)
  * [release-2.7.x] docs(embedded-cache): config uses embedded_cache (#8554)
  * [release-2.7.x] Fixed XSS on LogQL Analyzer page (#8546)
  * Backporting fix for broken link. (#8491)
  * [release-2.7.x] Temporarily unpublish Analyzer page. (#8505)
  * [release-2.7.x] Update publishing workflows to use organization secret (#8435) (#8458)
  * [release-2.7.x] Fix numbering issue in second procedure. (#8456)
  * Remove call to action from 2.7 release. (#8428)
  * Fixing typo in 2.7.x branch. (#8390)
  * Bump new loki/promtail versions in ksonnet libs (#8367)
- Rebase proper-data-directories.patch
* Tue Apr 11 2023 ecsos@opensuse.org
- Update to version 2.7.3+git.1675246761.a880ea3b:
  * Prepare 2.7.3 changelog and release notes (#8348)
  * [release-2.7.x] Ensure a delete request interval of at least a second (#8341)
  * [release-2.7.x] Loki: Fix version info issue that shows wrong version (#7669, #8055) (#8314)
  * Prepare release 2.7.2 - Part 2 (#8292)
* Tue Apr 11 2023 ecsos@opensuse.org
- Update to version 2.7.2+git.1674741535.c35554d0:
  * Prepare release 2.7.2 - Part 1 (#8287)
  * [chore] Sort imports so that linter does not complain (#8286)
  * Backport #8278 and #8279 (update Go version to 1.19.5) (#8282)
  * Backport PRs #7555 and #7708 to 2.7 release branch (#8280)
  * [release-2.7.x]  fixed logql-analyzer (#8273)
  * [release-2.7.x] enable responsive table (#8262)
  * [release-2.7.x] fix bugs in processing delete requests with line filters and add proper tests (#7749)
  * [release-2.7.x] Update README.md (#8141)
  * [release-2.7.x] Update v2-7.md (#7867)
  * [release-2.7.x] Update publishing workflows to use PATs with fine-grained access control (#8101)
  * Remove CircleCI config (#8114)
  * [release-2.7.x] Fix validation for pattern and regexp parsers (#7947)
  * [release-2.7.x] doc(api): Default value for `delete_ring_tokens` on `/ingester/shutdown` endpoint (#7929)
* Tue Apr 11 2023 ecsos@opensuse.org
- Update to version 2.7.1+git.1670610512.e0af1cc8:
  * Backport 7804 into 2.7.1 (#7896)
  * [release-2.7.x] Prepare changelog and release notes for 2.7.1 (#7897)
  * default compactor deletion mode to filter only (#7877)
  * Backport: Fix alertmanager per tenant override config behavior (#7805) (#7858)
  * [release-2.7.x] Fix Promtail GCP Logs diagram route (#7822)
  * [release-2.7.x] Add single compactor http client for delete and gennumber clients (#7607)
  * Revert "[release-2.7.x] docs/upgrading: Add a note about windows event log fix" (#7801)
  * [release-2.7.x] backport of #7715  (#7774)
  * changed the URL to LogQL Analyzer backend v2.7.0
  * Update references to 2.6.1 binaries to 2.7.0 (#7458)
  * [release-2.7.x] docs(v2.7.0): Minor tweaks on 2.7 release notes (#7712)
  * [release-2.7.x] docs(embedded-cache): Add missing docs on config page. (#7687)
  * [release-2.7.x] docs/upgrading: Add a note about windows event log fix (#7675)
  * docs: Fix refs on helm docs that breaks rendering new docs (#7670)
* Tue Apr 11 2023 ecsos@opensuse.org
- Update to version 2.7.0+git.1668123866.1b627d88:
  * [release-2.7.x] Add config changes to upgrade guide (#7664)
  * [release-2.7.x] Add 2.7 release notes (#7665)
  * Rebase 2.7 on k122 (#7621)
  * [release-2.7.x] Docs: Add missing changelog entry for stream sharding (#7623)
  * [release-2.7.x] Enable Loki to configure Alertmanagers per tenant (#7487)
  * Remove groupcache (#7126) [Backport to v2.7.x] (#7503)
  * [release-2.7.x] Revert "fluentd: Add un-escaping of control characters in JSON" (#7486)
  * [release-2.7.x] Docs: Add max_streams to Promtail configuration doc (#7493)
  * Expose ring and memberlist handlers through internal server listener (#7436)
  * Results cache fix improvements (#7444)
  * Revert "Revert "Update Thanos dependency to latest version"" (#7372)
  * Fix result cache misses on sharded queries (#7429)
  * Add Li Guozhong as a maintainer (#7440)
  * fluentd: Add un-escaping of control characters in JSON (#7396)
  * operator: Regenerate manifests (#7438)
  * Do not log 'unable to read rules directory' at startup if directory hasn't been created yet (#7434)
  * Fix enable of internal server for modules (#7423)
  * Add helm-docs to build image. (#7424)
  * operator: Add alert relabel config (#7415)
  * Promtail: correctly hashes the config on reload (#7421)
  * Loki mixin: Correct Loki datasource variable name. (#7422)
  * operator: Update golang and dependencies (#7418)
  * Promtail: Add handler timeout for GCP Logs Push target (#7401)
  * promtail: Fix exposed metric documentation for request_duration_seconds (#7420)
  * Bump tail dependency to address windows locking issues (#7417)
  * log panic full stack in boltdb recover block (#7410)
  * Provide example policy for S3 storage. (#7407)
  * [promtail] log:   simplify log, only print hash (#7405)
  * [loki-canary] Allow insecure TLS connections (#7398)
  * Fix promtail scrape config job name validation (#7402)
  * Create automated SBOM reports on Release (#7397)
  * Fix stream sharding (#7393)
  * Promtail: flush logs on exit (#7400)
  * [docs: logql-analyzer] changed url for main branch (#7378)
  * Update installation.md (#7388)
  * [helm loki] add support for custom analytics config (#7262)
  * Add metrics to the distributor about stream sharding (#7390)
  * Fix Flaky Distributor Test (#7391)
  * Measure Per-Stream rates (#7370)
  * Loki: Renames metric 'loki_log_messages_total' to 'loki_internal_log_messages_total' (#7361)
  * add promtail reload changelog and doc (#7386)
  * chunks: improve readability of compression benchmarks (#7246)
  * [new feature] promtail: Add config reload endoint / signal to promtail (#7247)
  * logging: Change Docker target discovery log level from Error to Info (#7312)
  * promtail/scraping.md: Fix 404 (#7317)
  * Bump actions/checkout from 2.4.0 to 3.1.0 (#7376)
  * use a channel to signal completion of index read operation for tsdb and boltdb shipper (#7381)
  * CONTRIBUTING: fix layout
  * area(promtail): add -check-syntax functionality (#7363)
  * Provision alerts for Loki Canary in Helm Chart. (#7286)
  * Import Canary dashboard into Loki mixin. (#7304)
  * documentation: correct yaml file (#7375)
  * Revert "Update Thanos dependency to latest version" (#7371)
  * [logql-analyzer] auto-deploy on Tag or Main (#7366)
  * lock boltdb and tsdb index while queries are in process (#7367)
  * TSDB explicit fingerprint (#7362)
  * operator: Add TLS profile support for Loki server and client HTTP and GRPC TLS options (#7322)
  * Implement Distributor Rate Store (#7349)
  * [dashboards] update dashboards for zone aware ingesters (#7313)
  * Fix Flaky Integration Tests (#7360)
  * removes unused tsdb files (#7353)
  * Use labelbuilder in syntax.ParseLabels to remove empty label values (#7355)
  * Update Thanos dependency to latest version (#7348)
  * Adding Promtail and Heroku blogpost files to `examples/` (#7347)
  * Loki: Per-tenant stream sharding (#7311)
  * Upgrade operator gh workflows to go1.19 (#7341)
  * Clarify how and where to download the Loki config file from (#7346)
  * Implement ingester API to return stream rates (#7176)
  * [loki helm chart] fixed to pass CI (#7345)
  * Service selector for single binary deployment fix. (#7301)
  * Loki: Add sharding support for negative/zeroed desired rate (#7342)
  * Restoring lint checks that were previously disabled (#7340)
  * mmap tsdb index file while opening it for querying (#7338)
  * Upgrade to Go 1.19 (#7243)
  * feat(lambda-promtail): add bearer token support (#7333)
  * Patching loki-build-image with latest golangci-lint version (#7337)
  * operator: Use quayio v2.7.0-pre image for openshift overlay (#7329)
  * docs: Document setting up command completion for logcli (#7325)
  * Updating loki-build-image to Go 1.19 (#7334)
  * Add compactor_address to fix startup (#7332)
  * Fix internal server bootstrap for query frontend (#7328)
  * operator: Use cluster monitoring alertmanager by default on openshift clusters (#7272)
  * Use a line-buffered logger to deamplify write syscalls (#6954)
  * operator: Move Loki operand from v2.6.1 to main-ec0bf70 (#7298)
  * operator: Add extended-validation for rules on OpenShift (#7295)
  * pkg/ruler/rulestore/configdb: Preallocate memory (#7326)
  * update regex for matching nlb logs while using lambda promtail (#7305)
  * adds result cache key version comparison metrics (#7323)
  * Added mapstructure tag to promtail configs structs (#7320)
  * reintroduce mmap for tsdb indices (#7321)
  * Bugfix include cache generations on querier response (#7300)
  * Add support for username to redis cache configuration (#7270)
  * Fix typo in flags definitions (#7257)
  * Loki: Improve query timeouts behavior (#7230)
  * Log delete request ID upon creation (#7307)
  * chunks: decode varints directly from byte buffer; stop panicing on some corrupt inputs (#7264)
  * Add list of delete requests to deletion dashboard (#7309)
  * operator: Add lokistack operations alerts and sop (#6951)
  * operator: Prepare bundle for openshift-logging release 5.6 (#7297)
  * operator: Enable subscriptions on OpenShift 4.12 (#7296)
  * Tests: Improve several tests behavior (#7283)
  * [docs] Fix docs for `rate_counter()`
  * operator: Expose Loki Ruler API via the lokistack-gateway (#7254)
  * Fix rangemapper with VectorExpr support (#7288)
  * fix/docs: Fixed a typo in the ingestor section (#7285)
  * [Mixin] Rename `logs` template variable to `loki_datasource`. (#7278)
  * Configurable TLS MinVersion and CipherSuites (#7227)
  * Tests: Reduce flakiness of GCPLog and integration tests (#7273)
  * Remove deletion filter debug log messages (#7277)
  * Promtail: Change max support compressed line size to be 2MB (#7268)
  * Expose tenant ID through relabel in push promtail targets (#7250)
  * Promtail: Add compressed files support (#6708)
  * chunks: update klauspost/compress package to v1.15.11 (#7263)
  * Logcli: load remote schema before validation (#7258)
  * Loki: Shard streams based on desired rate (#7199)
  * Operator: Config and bundle manifest changes for Lokistack API ObjectstorageTLS CA certificate key addition (#7256)
  * correct heartbeat timeout to distributor lifecycler for ring page (#7253)
  * Update deletions dashboard (#7244)
  * bumped GEL version in Loki helm chart to v1.5.2 (#7241)
  * [Optimization] logql client: When logql fails to execute, return the failure information to the caller (#6671)
  * operator: Add support for certificates to allow external S3 storage connections (#7070)
  * Fix promtail `metric` stage causing failure when getting extracted metrics (#7216)
  * Documentation: Fix broken link (#7136)
  * operator: Fix ruler grpc tls client configuration (#7214)
  * Docs: remove redundant section in Template functions (#6458)
  * Docs: Populate empty index pages (#7200)
  * Replace deprecated `io/ioutil` with `io` and `os` packages (#7212)
  * [bugfix] logql: vectorExpr run fail when query_range: parallelise_shardable_queries: true (#7045)
  * tsdb supports data deletion, this PR takes care of todo to enable delete request client for tsdb (#7223)
  * Jsonnet: fix overrides exporter to use correct CPU limits (#7221)
  * Helm: add support for configuring ruler (#7196)
  * Helm: expose Prometheus-compatible endpoints in gateway (#7195)
  * [helm] Add Loki Canary to Helm Chart (#7173)
  * Helm: Fix ExternalLicence (#7189)
  * Helm: Make automountServiceAccountToken configurable (#7114)
  * avoid using bloomfilters for chunks in stats calls by avoiding duplicates (#7209)
  * highly sharded subqueries are ellided in expr.String (#7203)
  * add index requests panel to reads/writes dashboard (#7163)
  * Guidelines: Update CONTRIBUTING.md (#6757)
  * Update distributor push tests (#6641)
  * Helm: Adding tolerations value support for tokengen job (#7122)
  * [helm] Storage: Read support for Azure Object Storage (#7162)
  * Document validation & rate-limit errors (#7145)
  * operator: Write configuration for per-tenant retention (#7201)
  * docs: Change AWS EKS example eventrouter rbac resources from v1beta1 apis to v1 (#6483)
  * support custom label selector in kubernetes_sd_configs (#5920)
  * ingester_querier: early exit queries on reaching quorum (#7172)
  * Bring addition of server config into existing style (#7174)
  * Update README.md (#7190)
  * Update README.md (#7191)
  * Project: Change PR template and CONTRIBUTING guide (#7116)
  * Evenly spread memcached across nodes (#7183)
  * Abide to Mixin linting rules. (#7010)
  * TSDB indexBuckets helper logs instead of errors (#7187)
  * Helm: Bump helm chart patch version (#7184)
  * [Bugfix] TSDB index bucket calculation (#7178)
  * fixes azure client secret duplicate CLI registration (#7185)
  * Helm: Fix limits_config key in helm values file (#7182)
  * allow backup store metrics registration by including backend type in labels (#7177)
  * [loki] Azure auth using Service Principal (#7179)
  * fixes nil interface value with non-nil type in cache construction (#7175)
  * Add local k3d environment for enterprise-logs (#7146)
  * Helm: Allows loki s3 http_config block to be configured (#7041)
  * Helm: Make server configuration configurable (#7137)
  * operator: Fix TLSProfile not working on vanilla k8s (#7167)
  * Expose limits and compactor config via helm values (#7108)
  * Fix minio values, reduce replicas, and fix tokengen job (#7147)
  * Update GEL helm deployment example (#7144)
  * promtail: Fix issue with dropping logs when a file based SD target's labels are updated (#7016)
  * revert stream push error response (#7160)
  * operator: Skip enforcing matcher for certain tenants on OpenShift (#7037)
  * operator: Manage global stream-based retention (#7106)
  * refactor index storage code to index reader/writer interfaces for better monitoring (#7154)
  * tsdb: clean-up metrics (#7150)
  * Promtail: Add support for max stream limit (#7101)
  * fix(ruler): Initialize multi remote clients config (#7151)
  * Docs: Fix template function examples (#7148)
  * Remove duplicated `loki_boltdb_shipper` prefix from `tables_upload_operation_total` metric (#7040)
  * Implement all-or-nothing stream ingestion (#7094)
  * [bugfix] fix query_frontend init fail error (#7013)
  * tsdb: boltdb shipper backup store tsdb (#7130)
  * loki: Attach the panic recovery handler on all HTTP handlers (#6780)
  * operator: Add network tenant for netobserv (#6769)
  * operator: Fix flaky TLSProfile feature gate test (#7131)
  * Docs: Fix Helm chart link path (#7107)
  * Fix errors loading deletes after force-removing partially-completed delete (#7125)
  * Bump chart version to test release (#7124)
  * Fix helm release name template (#7123)
  * Log the interval of a delete request (#7120)
  * Make helm with style more consistent (#7096)
  * Fix pod affinity selector for single binary (#7109)
  * Small updates to the deletion documentation (#7112)
  * feat(loki-canary): Add support to push logs directly to Loki. (#7063)
  * Add ability for Ruler to remote write to multiple clients (#6823)
  * docs: fix alertmanager_client config settings (#6858)
  * Add chart-tools and chart-releaser for helm (#7095)
  * Docs: Fix Helm Chart links (#6985)
  * Improvements to Promtail GCP push target (#7057)
  * Automatically label Helm realted pull requests. (#7083)
  * Missing conditional on ServiceMonitor (#7067)
  * Only release helm for helm paths (#7093)
  * Bump github.com/docker/docker to v20.10.17 (#6975)
  * Bump golang.org/x/sys to v0.0.0-20220829200755-d48e67d00261 (#7021)
  * doc: Clarity on querier remapping when shuffle sharding is disabled (#7026)
  * operator: Configure kube-rbac-proxy sidecar to use Intermediate TLS security profile in OCP (#7092)
  * Fix setting name in documentation (#7086)
  * Helm: Fix s3 region in ruler storage config (#7077)
  * Add sequence num to log output for delete requests (#7087)
  * Fix internal server initialization (#7085)
  * Helm: Adding template-able image value for tokengen job container (#7075)
  * Add support for custom internal server (#7069)
  * Troubleshooting: instructions for loki + istio (#6205)
  * Add prefix for helm-release tags (#7073)
  * bugfix:add cases.NoLower option (#7052)
  * docs: fix typo in layout (#7071)
  * feat: add kms and ec2 permission (#7058)
  * Add nix configuration (#7020)
  * operator: Configure gateway to honor the global TLS security profile (#6870)
  * tsdb: build tsdb from tenantheads (#7036)
  * [doc] logql: logql engine support exec vector(0) grama (#7044)
  * Update metrics descriptions (#6982)
  * Deprecation Fix: Replace strings.Title with cases.Title().String() (#7048)
  * Do not run helm release on tags matching our version releases (#7038)
  * Helm: Publish Helm charts to grafana/helm-charts. (#6955)
  * Enable build in env w/o internet or GCP creds (#7029)
  * tsdb: build rotated heads asynchronously (#6956)
  * [new feature] logql engine support exec `vector(0)` grama (#7023)
  * Revert "Hide duplicates caused by stream sharding (#7005)" (#7031)
  * operator: Adding Lokistack Gateway Request Errors Alert (#6999)
  * operator: Configure default node affinity for all pods (#7000)
  * Helm: test migration from `grafana/loki-simple-scalable` (#6986)
  * fix test increase timeout (#7022)
  * [new feature] syntax: support "vector" grama (#7007)
  * azblob: Make azblob support private cloud endpoint suffix (#6842)
  * Hide duplicates caused by stream sharding (#7005)
  * Generate Helm chart README. (#7012)
  * Helm: Upgrade Minio chart dependency to 4.0.12. (#6974)
  * [bugfix] fix flush.go nil pointer panic (#6993)
  * Loki: Modify ingesters to return rate-limited streams to distributors (#6977)
  * [TSDB] 600MB max per shard in query planning (#7004)
  * doc(community): Update community call timings. (#7002)
  * compactor: prefetch existing compacted user index files in parallel (#6803)
  * operator: Fixing logcli pod image value for operator addons (#6997)
  * Make TSDB store singleton resettable (#6950)
  * [docs] document logfmt pipeline stage (#6238)
  * Helm: Add helm ci (#6988)
  * Docs: Fix default max_chunk_age (#6996)
  * Logql Analyzer (#6171)
  * querier deployment rollingupdate works as a percentage to allow faste… (#6990)
  * Remove deprecated helm chart source code (#6978)
  * Docs: update `split_queries_by_interval` documentation to have the correct explanation for how to disable. (#6715)
  * Loki: add `__line__` and `__timestamp__` to label_format (#6983)
  * update to alpine:3.6.2 (#6979)
  * lambda-promtail: Add support for Kinesis data stream events (#5977)
  * [fix panic] s3: fix object nil point (#6970)
  * [Doc] Fixed comma and missing "of" in observability.md (#6976)
  * compactor: adds tunable to control upload parallelism (#6817)
  * Support helm migration from current grafana/loki chart (#6958)
  * promtail: GCPLog fixing `failed to receive pubsub messages` error (#6965)
  * Use backticks for code syntax. (#6967)
  * Return Querier/QueryTimeout YAML configuration. (#6972)
  * Add deletion metrics to the documentation (#6971)
  * compactor: prioritize newer tables when compacting. add operator flags to compac… (#6804)
  * Loki: Implement stream sharding (#6952)
  * Adapt queryTimeout to be a per-tenant configuration (#6835)
  * Shard deletes requests based on time ranges (#6903)
  * Evenly spread distributors across available nodes (#6964)
  * Fix Loki distributor in production Nomad job and docs. (#6963)
  * lambda-promtail: allow numbers on LB name regex (#6961)
  * Restoring metrics removed by #6957, simplifying implementation (#6962)
  * Upgrade prometheus/client_golang and reconfigure to restore `go_sched.*` metrics (#6957)
  * docs: Fixed examples within Loki and Promtail docs (#6591)
  * Bring helm chart back into Loki repo (#6829)
  * feat: add kms ecryption (#6926)
  * Setting sane defaults for ruler in SSD "read" mode (#6551)
  * [TSDB] disables bloom filters for tsdb index on ingesters (#6939)
  * Remove comparisons page, it's not very acurate and the information is outdated. (#6938)
  * Add operational guide for autoscaling (#6801)
  * docs:Add documentation for TLS configuration parameters for HTTP and gRPC (#6933)
  * Fix topk and bottomk operations with int <= 0 (#6937)
  * Change Loki Operator namespace to openshift-logging in the CSV (#6935)
  * Fix `increment_duplicate_timestamps` for multiple dupped timestamps (#6924)
  * log query which causes panic in logql.clone (#6934)
  * Improve error message (#6913)
  * operator: Reconcile owner reference for existing objects (#6923)
  * Disable distributed cache for the default loki local config (#6925)
  * Update documentation deletion_mode and allow_deleted configuration values (#6921)
  * reintroduces now deprecated+noop deletion configs for compatibility (#6917)
  * Remove unnecessary spin up of mock (#6911)
  * Previous PR #6888 broke some additional jsonnet, use {} instead of null (#6918)
  * fix(consul): allow consul deployment (#6888)
  * detects issuer via useragent in querytee reqs (#6914)
  * Adding valid subscription annotation to metadata (#6907)
  * Propagate error detail properly in all cases (#6890)
  * Update build-image to 0.23.0 (#6899)
  * Add missing environment variable names on logcli flags description (#6865)
  * Docs: add minimal docs explaining how to use the LogQL Analyzer (#6900)
  * Update alpine and golang base images (#6897)
  * Fix free port allocation flake (#6898)
  * fix(stats_collector): Do not collect stats for failed requests. (#6878)
  * Add support for journal matches (only conjuntions) (#6656)
  * fixed typo in API host (#6892)
  * Logql analyzer page cherry picks (#6889)
  * add metric for measuring overall index query latency (#6880)
  * [bugfix] fixes issues sharding series by storageref vs fingerprint in stripeSeries (#6882)
  * Add timeouts to deletions  (#6879)
  * Remove unused code (#6872)
  * Docs: improve wording and grammar (#6861)
  * Clarify delete upgrade path (#6871)
  * Add delete api validations (#6860)
  * update deletion docs (#6869)
  * update dskit and fix (#6868)
  * Add ability to limit the impact of pathological delete requests. (#6854)
  * Existing limits were low for large envs (#6846)
  * avoid creating multiple tenant heads in tsdb during a race (#6866)
  * test(promtail): Fix flaky test with promtail bind port. (#6859)
  * don't deploy consul if we're using memberlist and not actively migrating (#6836)
  * chore(makefile): Remove `NETGO` check after building loki binaries. (#6856)
  * embedded-cache: Bring `fifocache` and `groupcache` into single tent. (#6821)
  * promtail/client: add bot fields (#6828)
  * fix context propagation for child spans in shard resolver (#6853)
  * [TSDB] Ingester Index Sampling (#6852)
  * Only process deletes in batches (#6851)
  * Delete requests processing improvements (#6837)
  * [TSDB] Indexgateway Protobuf refactor  (#6841)
  * operator: Use mod readonly when building container (#6843)
  * Improve error message when max error message is hit (#6834)
  * Support building against Go 1.19 (#6833)
  * Add groupcache timeouts (#6808)
  * Adding properties file (#6799)
  * fix(logql): Make `LabelSampleExtractor` work as expected when label doesn't exist in logline (#6766)
  * Change existing labeler action to use type/docs label (#6754)
  * Promtail: Add new target for receiving GCP PubSub Push messages (#6777)
  * Treat version flag at any position (#6827)
  * Log stream flushes to see how many chunks we flush at a time (#6819)
  * doc(retention): Add clarity on default behavior. (#6815)
  * Simplify shard membership calculations (#6810)
  * chore(groupcache): Groupcache doesn't need global server handler anymore (#6820)
  * deb and rpm packaging for all binaries (#6456)
  * Remove reference to non-existent config field (#6781)
  * Open access to Minio console in dev setup. (#6807)
  * Fix log messages for deletion requests (#6727)
  * Run `loki -version` without needing a config defined (#6802)
  * populate the memberlist label by default (#6800)
  * only set the consul kvstore configs if memberlist is not being used (#6809)
  * Allow fifocache to be configured with groupcache (#6806)
  * chore(groupcache): Fix panic with stats collector wrapper (#6798)
  * docs: fix a typo (#6791)
  * Fix Promtail dashboard. (#6796)
  * operator: Changing channel to stable (#6795)
  * query-tee: support for multi backend response comparison and disabling query proxy for select backends (#6736)
  * chore(groupcache): Support per cache group capacity (#6793)
  * Docs: Revise location of some LogQL examples; improve prose (#6751)
  * Groupcache improvements (#6752)
  * chore(groupcache): disable hotcache for chunks (#6784)
  * Fix YAML syntax and ConfigMap reference (#6735)
  * Typo in 'trimPrefix' function signature (#6733)
  * Backport Memberlist dependency version bump to k108 (#6773)
  * Update Memberlist dependency version; tidy and re-vendor (#6717)
  * Rephrase error message (indexgateway->groupcache). (#6763)
  * Fix cache instrumentation (#6753)
  * operator: Update Loki operand to v2.6.1 (#6749)
  * operator: Update go4.org/unsafe/assume-no-moving-gc to latest (#6748)
  * operator: Golang version to 1.18 and k8s client to 1.24 (#6741)
  * doc: Add shuffle sharding doc (#6173)
  * chore(groupcache): Disable hotcache during set (#6740)
  * use owen-d gomemcache fork for connection sharding (#6722)
  * [Enhancement] Removes memcached failure log (#6720)
  * tsdb store refactoring (#6724)
  * Index shipper move code (#6704)
  * upgrade `go:1.17.9` to `go:1.18.4` (#6726)
  * Reinclude .git dir in docker builds (#6723)
  * [Fix] Furthers gcs latency buckets (#6721)
  * Fix goroutine leak when using http2 (#6718)
  * operator: Addons work in restricted policy (#6564)
  * Revert "Set ingester PDB to have max_unavailable=0. (#6589)" (#6714)
  * Adding "start_delta" entry to metrics.go line (#6550)
  * keep the memberlist labels jsonnet config backwards compatible with 2.6.1 (#6711)
  * add jsonnet for configuring memberlist cluster label (#6707)
  * Loki: Do not store exact log line duplicates (now including unordered inserts) (#6642)
  * Loki: Return an __error_details__ label for any line which incurs a __error__ while being processed (#6543)
  * Add push route (#6616)
  * promtail: Inject tenant ID when receiving X-Scope-OrgID in heroku target (#6695)
  * Add function to reset boltDBIndexClientWithShipper singleton
  * updated versions to the latest release v2.6.1 (#6705)
  * updated versions to the latest release v2.6.1 (#6703)
  * Add configurable groupcache capacity (#6678)
  * Update production-ready Loki in docker-compose (#6691)
  * added changelog for 2.6.1 release (#6697)
  * Fix per-tenant delete client (#6696)
  * Document loki lable format (#6647)
  * Docs: Fix bad links in the API section (#6688)
  * Targets: Add Heroku HTTPS drain target (#6448)
  * query_frontend_shard_factor uses exponential buckets (#6689)
  * Fix TIME_WAIT connection leak from queriers to compactor (#6681)
  * Add API delete curl examples (#6680)
  * stripes frontend requests in progress (#6679)
  * Set log level for GetChunkRefs log (#6677)
  * Introduce an "enable_groupcache" config to control initialization better (#6673)
  * fix the issue of overwriting tsdb files during rollouts (#6668)
  * Add README file to loki-mixin (#6083)
  * operator: Set minimum TLS version to 1.2 to support FIPS (#6669)
  * operator: Fix kind deployment for make quickstart (#6666)
  * [TSDB] store uncompressed chunk size in index (#6665)
  * dont skip writing to TSDB index when chunk exists in cache (#6664)
  * operator: Add support for tail TLS encryption (#6663)
  * Defining Loki dockerfile user as numeric value (#6659)
  * operator: Fix live tail of logs not working on OpenShift-based clusters (#6443)
  * Loki: Remove ring client from the distributor (#6622)
  * bumped version of grafana's memberlist fork to have the fix that allows to disable labels check that is required for the migration. (#6655)
  * operator: Update Loki operand to v2.6.0 (#6646)
  * Fix inconsistent coverage in the distributor package (#6645)
  * Introduce Groupcache (#6644)
  * Loki: Update `grafana/dskit` and `weaveworks/common` (#6643)
  * [TSDB]  fingerprint offsets is now correctly 16 byte aligned (#6630)
  * removed redundant 2.6.0 release title (#6640)
  * use the configured index prefixes while building table names for tsdb index (#6436)
  * updated date of the release and release notes (#6635) (#6636)
  * manually backported upgrading guide from release 2.6.0 (#6631)
  * backport changelog from 2.6.0 (#6615)
  * build and hook tsdb compaction code to the generic index compactor (#6627)
  * Don't add the memberlist label as a selector to services.
  * Draft of release notes for loki 2.6. (#6546)
  * Add integration for SSD (read & write targets) (#6585)
  * Promtail: Add text encoding conversion to file targets (#6395)
  * Append .x to the versioned directories for the website sync (#6611)
  * operator: Disable client certificate authentication on gateway (#6594)
  * Fix release workflow (#6610)
  * operator: Bump loki.grafana.com/LokiStack from v1beta to v1 (#6474)
  * CI/CD: Update documentation publishing workflows (#6381)
  * operator: Use docker build context for root make targets (#6601)
  * Fix drone CI builds for loki operator (#6599)
  * Tsdb tenant index querying (#6598)
  * Remove ourdated comment (#6597)
  * avoid making delete requests if deletes are disabled for a user (#6583)
  * operator: Build and publish images for docker hub (#6086)
  * Drone: Do not run pipelines twice on PRs (#6511)
  * Set ingester PDB to have max_unavailable=0. (#6589)
  * loki-canary: Fix resource leak when using client-side certs (#6579)
  * operator: Update to operator-sdk 1.22.0 (#6581)
  * fix(lambda-promtail): update default lambda_vpc_subnets / lambda_vpc_security_groups values to be appropriate empty list(string) value (#6453)
  * operator: Add docs for object storage (#6561)
  * generic index compactor (#6537)
  * log addtl info about bytes/shard in planning (#6573)
  * Support dashboards for SSD mode (#6540)
  * introduce randomness to the first call for the metric test query to reduce the likelyhood that large numbers of canaries will all make this request at the same time. (#6562)
  * Stop compaction interval timer to avoid leak. (#6570)
  * operator: Fix make target deps for web-pre (#6565)
  * logcli: add flag to read remote schema configs (#6539)
  * operator: Refactor feature gates to use custom resource definition (#6549)
  * Docs: Add multi-tenant query curl examples (#6530)
  * Add jsonnet to build image (#6526)
  * operator: Making all pods and containers compliant with restricted policy (#6514)
  * Do not fail queries if compactor returns unexpected status code (#6552)
  * Loki: Update `grafana/dskit` to `3624a96` (#6529)
  * operator: Publish docs as public website (#6449)
  * Fix documentation of environment variable defaults (#6536)
  * tools: add lambda-promtail missing errchecks (#6541)
  * Fix operator forwarding logs docs (#6545)
  * Promtail: update certificates used for syslog’s tests (#6534)
  * Loki: Add the ability to use the log line timestamp in label and line formatter (#6517)
  * operator: Fix clusterserviceversion description (#6524)
  * operator: Use default interface_names for lokistack clusters (#6531)
  * Add client type as label (#6469)
  * Add label_replace and literal expressions to instant query split by range (#6515)
  * Loki Prometheus mixin: Fix incorrect selectors and simplify mixin usage (#6189)
  * Docs: improve API docs (#6485)
  * Promtail: disable syslog tests which have expired certs (#6520)
  * dont call getinstance twice in checkpointing (#6516)
  * Add Drone pipeline to test packaging (#6482)
  * operator: Support TLS enabled lokistack-gateway (Kubernetes native) (#6478)
  * operator: Disable report on overlay openshift (#6504)
  * Updating maintainers.md (#6466)
  * Disable index gateway client on read target. (#6490)
  * During query readiness, log duration of all object-store operations (#6489)
  * logcli: add --proxy-url flag for http/https proxy support (#6484)
  * Update loki's default port to 3100 (#6349)
  * Loki: Fix flaky IndexGatewayClient test (#6481)
  * Changelog: Fix changelog link (#6479)
  * Handle duplicate registration of deletion metrics (#6446)
  * Remove file lag alert (#6452)
  * Remove whole stream deletion mode (#6435)
  * Fix panic in instant query splitting when using unwrapped rate (#6348)
  * Use shipper as indexClient for read mode. (#6461)
  * Set RingManager mode as Server if in read target. (#6427)
  * operator: Add shellcheck disables (#6460)
  * operator: Add e2e local development with kind (#6339)
  * Docs: revise multi-tenancy prose (#6355)
  * fix(documentation): correct spelling and scrape_config (#6454)
  * operator: Move cli flags to component config (#6433)
  * Add TLS config to query frontend (#6444)
  * operator: Update Grafana and forwarding documentation (#6442)
  * operator: Extend schema validation in LokiStack webhook (#6411)
  * operator: Enhancement Proposal to configure log retention (#6232)
  * Evenly spread queriers across available nodes (#6415)
  * Compactor: add per tenant compaction delete enabled flag (#6410)
  * Fixes bad initialization for uniqueString (#6432)
  * Tsdb/wal rotate fix (#6423)
  * [modules] pin version of memberlist (#6413)
  * Add unwrapped aggregation `rate_counter()` (#6412)
  * Add support for ARM64 to lambda-promtail drone build job (#5354)
  * [TSDB] Use index sampling to determine shard factor (#6396)
  * Add index gateway to the read path (#6385)
  * Parallize label queries to both stores (#5997)
  * Sum values in unwrapped rate aggregation instead of treating them as counter (#6361)
  * promtail: fix infinite loop in file target (fixes #5350) (#6135)
  * operator: Add support for gRPC over TLS for Loki components (#6224)
  * Git ignore pkg/loki/wal (#6405)
  * Bump prometheus dependency (#6403)
  * operator: Storage schema update (#5952)
  * Docs: revise changelog entry for PR 5626 (#6406)
  * Docs: Edits for several PRs that did not have a docs review (#6398)
  * Add more logging for delete requests (#6394)
  * Add deleted lines panel to deletion dashboard (#6390)
  * Add lokistack prefix to role and rolebinding names. (#6397)
  * Docs: edit the CHANGELOG (#6386)
  * Docs: add unpopulated v2.6 release notes section (#6354)
  * Use correct counter when deleting lines (#6376)
  * feature: Add ingester handler for shutdown and forget tokens (#6179)
  * Mixins templatize clusterlabel fixes (#6383)
  * Don't interupt the query path if deletes aren't available (#6368)
  * Promtail: Support all `cri-o` tags (multiline tags). (#6177)
  * Naïve fix for optimize bug with `line_format` and `json` expression parser (#6375)
  * JSON label extraction field validation expression overly strict (#6372)
  * chore(jsonnet-lint): Make `promtail-mixin` depends on `loki-mixin` `main` version (#6379)
  * Revert "Loki Prometheus mixin: templatize cluster label" (#6377)
  * Loki Prometheus mixin: templatize cluster label (#6353)
  * fix(loki): allow global and per tenant sigv4 config (#6358)
  * Add compactor route for the cache gen number api (#6365)
  * GCS: Add service_account option (#6366)
* Thu Jul 21 2022 ecsos@opensuse.org
- Update to version 2.6.1+git.1658128747.6bd05c9a4:
  * [release-2.6.x] Backport dskit, memberlist version updates to 2.6.x to support memberlist cluster labels and verification; re-vendor (#6693)
  * Fix per-tenant delete client (#6696) (#6698)
  * Docs: Fix bad links in the API section (#6688) (#6694)
  * Fix TIME_WAIT connection leak from queriers to compactor (#6681) (#6692)
  * avoid making delete requests if deletes are disabled for a user (#6583) (#6687)
  * Add client type as label (#6469) (#6685)
  * Handle duplicate registration of deletion metrics (#6446) (#6684)
  * Do not fail queries if compactor returns unexpected status code (#6552) (#6683)
  * Add API delete curl examples (#6680) (#6682)
  * added link to release notes page on releases page (#6639)
  * added link to release notes page (#6638)
  * updated date of the release and release notes (#6635)
  * Draft of release notes for loki 2.6. (#6546) (#6624)
  * 2.6 Backport: Promtail: Add text encoding conversion to file targets (#6395) (#6617)
  * Append .x to the versioned directories for the website sync (#6611) (#6613)
  * [release-2.6.x] CI/CD: Update documentation publishing workflows (#6607)
  * manually backported changes from #6386 (#6588)
  * Docs: Edits for several PRs that did not have a docs review (#6398) (#6575)
  * fix(documentation): correct spelling and scrape_config (#6454) (#6576)
  * Fix documentation of environment variable defaults (#6536) (#6577)
  * Docs: revise multi-tenancy prose (#6355) (#6578)
  * Docs: Add multi-tenant query curl examples (#6530) (#6563)
  * Add label_replace and literal expressions to instant query split by range (#6515) (#6559)
  * Fix panic in instant query splitting when using unwrapped rate (#6348) (#6557)
  * [release-2.6.x] Add unwrapped aggregation `rate_counter()` (#6556)
  * Sum values in unwrapped rate aggregation instead of treating them as counter (#6361) (#6555)
  * resolved merge conflict Docs: improve API docs (#6485)
  * Removing CHANGELOG entry (#6525)
  * Promtail: disable syslog tests which have expired certs (#6520)
  * Revert "Add cache usage statistics (#6317)"
  * bumped images/binaries version to 2.6.0
  * created section with loki version 2.6.0 in upgrading guide
  * updated CHANGELOG.md for the release 2.6.0 (#6506)
  * [release-2.6.x] Add TLS config to query frontend (#6498)
  * [k102] Backport Remove whole stream deletion mode (#6435) (#6477) (#6497)
  * Compactor: add per tenant compaction delete enabled flag (#6410) (#6476) (#6496)
  * Add more logging for delete requests (#6394) (#6473) (#6495)
  * Use correct counter when deleting lines (#6376) (#6472) (#6494)
  * Don't interupt the query path if deletes aren't available (#6368) (#6471) (#6493)
  * Backport #6413 and #6377 to k102 (#6422) (#6492)
  * Promtail: Add metrics for journal target (#6105)
  * TSDB/query-planning-groundwork (#6367)
  * cmd/loki: minor consistency patch (#6364)
  * Add total number of unique users involved in query readiness. (#6035)
  * operator: Allow optional installation of webhooks (#6363)
  * operator: Allow reduced tenant OIDC authentication requirements (#6362)
  * operator: Expose only an HTTPS gateway when in openshift-logging mode (#6288)
  * chore(fluentd): resolve rubocop failures (#6359)
  * Tsdb/index sampling endpoint (#6347)
  * loki-canary: Add support for client-side TLS certs for Loki connection (#6310)
  * operator: Add missing rbac to get/list/watch namespaces (#6303)
  * Update gopkg.in/yaml.v3 (#6284)
  * Support `series|labels` query_type in `logql_query_duration` (#6341)
  * Fix max series test loop that returns early (#6345)
  * [logql] don't try to execute a modified function that is not allowed by the AST (#6346)
  * Docs: Add changelog entry for configuration parameter name change (#6340)
  * TSDB/index-sampling-wiring (#6338)
  * Define a reason why the fifocache has evicted an item (#6335)
  * Set `MetricsNamespace` configurable for MemberlistKV module in Loki (#6330)
  * Update _index.md - an unofficial Loki client added (#6312)
  * Expose Memberlist status page on MemberlistKV module init (#6322)
  * Add multi_kv_config block to overrides configmap when multi kv is enabled (#6323)
  * Tsdb/index sampling (#6329)
  * always retry syncing index files from indexshipper when the index list cache is stale (#6327)
  * Add cache usage statistics (#6317)
  * Update delete integration test (#6192)
  * Use fake credentials in storage/chunk/storage tests (#6187)
  * Add licensing boiler plate in case we ever need it (#5251)
  * make index shipper read path handle range of tables by type of index (#6304)
  * copy boltdb-shipper cache changes from PR #6054 to generic index shipper (#6316)
  * Reduce to a single code path through sendBatches regardless of limit (#6216)
  * fix: allow promtail docker_sd_config to handle long log lines (#6256)
  * Fix delete cancellation timeout (#6285)
  * fixed type of the property in memberlist config (#6307)
  * Support tenant id from value (#6290)
  * We shouldn't modify the loki config at all if the memberlist ring is not (#6299) (#6308)
  * Tsdb/inverted index wiring (#6252)
  * Only consider an interval to have possible expired chunks if it overlaps a delete. (#6297)
  * exposes line length hist on distributors  (#6309)
  * do not initialize tsdb index store when using index gateway client for queries (#6305)
  * update loki-mixin json dashboards with latest jsonnet changes (#6306)
  * Look up config file in default locations (#6160)
  * Avoid line copy during LogQL line_format (#6104)
  * Improve write dashboard by removing unrelated route (#5853)
  * make tsdb store instance a singleton (#6273)
  * Import memberlist.libsonnet in loki.libsonnet. (#6294)
  * feat(fluentd): allow fluentd_thread label to be configurable (#6240)
  * Only delete data when WholeStreamDeletion or FilterAndDelete (#6286)
  * Document multi-tenant queries. (#5994)
  * operator: Add ruler config support (#6195)
  * Loki: add a run-once flag to the compactor (#6281)
  * fix boltdb shipper local query in logcli and support `fake` tenant (#6282)
  * operator: Add support for custom S3 CA (#6198)
  * Move ingester metrics around (#6275)
  * Snyk SBOM workflow add (#6274)
  * add metrics for tracking index shipper operations (#6278)
  * update drone signature (#6277)
  * Update docs for xk6-loki log formats (#6134)
  * Add duration filter unit test (#6271)
  * use tsdb config for initializing index gateway client (#6267)
  * Documentation: Explain --config.expand-env=true double slash with slash substitution (#6139)
  * Fix wording about pattern parser (#6264)
  * docs: Add Nomad deployment examples (#6258)
  * operator: Document how to connect Grafana to gateway (#6250)
  * Fix delete updates (#6194)
  * update drone branch match for 3 digit k release (#6263)
  * feat: Add support for Azure user assigned identity (#5891)
  * Memberlist related jsonnet (#6253)
  * docs: Default loki service port. (#6212)
  * Loki mixin: publish compiled version of the mixin (#6254)
  * Add jsonnet tools to build image (#6255)
  * chore(cache): Make exprimental messages more clear for cache. (#6219)
  * feat(ruler): support alert relabeling (#6220)
  * Docs: Reimplement PR 5649 on troubleshooting timeout errors (#6183)
  * Migrate Tool: Update to work with boltdb-shipper, improve logging output. (#6237)
  * Fix the signature for substr (#6236)
  * Add upgrade guide regarding azure container name change (#6118)
  * make boltdb-shipper use the generic indexshipper for managing index in object storage (#6226)
  * Add NRC in Adopters (#6242)
  * [Promtail] drop lines with malformed json (#6099)
  * Runtime reloadable config; ring migration setup (#6214)
  * Tsdb/inverted index (#6233)
  * Remove __name__ from label calls (#6229)
  * Improve labels computation during LogQL pipeline (#6110)
  * Fix label extraction pushdown on instant queries (#6215)
  * operator: Add rules support (#5986)
  * Docs: Hint about potential high cardinality metrics (#5603)
  * docs: describe ordering in http query results (#6024)
  * Docs: Fix design docs index page (#6008)
  * run store queries in ingester when using tsdb as index store (#6209)
  * prevents sharding avg and avg_over_time when their children arent shardable. (#6204)
  * docs: Fix broken link from unpack parser to pack stage (#6207)
  * doc(storage-example-configs): AWS single store configs (#6196)
  * Loki: Modifies TableManager to use IndexGateway ring (#5972)
  * Rename fudge_duplicate_timestamp to be increment_duplicate_timestamp (#6120)
  * creates a single tsdb for entire wal recovery (#6203)
  * copy all the fixes/improvements that went into boltdb-shipper that are missing from generic index-shipper (#6200)
  * operator: Changing GCP secret file path (#6199)
  * [loki microservices]: allow custom gateway server configuration (#6138)
  * Change deletion_enabled setting to deletion_mode (#6190)
  * Fix CHANGELOG entries. (#6193)
  * security: Redact credentials when marshalled to YAML (#6186)
  * Fix flaky gRPC server shutdown in tests (#6191)
  * tsdb index gateway (#6158)
  * strips out tenant label from LabelNames queries (#6181)
  * Add integration test for delete request (#6188)
  * Fixed reader to support both authentication and tenant-id at the same time. (#5719)
  * Fix typo in operator/docs/hack_operator_make_run.md (#6180)
  * tsdb creation supports fingerprint overrides (#6178)
  * skip empty object key returned by some s3 compatible storage while listing boltdb-shipper index (#6123)
  * fix(querier): Record `result` length after response validation. (#6176)
  * query-scheduler: Now proper support for `querier_forget_delay` (#6174)
  * ruler: Add support for alertmanager header authorization (#6136)
  * fix(tanka): add customizable common env vars (#6124)
  * Update SSL config for cassandra (#6145)
  * feat: support simple selection of labels in json expr parser (#6151)
  * Bump golangci/golangci-lint-action from 3.1.0 to 3.2.0 (#6170)
  * LogQL: add the `default` sprig template function to logql label/line formatter (#6163)
  * update auth header env variable usage help (#6169)
  * Add docs for updated deletion api (#5763)
  * specify logcli authorization header by flag (#6164)
  * corrected copy&paste error in list of labels (#6146)
  * Removed double space in Log (#6166)
  * tsdb query fixes (#6142)
  * operator: Add method to get authenticated from GCP (#6125)
  * Loki: When processing logs during tailing, don't reuse the query pipeline (#6152)
  * Fix certain binary expression queries by optimizing through push down (#6132)
  * Docs: redo PR 5109 (#6119)
  * Bump k8s.io/api, k8s.io/client-go, k8s.io/apimachinery from 0.22.7 to 0.23.6 (#6037)
  * Remove unused grpc health check endpoints (#6113)
  * loads previously created TSDBs into shipper on startup (#6117)
  * fix mutability bug with labels during tsdb flushing (#6116)
  * operator: Ruler enhancement proposal (#5985)
  * Tsdb/head wal feedback (#6107)
  * Document `/services` API endpoint (#6111)
  * do not increment sync operation count metric on per index set (#6109)
  * Update consistent hash ring docs with new index gateway ring (#6041)
  * Feat: add Baidu Cloud BOS as storage backends for Loki #4788 (#5848)
  * Serve correct status of ingester/distributor in gRPC healthcheck endpoint (#6094)
  * lambda-promtail: Add multi-tenancy support (#6102)
  * TSDB shipper + WAL (#6049)
  * clean up the pr diff message (#6098)
  * Revert "Loki: Change live tailing to only allow mutating the log line not the number of streams. (#6063)" (#6097)
  * Revert "Docs: fix pic location in `sources/fundamentals/architecture/deployment-modes.md` (#6089)" (#6093)
  * docs: update the labels timespan info (#6019)
  * Introduce coverage to PR pipelines (#5357)
  * `metrics.go` support for metadata queries(labels and series) (#5971)
  * table_manager: Change some level.Info() logging to level.Debug() (#6076)
  * Docs: fix pic location in `sources/fundamentals/architecture/deployment-modes.md` (#6089)
  * Remove nosiy "inflight" requests log entries (#6074)
  * Docs: remove Cortex references (#6079)
  * fix labeler (#6087)
  * renames skip -> ok in ProcessString (#6064)
  * Fix(query-frontend): LokiCodec encode/decode works correctly with label values endpoint (#6084)
  * Auto add labels on new pull request (#6065)
  * Add integration tests which test happy path (#5968)
  * Add UDP protocol support to Promtail's syslog target (#5790)
  * Loki: Change live tailing to only allow mutating the log line not the number of streams. (#6063)
  * Fix(query-frontend): `/label/<name>/values` endpoint to use right set of middlewares (#6072)
  * Bump actions/checkout from 2 to 3 (#5558)
  * Added NLog-Targets-Loki as unofficial C# client to Loki (#6061)
  * Fix broken link on deployment-modes.md (#6068)
  * allow more time for boltdb-shipper index syncs to finish (#6071)
  * promtail: Add support for exclusion patterns in `static_config` (#5943)
  * Update Loki reads/writes resources dashboards (#5765)
  * Add dot to some DNS address to reduce lookups (#5789)
  * Promoto policyRule to v1 (#6003)
  * Update libsystemd-dev from bullseye-backports for arm32 docker images, fixes (#5938) (#6012)
  * Bump github.com/minio/minio-go/v7 from 7.0.10 to 7.0.24 (#6007)
  * Use quiet flag in logcli tail.go. (#6033)
  * Add missing changelog entry for change introduced by PR 6034. (#6040)
  * boltdb shipper index list cache improvements (#6054)
  * Docs: Improve wording of getting started guide (#6060)
  * Add tailing metrics (#6059)
  * ignores reporting cancellations as errors in the usage-reporter module (#6058)
  * Improve index entries deduping and concurrency (#6055)
  * Add metrics to range mapper (#6030)
  * Improve batching in boltdb index (#6044)
  * Decrease log level for "failed to put to memcached" (#6018)
  * Add IndexGateway Query Readiness Duration panel to `Loki - Reads Resources` dashboard in production/loki-mixin (#6014)
  * Ensure proto definitions are formatted [2/2] (#6000)
  * docker-compose: Disable auth in Grafana (#5998)
  * Add filter parameter to rebound so lines can be deleted by the compactor (#5879)
  * operator: Merge gh index page with README.md to link to docs (#6048)
  * Improve series store index queries (#6045)
  * Upgrade inet.af/netaddr (#6046)
  * Docs: PR 5387 redo - Warn ECS users to avoid plain text creds (#6051)
  * Add query scheduler to "Read Resources" mixin dashboard (#6028)
  * Docs: revise getting started guide (#5939)
  * Minor fixes in docs/sources/api/_index.md (#5915)
  * Add better observability to queryReadiness (#5946)
  * Loki: Add a configurable ability to fudge incoming timestamps for guaranteed query sort order when receiving entries for the same stream that have duplicate timestamps. (#6042)
  * Revendor `grafana/tail` to fix promtail symlink behavior (#6034)
  * Remove empty match within concat of regex (#6026)
  * Disable calling new index-gateway client's API. (#6025)
  * operator: logerr v2 update (#5987)
  * Remove references to cortex (#6015)
  * migrated gelfTarget to go-gelf/v2 library that contains fix for chunked messages (#5992)
  * Add buf to the build image (#5785)
  * Use new build image 0.20.3 (#5904)
  * Invalidate caches on delete (#5661)
  * Querier: prevent unnecessary calls to ingesters (#5984)
  * Add string representation of boltdb shipper mode (#5982)
  * fix: remove typo in gateway config (#5981)
  * Call correct method on index store (#5979)
  * Do not parse string of empty matchers (#5980)
  * Add changelog entry for split by range of instant queries (#5966)
  * redact s3 credential values when printing config to logs (#5961)
  * Loki: Make DNS resolver configurable in Gateway (#5973)
  * Add query filtering to the tailer (#5969)
  * Fix query filtering (#5951)
  * Other: Update pr template (#5885)
  * Other: trigger build of loki-build-image:0.20.3 (#5924)
  * fix index gateway chunk refs response (#5957)
  * operator: Bump operator-sdk to v1.19.1 (#5929)
  * Other: Improve check-drone-drift script (#5925)
  * common index set should not expire before any of the user index sets (#5954)
  * [promtail] Add a log message stating that client level stream lag labels are deprecated (#5850)
  * chore: Fix flaky test with `TestSingleIdx`. (#5947)
  * Docs: Fix typo in 429 exceeded rate limit error message (#5944)
  * build generic index shipper to be shared between boltdb-shipper and tsdb-shipper (#5705)
  * Query filtering in the ingester and storage (#5629)
  * store: fix bug in getting chunk ids from ingesters when using boltdb-shipper (#5945)
  * Update _index.md (#5934)
  * Update CHANGELOG.md (#5935)
  * Add SIG operator team to governance doc (#4977)
  * Fix SSD Docker installation (#5916)
  * Loki: Fix issue with recent change to flush code (#5932)
  * Implements TSDB Head (#5864)
  * Fixes the index-gateway when using the ring (#5923)
  * Include tenant ID label in label values. (#5908)
  * Only run boltdb-shipper when appropriate. (#5917)
  * Fixes a panic when response is nil in the index-gw (#5910)
  * operator: Do not include non-static labels in pod selectors (#5907)
  * operator: Align PVC storage size requests for all lokistack t-shirt sizes (#5893)
  * Loki: Flush chunks one at a time (#5894)
  * Update golangci-lint in build image (#5901)
  * Introduce a more scalable index-gateway API. (#5892)
  * Do not use boltdb-shipper if no ring or address are given. (#5902)
  * Raise version of build image correctly (#5900)
  * docs: fix query_ingester_only config (#5873)
  * Enable tenant ID selection for multi-tenant queries. (#5821)
  * Upgrade golang version to v1.17.9 (#5899)
  * Add a Ring to IndexGateway (#5358)
  * loki: Fix common config net interface name overwritten by ring common config (#5888)
  * Update _index.md (#5887)
  * Update _index.md (#5871)
  * operator: Update Loki operand to v2.5.0 (#5884)
  * Add more function comments to the rangemapper implementation (#5861)
  * remove excessive underscore from `dockerLabelLogStream` (#5890)
  * Return HTTP 400 when multiple tenants are present in push. (#5800)
  * Docs: Improve the new schema docs (#5869)
  * Update dskit to v0.0.0-20220331160727-49faf69f72ca. (#5881)
  * document flag for disabling broad index queries (#5880)
  * [promtail] Mark promtail single client config flags and config file block as deprecated (#5842)
  * GCS: refactor creation of http client (#5838)
  * Minor fix in docs/sources/logql/log_queries.md (#5868)
  * Bump actions/setup-go from 2 to 3 (#5859)
  * Improve kafka discovery test. (#5860)
  * Fix flaky test (#5307)
  * Docs: Add usage reporting section to 2.5 release notes (#5865)
  * add some docs for working with the storage schema (#5863)
  * fix: adopters link for Heureka Group (#5862)
  * Moves TSDB to the stores package. (#5852)
  * Fix wrong indentation in example config (#5828)
  * promtail: Add ActiveTargets method (#5839)
  * Add Heureka Group to adopters (#5846)
  * lambda-promtail: fix typos in CloudFormation and Terraform files. (#5749)
  * Refactoring of the Loki storage (#5833)
  * Makefile: run lint and tests with default garbage-collection (#5841)
  * usagestats tests: don't check unpredictable number (#5840)
  * Fixes deduping when multiple timestamp are equal (#5799)
  * gcs client: use fake credentials in unit test (#5834)
  * TestPromtail: avoid hanging when test fails midway (#5837)
  * incorporate feedback on merged pr #5830 (#5831)
  * improve mutex locking when writing index in boltdb-shipper (#5830)
  * [Optimization] boltdb: reduce the code block affected by the lock tablesMtx in the TableManager.query() function. (#5829)
  * Split by range of instant queries (#5662)
  * try fixing drone again (#5826)
  * update drone to push images on tagged builds (#5824)
  * 2.5 changelog, release notes, and upgrade guide (#5819)
  * fix missing file during rpm and deb packaging step (#5818)
  * Tsdb/compaction (#5783)
  * storage: make Azure blobID chunk delimiter configurable (#5777)
  * Promtail docs: fix metrics stage. (#5740)
  * Add X4B as an adopter (#5795)
  * Return bad request for multi-tenant tail. (#5792)
  * fix boltdb-shipper doc (#5796)
  * Update alpine images to 3.15.4 (#5780)
  * Add a DeletionMode config variable (#5481)
  * Allow promtail to push RFC5424 formatted syslog messages (#5715)
  * golangci-lint: Check for pointers to enclosing loop variables (#5775)
  * Build: update package for fuzzer after refactoring (#5776)
  * Loki: Add more details about usage reporting to the docs and default config files. (#5767)
  * Loki: Revert #4845 which changed the format of errors from the API (#5772)
  * Docs: Document Promtail global rate limiting (#5737)
  * Increase flush_op_timeout to 10m, 10s is often much too short for a big WAL replay which can generate a lot of chunks very quickly. (#5768)
  * use an empty registry when setting up the logger for the push server (#5761)
  * operator: Update Prometheus go client to resolve CVE-2022-21698 (#5748)
  * [new] promtail pipeline:  Promtail Rate Limit stage #5048 (#5051)
  * ensure tsdb is sorted by hash then labelset (#5746)
  * operator: change uuids to tenant name in doc (#5739)
  * fixes existing test case and adds more (#5687)
  * Update MultiTenantQuerier `Series()` and `Label()` to use `user.InjectOrgID()` instead of `user.InjectUserID()` (#5735)
  * operator: Add missing label matcher for openshift logging tenant mode (#5729)
  * Implement `Series` and `Label` for MultiTenantQuerier (#5566)
  * Revert changes to generated assets_vfsdata.go. (#5728)
  * Use dskit/tenant intead of loki/pkg/tenant. (#5724)
  * Update fluent-bit output name (#5711)
  * Fixed Getting started docs error (#5504)
  * Docs: add an empty v2.5 release notes section (#5533)
  * Promtail: Fix retry/stop when erroring for out of cloudflare retention range (e.g. over 168 hours old) (#5698)
  * logcli: Remove port from TLS server name when provided in --addr (#5477)
  * Update docker repo to grafana/loki-query-tee (#5716)
  * Assert that push values tuples consist of string values (#5685)
  * Mark GELF support in Promtail as experimental (#5697)
  * Build querytee image as part of CI pipeline (#5700)
  * Update Fluent Bit docs (#5402)
  * operator: Fix immediate reset of degraded condition (#5691)
  * Update retention.md (#5706)
  * Promtail: Rename config name limit_config to limits_config (#5707)
  * operator: Update operator-sdk to 1.18.1 (#5704)
  * operator: Replace frontend_worker parallelism with match_max_concurrent (#5693)
  * operator: Fix multiple storage support for boltdb_shipper and schema (#5699)
  * Move promtail StreamLagLabels config to upper level config.Config (#5686)
  * operator: make replicationFactor optional (#5701)
  * Require unique client configs when there are multiple clients. (#5688)
  * operator: Update to Go 1.17 (#5695)
  * operator: Document how to connect to LokiStack gateway component (#5615)
  * operator: Update Loki operand to 2.4.2 (#5655)
  * Fix bug with new promtail stream lag metric where labels might not be (#5675)
  * Fix debug image by updating Delve version (#5673)
  * Speed up re-labelling in multi-tenant queries. (#5663)
  * Add Digitalist as adopter (#5596)
  * Fix broken Fluentbit / Fluentd plugin doc links (#5664)
  * operator: Update developer addons (#5599)
  * operator: Adding instructions to respond to alerts (#5579)
  * TSDB Index reuses slices, adds pools (#5630)
  * Tsdb/hash order (#5631)
  * Support limits in multi-tenant queries. (#5626)
  * Add inflight requests metric to scheduler (#5658)
  * operator: Update CSV to point to candidate channel and use openshift-operators-redhat ns (#5640)
  * operator: Document how to connect to distributor component (#5551)
  * Preserve interval parameter when splitting queries by time (#5622)
  * Introduce a ChunkRef type as part of logproto  (#5643)
  * improve boltdb-shipper logging to help debug index query latency issues (#5651)
  * Remove more chunkstore and schema version below v9 (#5650)
  * Remove more unused code (#5638)
  * debug log number of index entries cached and retrieved from the cache per index query (#5642)
  * Remove benchmark cron job. (#5641)
  * Remove unused code from cortex (#5633)
  * Remove unused storage gateway references (#5627)
  * Tsdb/sharding-benchmarks (#5628)
  * operator: Use tenant name as id for mode openshift-logging (#5624)
  * [Frontend] Log Result Cache (#5502)
  * [promtail] Refactor promtail client metrics so that we can't have duplicate metrics collected for the lag metric. (#5521)
  * Test multi-tenant context propagation. (#5620)
  * operator: Use recommended labels for LokiStack components (#5621)
  * Query Filtering -- Querier (#5482)
  * Refactor LogQL syntax into its own package (#5539)
  * operator: Use lokistack name as prefix for owned resources (#5607)
  * Update Prometheus to latest (#5545)
  * Print stacktrace to stderr for easier readability (#5616)
  * Replace `PromQL` -> `LogQL` wordings in Querier (#5602)
  * Tsdb/sharding (#5600)
  * Tsdb/multi idx (#5598)
  * Add RBAC for Prometheus service discovery to Loki component metrics (#5588)
  * canary: Adds locking to prevent multiple concurrent invocations of `confirmMissing` from clobbering each other (#5568)
  * bounds utility for tsdb lib (#5593)
  * more tsdb benchmarks + updates script to work with incompatible branches (#5590)
  * Compactor improvements (#5587)
  * Make Loki adopters visible in README (#5586)
  * cleanup common index source files at the end while compacting index with boltdb-shipper (#5585)
  * store tsdb bounds (#5582)
  * build a new batch while starting to process a bucket (#5580)
  * Tsdb/index interface (#5577)
  * operator: Change endpoints for generated liveness and readiness probes (#5576)
  * operator: Reorder changelog in descending order (#5572)
  * Docs: update documentation about "limit" param (#5540)
  * Fix frontend-worker error message (#5567)
  * operator: Add steps to check and run the prometheus rule tests in GitHub action (#5564)
  * Fix service monitor's server name for operaror metrics (#5560)
  * Refactor sharding engine to downstream engine (#5546)
  * operator: Add flag to create Prometheus rules (#5345)
  * Loki mixin: add DiskSpaceUtilizationPanel (#5552)
  * Docs: Fix broken link to "Matching IP addresses" (#5550)
- Rebase proper-data-directories.patch.
- Add missing paths into proper-data-directories.patch.
* Thu Jun 30 2022 Marcus Rueckert <mrueckert@suse.de>
- also track quilt series file to make it easy to setup a quilt
  working copy
* Thu Jun 30 2022 Marcus Rueckert <mrueckert@suse.de>
- also make the config file permissions more strict:
  /etc/loki/loki.yaml     root:loki u=rw,g=r,o=
  /etc/loki/promtail.yaml root:root u=rw,g=r,o=
* Thu Jun 30 2022 Marcus Rueckert <mrueckert@suse.de>
- default configs reference paths in /tmp. move those to proper
  places:
  loki data dir: /var/lib/loki loki:loki u=rwx,g=rx,o=
  promtail data dir: /var/lib/promtail root:root u=rwx,g=rx,o=
  Existing configs will not be updated
  Added proper-data-directories.patch
* Mon May 23 2022 ecsos@opensuse.org
- Update to version 2.5.0+git.1649366683.2d9d0ee23:
  * try fixing drone again (#5826) (#5827)
  * update drone to push images on tagged builds (#5824) (#5825)
  * [release-2.5.x] 2.5 changelog, release notes, and upgrade guide (#5823)
  * fix missing file during rpm and deb packaging step (#5818) (#5822)
  * Update Fluent Bit docs (#5402) (#5805)
  * Fixed Getting started docs error (#5504) (#5806)
  * Docs: update documentation about "limit" param (#5540) (#5807)
  * Make Loki adopters visible in README (#5586) (#5808)
  * Update retention.md (#5706) (#5809)
  * Update fluent-bit output name (#5711) (#5810)
  * operator: Document how to connect to distributor component (#5551) (#5811)
  * Fix broken Fluentbit / Fluentd plugin doc links (#5664) (#5812)
  * Mark GELF support in Promtail as experimental (#5697) (#5813)
  * Docs: Document Promtail global rate limiting (#5737) (#5814)
  * Release 2.5.x (#5817)
  * Preserve interval parameter when splitting queries by time (#5622) (#5815)
  * remove extra stuff accidentally added to changelog
  * [new] promtail pipeline:  Promtail Rate Limit stage #5048 (#5051) (#5793)
  * update docs references from 2.4 -> 2.5
  * Update changelog for 2.5 release
  * Promtail: Rename config name limit_config to limits_config (#5707) (#5788)
  * Update Prometheus to latest (#5545) (#5787)
  * Update alpine images to 3.15.4 (#5780) (#5786)
  * Fix frontend-worker error message (#5567) (#5781)
  * Promtail: Fix retry/stop when erroring for out of cloudflare retention range (e.g. over 168 hours old) (#5698) (#5782)
  * use an empty registry when setting up the logger for the push server (#5761) (#5762)
  * Increase flush_op_timeout to 10m, 10s is often much too short for a big WAL replay which can generate a lot of chunks very quickly. (#5768) (#5771)
  * Loki: Revert #4845 which changed the format of errors from the API (#5772) (#5774)
  * Loki: Add more details about usage reporting to the docs and default config files. (#5767) (#5778)
  * creating release branch for 2.5.x from k88
  * cleanup common index source files at the end while compacting index with boltdb-shipper (#5585)
  * build a new batch while starting to process a bucket (#5580)
  * updates clusterrole and clusterrolebinding apiVersions in promtail.sh (#5547)
  * Fix path to binary in Dockerfile for querytee (#5537)
  * update loki go version to 1.17.8 (#5543)
  * regexp filter: use modified package with optimisations (#5542)
  * Update vectorAggEvaluator to fail for expressions without grouping (#5544)
  * Update grafana/regexp package to reject very deeply nested regexps (#5541)
  * Change usagestats expvars so they can be set twice (#5515)
  * Revert "metrics: Add `user` label to `worker_inflight_queries` (#5485)" (#5534)
  * loki mixin: make labelsSelector in loki chunks dashboards configurable (#5536)
  * loki mixin: use labels selector for loki chunks dashboard (#5535)
  * Support `SelectLogs` and `SelectSamples` in multi-tenant querier. (#5517)
  * [bugfix] fix nil pointer (#5527)
  * Update metric_queries.md (#5525)
  * Fix orphaned metrics in the file tailer (#5497)
  * Update Pub/Sub docs section (#5205)
  * fix broken index gateway benchmark due to missing limits (#5520)
  * Lambda-promtail: add basic auth support (#5503)
  * Update out_loki.rb (#5512)
  * [operator] Update ClusterServiceVersion to add missing configurations (#5467)
  * Fix port name used for GRPC service (#5489)
  * Add prefix to vault path (#5510)
  * Fix test (#5509)
  * Remove extra param in call for inflightRequests metric (#5507)
  * Change path for deploy config (#5506)
  * Bump google.golang.org/api from 0.63.0 to 0.65.0 (#5135)
  * Align usage report config with Grafana (#5406)
  * Stub multi tenant querier. (#5490)
  * Replacing cortex_bigtable* metrics with the correct loki_bigtable* metrics (#5500)
  * Changelog: Include #5409 (#5480)
  * CI: moving autodeploy configuration secret to new location (#5491)
  * Bump golangci/golangci-lint-action from 2 to 3.1.0 (#5488)
  * metrics: Add `user` label to `worker_inflight_queries` (#5485)
  * Docs: Fix links and formatting of HTTP API page (#5498)
  * Docs: fix link reference to "Step vs Interval" section. (#5495)
  * initialize overrides when running index gateways which is required to run them (#5496)
  * mount overrides volume to index gateways (#5493)
  * Document all support API timestamp formats. (#5439)
  * Fix potential deadlock in the table manager (#5472)
  * per user index query readiness with limits overrides (#5484)
  * Rounds chunk bytes to kb in tsdb and includes benchmarking script (#5479)
  * promtail/targets/syslog: Enable best effort parsing for Syslog messages (#5409)
  * Fixes Reads dashboard boltdb panels. (#5475)
  * Stream query responses from boltdb index client (#5468)
  * Fix circular dependencies (#5420)
  * Disable sharding of count/avg when labels are mutated (#5474)
  * Fixes ingester sample deduping (#5470)
  * Add support for additional storage backends in operator (#5432)
  * boltdb shipper index gateway client improvements (#5456)
  * Update _index.md (#5458)
  * Fix two remote_timeout configs in ingester_client block (#5418)
  * logproto: Add deprecated annotation to LegacySample and LegacyLabelPair (#5454)
  * use the defined querypages callback in all the types implementing QueryPages function from IndexClient interface (#5463)
  * Change default installation namespace on OpenShift (#5441)
  * Do not insert point when missing when sharding (#5444)
  * Update loki-mixin/dashboard-loki-operational queries to correctly display Loki metrics for Memcache and Consul (#5462)
  * Tsdb/idempotent builder (#5424)
  * pkg/ruler/base: Add external_labels option (#5450)
  * Fix operational dashboard (#5448)
  * add a metric for tracking the duration it took to sync the tables in queriers/index-gateways (#5446)
  * Adds a tool for converting boltdb->tsdb and benchmarking queries (#5430)
  * do not send grpc responses concurrently from index-gateway (#5445)
  * Build: simplify make targets to just run every time (#5411)
  * Parse duration expressions in accordance with promql (#5275)
  * set match_max_concurrent true by default (#5435)
  * jsonnet: move boltdb-shipper configs set as compactor args to yaml config (#5393)
  * Do not use WaitGroup context for StepEvaluator (#5425)
  * Use output plugin grafana-loki (#5386)
  * Correctly sets hash value for headblock iterator (#5423)
  * Adds bytes and entries to chunk metadata in tsdb (#5414)
  * remove promtail_log_entries_bytes_bucket (#5377)
  * Lambda-promtail: Enhance lambda-promtail to support adding extra labels from an environment variable value (#5359)
  * Revert to working version of Azure client (#5413)
  * Run `make drone` to use the new build image (#5368)
  * Update dskit version (#5392)
  * Fixes double metrics registration in reporting (#5407)
  * Experimental TSDB index (#5376)
  * Add the total number of subqueries to query statistics (#5397)
  * [operator] Add degraded condition when gateway is enabled and tenants spec is nil (#5383)
  * Cleaning up deploy-example-secret.sh (#5374)
  * Fix Azure issue where 404 not recognized (#5399)
  * Logql: Correct grouping type in pkg/logql/expr.y (#5306)
  * Add more context to tailer-> ingester connect error. (#5394)
  * Loki: include the component in metrics.go log line (#5379)
  * Verify that drone.yml was updated. (#5396)
  * add more context to logs, improve comments for clarity in boltdb-shipper code (#5341)
  * Fixes a flaky hedging test. (#5389)
  * cleanup common index set after cleaning up all the user index sets (#5372)
  * updated documentation for xk6-loki extension (#5321)
  * Fixes memberlist usage report (#5369)
  * Build and publish build image. (#5322)
  * Improve report usage to never fail (#5364)
  * Add usage report into Loki. (#5361)
  * Ruler: Rule group not found API message (#5362)
  * add a ms instead of ns to end time of the rebound chunk interval (#5351)
  * fix rounding of time to milliseconds (#5352)
  * Speed up `EntrySortIterator` by 20%%. (#5318)
  * Test `LegacySample` and `LegacyLabelPair` compatibility. (#5313)
  * fix changelog issue reference to lambda-promtail (#5347)
  * Fix apply retention issue (#5342)
  * Delete docs/sources/copyright directory (#5325)
  * Revert "Simplify code for write path in distributor (#5248)" (#5337)
  * Makes `tailer.droppedStreams` slice bounded. (#5334)
  * filters: use faster regexp package (#5315)
  * Release entryBufferPool once (#5324)
  * lambda-promtail: Add ability to ingest logs from S3 (#5065)
  * Docs: remove "regular" from string definition (#5309)
  * Documentation for load testing Loki with xk6-loki (#5182)
  * Simplify code for write path in distributor (#5248)
  * Fixes log deduplication when mutating Labels using LogQL (#5289)
  * Logql/parallel binop (#5317)
  * Add tooling for local k3d clusters under tools/dev (#5272)
  * added upgrade notes (#5311)
  * Update promtail to support duration string formats (#5290)
  * changed logic to respond with '500 Internal Server Error' if rpc error with code 'Cancelled' happened.
    it's made to allow loki to retry the request to the querier instead of returning '499 The request was
    cancelled by the client.' back to the client. (#5297)
  * storage: update azure blobstore client to use new sdk (#5302)
  * Fix transitive dependency error (#5308)
  * less opaque chunk keys on fs with v12 (#5291)
  * cleanup: consolidate util strings contain functions (#5304)
  * Implement `LegacySample`, `LegacyLabelPair` proto messages (#5301)
  * Fix `go.mod` path of operator (#5287)
  * better logic for when to shard wrt disabled lookback (#5303)
  * fix a panic in index-gateway caused by double closing of a channel (#5298)
  * Fix Promtail watching deadlock (#5283)
  * Link `replace` pipeline stage to doc (#5200)
  * Write Promtail position file atomically. (#5266)
  * Restart Docker target if stopped. (#5280)
  * Refactor HeapIterator into Merge and Sort Iterator. (#5281)
  * logstash: re-add bundle update and update bundler (#5284)
  * Revert "Adding a docs page that helps users understand memberlist a bit more (#5186)" (#5286)
  * Cleanup `util/validation` code. (#5285)
  * add some timing to the logs for downloading and opening index tables (#5042)
  * Auto-expire old items from FIFO cache (#5148)
  * Adding a docs page that helps users understand memberlist a bit more (#5186)
  * Update local configs to fix issues with incorrect addresses (#5207)
  * Promtail docs: Fix link to `unpack` LogQL documentation (#5274)
  * Return early if push payload does not contain data (#5229)
  * Remove `cortex` references from `go.mod` and makefile (#5269)
  * Copy `cortex/pkg/storage/bucket` package dependency into Loki (#5258)
  * Fix transitive dependency failure while building logstash plugin (#5268)
  * feat(promtail): fix TargetManager.run() not exit (#5238)
  * Remove `cortexpb` dependency from Loki packages. Use only `logproto` now. (#5264)
  * Logstash: Add config option which allows seting up an allowlist for labels to be mapped to Loki (#5244)
  * Fork `cortex/pkg/util` into Loki (#5257)
  * Ingester: remove the labelFilter (#5262)
  * use default retention period to check user index may have expired chunks when user does not have custom retention (#5261)
  * fluent-bit: Attempt to unmarshal nested json. (#5223)
  * Refactor/remove global splitby (#5243)
  * Copy `cortex/pkg/configs` package dependency into Loki (#5139)
  * Copy `cortex/pkg/ingester/client` package dependency into Loki (#5164)
  * Get rid of Cortex chunk. (#5239)
  * Push: add deflate compression in post requests (#5249)
  * refactor: use `T.TempDir` to create temporary test directory (#5253)
  * v12 chunk format handling in retention (#5254)
  * Fix docker plugin build (#5240)
  * Update Go version to latest and bump build image version (#5250)
  * Update _index.md (#5241)
  * skip glob search if path is an existing file and not a directory (#5246)
  * Lock consistencyMtx outside locking chunkMtx (#5210)
  * Update _index.md (#5159)
  * Remove ErrStreamMissing (#5234)
  * Update loki-mixin gcs queries in the Loki operational dashboard (#5232)
  * Start refactor of storage (chunks) clients metrics into structs (#5057)
  * Fix `cortexpb` -> `logproto` rename in some tests (#5231)
  * [querier] Abort a query in limitedRoundTripper if parallelism is 0 (#5190)
  * Bump logstash plugin gem (#5230)
  * Provide Docker target and discovery in Promtail. (#4911)
  * Improve docs on how to install logcli from source (#5126)
  * Add `MaxSurge` and `MaxUnavailable` strategy to all Loki k8 workloads. (#5227)
  * Copy `cortex/pkg/cortexpb` package dependency into Loki (#5151)
  * Copy `cortex/pkg/prom1` package dependency into Loki (#5196)
  * Update to Unofficial clients for JS (#5180)
  * Addition of cortex' queryrange tests (#5183)
  * Default max_outstanding_per_tenant to 2048 (#5204)
  * [instrument] cache: add tracing instrumentation when error !=nil (#5202)
  * Update Loki Team members in the Governance doc. (#5219)
  * fix broken boltdb-shipper test (#5222)
  * step align start and end time of the original query while splitting it (#5217)
  * per user index changes on the write path (#5193)
  * Copy `cortex/pkg/chunk/purger` package dependency into Loki (#5169)
  * Update docker.md (#5213)
  * Remove instance level streams lock (#5179)
  * Chore: Add pkg/util/log package (#5187)
  * [enhancement] querier : Add "query_memory_only" to make loki have option to rely only on memory availability like google monarch. (#5093)
  * changes on read path for supporting per user index with boltdb-shipper (#5073)
  * add objects list caching for boltdb-shipper index store to reduce object storage list api calls (#5160)
  * Remove temporary ruler ring key fix (#5189)
  * log headblock conversion error during replay cleanup (#5185)
  * Support `X-Query-Tags` in LogCLI (#5145)
  * align metric queries by step and other queries by split interval (#5181)
  * Avoid splitting large range vector aggregation. (#5172)
  * Move VerifyConfig after PrintConfig and LogConfig (#5149)
  * Handle `context` cancellation in some of the `querier` downstream requests (#5178)
  * Copy `cortex/tools/querytee` package dependency into Loki (#5165)
  * Support "POST" method for distributor ring (#5171)
  * Fix promtail deadlock (#5170)
  * Package logcli as rpm and deb. (#4667)
  * Add nil check for Ruler BasicAuth config. (#5168)
  * Fix encoding error in fluentd client (#5163)
  * Retry pulling Cloudflare logs after a stream error (#5158)
  * revert operator's loki-config changes (#5155)
  * [optimization] cache prometheus : fix "loki_cache_request_duration_seconds_bucket" ‘status_code’ label always equals "200" (#4891)
  * Docs: Update memory ballast documentation (#5106)
  * Ruler: Fix remote write basic auth credentials (#5144)
  * Fix broken `template_variable` doc link (#4960)
  * Remove unused `storegateway` base (#5141)
  * Fixes operational dashboard and add azure. (#5127)
  * Fix test in retention/expiration_test.go on slow machines (#5137)
  * add jsonnet for simple scalable deploymnet (#5138)
  * Querier worker/inflight metrics (#5124)
  * Jsonnet: Let compactor access the runtime_config (#4855)
  * Copy `cortex/pkg/querier` package dependency into Loki (#5122)
  * Document query limit parameter default. (#5133)
  * Bump github.com/klauspost/compress from 1.13.6 to 1.14.1 (#5134)
  * Bump github.com/fatih/color from 1.12.0 to 1.13.0 (#5111)
  * Fix cancel issue between Query Frontend and Query Schdeduler (#5113)
  * remove split_queries_by_interval validation (#5125)
  * Add missing forked gateway tests (#5118)
  * Update to 2.4.2 release (#5121)
  * Copy `cortex/pkg/querier/stats` package dependency into Loki (#5047)
  * Docs: Draft 2.4.2 release notes (#5105)
  * Copy querier subpackages dependency into Loki (#5068)
  * Copy `cortex/pkg/ruler` package dependency into Loki (#5089)
  * fluentd: Fix bug that caused lines to be dropped when containing non utf-8 characters (#5107)
  * Docs: Fix documentation with correct default values and add missing options (#4792)
  * Update Docker compose example (#4996)
  * Fixes HTTP2 removal for GCS (#5103)
  * update helm docs, add simple scalable (#4925)
  * Enable merge union strategy for CHANGELOG.md. (#5102)
  * improve default config values (#5077)
  * Bump github.com/pierrec/lz4/v4 from 4.1.7 to 4.1.12 (#5100)
  * better defaults for flush queue parallelism (#5091)
  * Bump github.com/mitchellh/mapstructure from 1.4.2 to 1.4.3 (#5101)
  * Fixes metric name for hedging object store requests (#5098)
  * [enhancement] querier cache: WriteBackCache should be off query path (#5083)
  * Handle `context` cancellation in some of the `querier` downstream requests (#5080)
  * LogQL: add __line__ function to | line_format template (#4879)
  * Add the option to configure memory ballast for Loki (#5081)
  * Copy `cortex/pkg/storegateway` package dependency into Loki (#5088)
  * Removes split-by upstream validation (#5087)
  * Chore: Upgrade to latest Cortex (#5085)
  * Fix deadlock in disconnecting querier (#5063)
  * Fixes a possible cancellation issue (#5075)
  * Docs: Revise hedging configuration block descriptions (#5069)
  * expand ruler ring section to add num_tokens property (#4899)
  * Simpler new chunk key v12 (#5054)
  * compactor changes for building per user index files in boltdb shipper (#5026)
  * Add an egress bytes total metric to the azure client. (#5067)
  * Define Ingester interface to enable wrapping. (#4988)
  * [new] promtail: add readline rate limit (#5031)
  * Fix race conditions in frontend_scheduler_worker. (#5060)
  * Store metrics queueTime in seconds (#5052)
  * Docs: add an empty subsection for v2.4.2 bug fix items (#5056)
  * Chore: Remove `cortex/util/test` dependency (#5050)
  * Remove `cortex/pkg/util/extract` dependency from Loki (#5049)
  * Copy `cortex/pkg/frontend` package dependency into Loki (#5044)
  * lock the mutex before working with the `fileEventWatchers` (#5043)
  * Improve error message if incoming logs timestamp is far too behind. (#5040)
  * Loki: Implement common net interface/instance addr (#4950)
  * Improve title of the chunk dashboard. (#5041)
  * Chore: Copy `cortex/util/math` into Loki (#5036)
  * Remove unnecessary ticker in the tail loop (#5039)
  * Fix typo 'Registring'->'Registering' (#4979)
  * Promtail: exclude_user_data description fix (#5038)
  * Support Redis Cluster Configuration Endpoint (#4947)
  * Update hack_operator_make_run.md (#5025)
  * Log time in queue per request (#4949)
  * Pre-allocate chunk buffer size (#4884)
  * Docs: revise block names (ring and filesystem) and correct spelling (#5015)
  * temporary fix for the ruler joining the ingester ring (#4968)
  * feat(docs): auto assign type/docs label to docs project (#5032)
  * Chore: use `spanlogger` from `dskit` (#5029)
  * Docs: improve Promtail installation prose (#5017)
  * [new feature] logql: extrapolate unwrapped rate function (#5013)
  * Allow to disable http2 for GCS. (#4942)
  * Add distributor ring page (#4938)
  * adds instrumentation to azure object client (#5022)
  * Copy `cortex/pkg/scheduler` package dependency into Loki (#4962)
  * Copy `cortex/pkg/ruler/rulestorage` package dependency into Loki (#4978)
  * Copy `cortex/pkg/distributor` package dependency into Loki (#4983)
  * Add doc for limit param max_concurrent_tail_requests (#5011)
  * Copy `cortex/pkg/querier/astmapper` package dependency into Loki (#4982)
  * Move querier.split-queries-by-interval to a per-tenant configuration (#5023)
  * Docs: SSD mode read target runs the compactor (#5016)
  * Remove querier.query-ingesters-within check when sharding is enabled (#5024)
  * docs: fix yaml grammar mistakes (#5027)
  * fix splitting of queries when step is larger than split interval (#5006)
  * update promtail daemonset docs (#4946)
  * Docs: Fix parent of wal and wal_cleaner in loki ruler config docs (#4993)
  * Move `min_sharding_lookback` to the right place. (#5007)
  * Docs: Fix list of Ruler supported storages (#5008)
  * Update syslog receiver documentation (#5003)
  * Docs: add initial descriptions of Loki use of hash rings (#4900)
  * Add default tags for docker-compose (#4916)
  * Update _index.md (#4893)
  * Docs: fix callouts for images in the Deployment modes section (#4992)
  * update docs preview commands (#4955)
  * Provide saner default for loki-operator managed chunk_target_size (#4975)
  * Fix logo on operator README.md (#4984)
  * add docker compose example for simple scalable mode (#4876)
  * Fix operator entrypoint markdown files (#4976)
  * Provide optional matchers to `LabelValuesForMetricName`. (#4933)
  * Fix operator images actions for bundle and calculator (#4973)
  * Copy `cortex/util/fakeauth` package dependency into Loki (#4956)
  * Provide saner defaults for loki-operator reconciled config (#4963)
  * Fix failing operator github actions (#4966)
  * Fix operator action for sending code coverage (#4965)
  * Fix operator actions branch protection from master to main (#4964)
  * Move `cortex/pkg/tenant` dependency to Loki. (#4944)
  * Switch provider from Red Hat to Grafana Loki SIG operator
  * Switch API group from openshift.io to grafana.com
  * Add missing index-gateway to pod status map
  * Remove ViaQ from source code and manifests
  * Prune ViaQ references from documentation resources
  * Remove old license references
  * Make `go test` command replaceable in Makefile (#4934)
  * Correctly use limits middleware in series query (#4929)
  * Add copyright notice (#4898)
  * feat(): add ManagedIdentity in Azure Blob Storage (#4858)
  * Update logstash dependency in logstash-output-loki plugin (#4930)
  * Document correct filesystem config options in reference (#4928)
  * Skip middleware for unsupported type (#4924)
  * Docs: Fix comment in Loki module loading for accuracy (#4926)
  * Add `-list-targets` command line flag (#4920)
  * Remove duplicated code in ruler rule validation (#4903)
  * ingester: use consistent set of instances (#4904)
  * Fixes 500 when query is outside of max_query_lookback (#4902)
  * dashboards: fix typo in row title (#4894)
  * Update hedgedhttp to v0.7.0 (#4892)
  * Docs: Reorganize architecture section (#4873)
  * Fix shellcheck issues
  * Move github actions to top-level github directory
  * Switch license to AGPL v3
  * Revert "Adding PR gatekeeper (#4869)" (#4880)
  * LOG-1894: Update Loki Operand to 2.4.1 (#106)
  * add multiline to stages overview (#4851)
  * always apply replication factor common config (#4875)
  * Fix replace missing adjacent capture groups (#4874)
  * stats were logged without a log level making them not correctly filterable. (#4872)
  * LOG-1947: Provide Dev Preview Docs on how to use `make run` on loki-operator (#107)
  * Promtail pull cloudflare logs (#4813)
  * Adding PR gatekeeper (#4869)
  * Add rate limiting and metrics to hedging (#4860)
  * Fix duplicate registry.MustRegister call in Promtail Kafka (#4866)
  * Change error responses from plain text to JSON (#4845)
  * recreate compacted boltdb files from compactor when they are more than 12 hours old (#4853)
  * fixes for operational and promtail dashboard (#4856)
  * Simplify chunks dashboard label selectors + port some more internal (#4850)
  * log the user ID in the rate limit error message. (#4852)
  * Lint Loki and Promtail mixins. (#4848)
  * Adds the ability to hedge storage requests. (#4826)
  * Correctly set string in env variable in jsonnet (#4847)
  * Allow to set JAEGER_REPORTER_MAX_QUEUE_SIZE globally. (#4843)
  * Reduce tracing spans (#4842)
  * Allow for setting of per-tenant runtime configs (#4840)
  * Set alert to fire after 15m, to match message (#4839)
  * Loki mixin: Add grafonnet-lib as dependency (#4811)
  * Use http prefix path correctly in promtail (#4832)
  * Use dependabot to keep gomod dependancies up to date. (#4834)
  * Add a stat panel function so we can more easily create grid layouts via (#4836)
  * Refactor pkg/util/server to avoid cortexpb import in downstream projects vendoring logql (#4833)
  * Improve LogQL format stages requireLabel (#4769)
  * Loki: Implement custom /config handler (#4785)
  * Refactor tests of Promtail filetarget (#4802)
  * Add LabelFilterer and Store wrapper (#4818)
  * Upgrade Cortex, Prometheus and Thanos (#4830)
  * Add support for `X-Query-Tags` (#4814)
  * Enhance logging on timeout tailing logs on canary (#4825)
  * LOG-1874: lokistack-gateway component restarting too many times on OpenShift (#100)
  * Set correct `Content-Type` header in query response (#4828)
  * Use common args in compactor and index-gateway (#4824)
  * Fix up a merge conflict on log filter (#4815)
  * [doc] wal: fix default value (#4810)
  * LOG 1838: Adding Promtail, Fluentd, and Openshift Logging docs (#104)
  * Do not run manifest and deploy jobs in cron. (#4772)
  * Refactor dashboard utils to include a separate function per template (#4807)
  * [doc]: Update URL for LokiLogger.jl (Julia client) (#4784)
  * [Hot Fix] Merge improving case sensitive search correctly (#4804)
  * Improve case insensitive search to avoid allocations. (#4394)
  * Aggregate inotify watcher to file target manager (#4794)
  * Docs: Modify label names of configuration blocks (#4787)
  * LOG-1840: Dev Preview Docs on how to get started with hacking on loki-operator (#99)
  * Improve heap iterators. (#4731)
  * Expose Kafka message key in labels (#4745)
  * Make `*` and `+` non-greedy to double regex filter speed. (#4775)
  * Minor operational dashboard improvements + fix missing log template (#4780)
  * add logging in querier when live tailing request starts and ends (#4783)
  * Logql `stdin` support only log queries (#4606)
  * Docs: fix broken links (#4770)
  * Run all benchmarks. (#4742)
  * Only run benchmarks on `loki-bench` cron. (#4753)
  * LOG-1955: Dev Preview Doc to install storage size calculator on OpenShift (#105)
  * Adding upgrade guide for recording rules (#4751)
  * Enrich WAL folder creation error message (#4705)
  * Loki: Set querier worker max concurrent regardless of run configuration. (#4761)
  * Docs: inject newlines into knob descriptions to avoid horizontal scroll bar (#4733)
  * Removes all GRPC warning. (#4757)
  * Add storage size calculator (#95)
  * Promtail: improve GCP labels (#4628)
  * index cleanup fixes while applying retention (#4741)
  * Add northflank to the adopters list (#4729)
  * Add GELF support for Promtail. (#4744)
  * Give more context to rule parser errors. (#4730)
  * Join contain filters into one. (#4528)
  * allow applying retention at different interval than compaction with a config (#4736)
  * Improves memchunk benchmark to account for block size. (#4645)
  * Simplify chunk flush rate %% query. (#4711)
  * Refactor and simplify stats package. (#4712)
  * ensures components with required SRV lookups use the correct port  (#4737)
  * Docs: Fix a typo (#4726)
  * Fixes Promtail User-Agent. (#4716)
  * Docs: small v2.4.1 release notes edits (#4718)
  * Add SASL&mTLS authentication support for Kafka in Promtail (#4663)
  * Only execute benchmarks on main. (#4710)
  * Run benchmarks in cron jobs. (#4636)
  * update everything for 2.4.1 (#4701)
  * fix flaky retention tests (#4697)
  * Project: Loki 2.4.1 release notes (#4688)
  * Adds replication_factor doc to common config (#4683)
  * overrides checks for nil tenant limits on AllByUserID (#4687)
  * Loki: check new Read target when initializing boltdb-shipper store (#4681)
  * Docs: revise v2.4 release notes (#4675)
  * update references to new 2.4.0 image (#4672)
  * 2.4 release notes, changelog, upgrade guide (#4658)
  * Update local and docker config for simple scalable deployment (#4660)
  * Docs: Document the common ring section (#4664)
  * Document duplicated protos warning occurence. (#4650)
  * Fix dskit/ring metric with 'cortex_' prefix (#4656)
  * Add a test to verify goroutine leak in compression pools. (#4653)
  * no longer publish `latest` tag on every push to main (#4651)
  * Instrument s3 client DeleteObject requests. (#4649)
  * Fix local kind deployments (#101)
  * Add gh pages (#98)
  * Fix upstream calls to Loki using server-side TLS when provided (#97)
  * Fix olm-based deployments on openshift (#96)
  * Move image tag v0.0.1
  * Add OpenShift Auth native support (#94)
  * Add support for openshift-logging tenant mode (#93)
  * Disable multi-arch builds
  * Create codeql-analysis.yml
  * Add support for dependabot our GH actions (#92)
  * Make Dockerfile compatible for multi-platform builds (#91)
  * Add multiple platforms (#89)
  * Fix target registry for docker-push-action (#88)
  * Fix latest tags for push to quay action (#87)
  * Move to docker-push-action@v2 (#86)
  * Fix wrong field in push to quay action (#85)
  * Use docker/build-push-action@v1 (#84)
  * Publish images to quay.io (#83)
  * Fix go mod sum (#82)
  * Add lokistack-gateway configuration (#77)
  * Remove vendor dir (#81)
  * Add template tests for loki config and runtime config (#80)
  * fix minio deployment (#79)
  * fix send coverage workflow (#78)
  * use URI Scheme HTTPS when tls flag is provided (#75)
  * Add lokistack-gateway deployment (#65)
  * Add profiler support (#74)
  * Bump operator-sdk v1.11.0 and ctrl-runtime 0.9.2 (#73)
  * fix manifests and mutate function (#72)
  * fix issues in example secret + add LOKI_BUCKET_NAME as configurable environment variable (#67)
  * fix scorecard (#66)
  * Fix broker to read a CR and generate manifests (#64)
  * removed manual apply and delete of servicemonitor resource (#62)
  * Log 1403: OCP Certificate Signing (#59)
  * Fix minor glitches and tidy modules (#61)
  * added service monitor for ocp prometheus to scrape metrics (#58)
  * Fix query path configuration (#60)
  * Separate openshift from native k8s production overlays (#55)
  * Creating telemetry metrics for loki operator based on complete build spec (#32)
  * Set lokistack condition failed/pending/ready based on pod status map (#53)
  * Add support for a per component pod status map (#50)
  * add CONTRIBUTING.md (#54)
  * Set query frontend replicas based on selected stack size (#52)
  * Provide CSV markers to display CRD fields properly in OpenShift Console (#49)
  * LOG-1289: set pvc quotas per size (#51)
  * [API-CHANGE] Remove field MaxStreamsPerTenant in favor of using only MaxGlobalStreamsPerTenant (#48)
  * Log 1318: Adding scorecard ci test (#46)
  * Add support for runtime config (#45)
  * Allowing controller to access secrets (#44)
  * Add owner watches for LokiStack owned resources (#42)
  * Provide sane defaults for limits per stack size and loki config (#43)
  * Use pointers for optional API fields (#41)
  * Add config map hash annotation for restarting components (#35)
  * remove parallel testing of internal/management/state/state_test.go (#40)
  * Streamline API terms based on enhancement proposal (#37)
  * LOG-1247: add node selectors support (#39)
  * LOG-1247: add support for tolerations (#38)
  * Add missing manifests tests (#36)
  * Add support for compactor (#30)
  * Add reconciliation for the s3 object storage secret (#33)
  * implement t-shirt sizes (#28)
  * Provide handler for LokiStack create and update events (#27)
  * add some tests to verify services will match pods (#29)
  * Fix default CSV sample (#31)
  * Use RELATED_IMAGE_LOKI for operand img pinning on production builds (#26)
  * center image on readme (#25)
  * Split default target into development and production overlays (#24)
  * Remove legacy manifests generation (#23)
  * Add the scaffolding for tshirt sizing (#21)
  * update readme with some instructions for development (#22)
  * Ensure bundle dependencies are overwritable bei env (#20)
  * Add support to install the operator via OLM in OCP clusters (#17)
  * fix make bundle (#18)
  * Add API for the Loki stack (#15)
  * LOG-1251/convert to statefulsets (#16)
  * Add operator-sdk to bingo targets (#14)
  * add bingo (#12)
  * fix missing error return (#11)
  * make lint a non-requirement for specific make targets (#10)
  * CI: add build targets for broker and operator (#9)
  * LOG-1241: create cli for generating manifests (#8)
  * better ci and fix make (#7)
  * rename github workflow to make more sense (#6)
  * add TestCreateLokiStack_WhenGetReturnsNotFound_DoesNotError (#5)
  * CI: split coverage and lint and try to fix coverage (#4)
  * Create LICENSE.txt
  * gofmt internal/handlers/lokistack_create_test.go
  * add README.md
  * fix golangci-lint timeout flag
  * increase golangci-lint timeout to 5m
  * add golangci-lint, github actions
  * add some tests
  * move things out of the controller and into a handler
  * set ownerRefs
  * maintenance
  * rename things
  * add hack/addons.yaml for promtail and logcli
  * cleanup
  * create querier, and querier frontend
  * fix memberlist resolution
  * fix rbac generation, etc
  * working with struct definitions
  * wip
  * kustomize/v1/base/{ => config}/loki-config.yaml
  * working stack with promtail for testing
  * kustomize
  * WIP
  * init
  * init
- Use BuildRequires: golang(API) = 1.17 instead of >=,
  because with go1.18 it stop mmediately and rise up an error:
  "panic: Something in this program imports go4.org/unsafe/assume-no-moving-gc to declare that it
  assumes a non-moving garbage collector, but your version of go4.org/unsafe/assume-no-moving-gc
  hasn't been updated to assert that it's safe against the go1.18 runtime. If you want to risk it,
  run with environment variable ASSUME_NO_MOVING_GC_UNSAFE_RISK_IT_WITH=go1.18 set.
  Notably, if go1.18 adds a moving garbage collector, this program is unsafe to use."
* Thu Jan 27 2022 ecsos@opensuse.org
- Update to version 2.4.2+git.1642005974.525040a32:
  * fix merge conflict (#5120)
  * Docs: Fix documentation with correct default values and add missing options (#4792) (#5115)
  * Backport 5077: improve default config values (#5077) (#5104)
  * Loki: Implement custom /config handler (#4785) (#5078)
  * temporary fix for the ruler joining the ingester ring (#4968) (#5037)
  * Backport to 2.4: always apply replication factor common config (#4875) (#4989)
  * Docs: fix broken links (#4770) (#4778)
  * Adding upgrade guide for recording rules (#4751) (#4763)
  * Docs: inject newlines into knob descriptions to avoid horizontal scroll bar (#4733) (#4758)
  * Docs: small v2.4.1 release notes edits (#4718) (#4719)
  * update everything for 2.4.1 (#4701) (#4702)
* Mon Dec 13 2021 ecsos <ecsos@opensuse.org>
- Change user in promtail.service from loki to root.
  Without run as root promtail can not tail logfiles.
* Mon Dec 13 2021 ecsos@opensuse.org
- Update to version 2.4.1+git.1636374074.f61a4d261:
  * fix flaky retention tests (#4697) (#4698)
  * Project: Loki 2.4.1 release notes (#4688) (#4692)
  * Adds replication_factor doc to common config (#4683) (#4691)
  * overrides checks for nil tenant limits on AllByUserID (#4687) (#4690)
  * Loki: check new Read target when initializing boltdb-shipper store (#4681) (#4689)
  * remove my text to test PR push (#4678)
  * testing docs publish
  * change branch publish pr runs on
  * Docs: revise v2.4 release notes (#4675) (#4676)
  * update references to new 2.4.0 image (#4672) (#4673)
* Sun Dec 12 2021 Robert Munteanu <rombert@apache.org>
- Move the logcli tool in a separate package, to allow users to install it
  without pulling in the full loki package
* Wed Oct  6 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_promtail.service.patch
  Modified:
  * loki.service
  * promtail.service
* Fri Jun 25 2021 Stefano Torresi <stefano.torresi@suse.com>
- Fix config fillup
* Fri May 28 2021 Stefano Torresi <stefano.torresi@suse.com>
- Update to upstream version 2.2.1
* Tue May 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Split Loki server and Promtail client into separate packages
* Tue Dec  8 2020 Bogdano Arendartchuk <BArendartchuk@suse.com>
- .service: Fix CONFIG_FILE to expand mid-word
* Mon Nov  9 2020 Stefano Torresi <stefano.torresi@suse.com>
- Update packaging
  * avoid systemd and shadow hard requirements
  * use systemd-sysusers to configure the user in a dedicated 'system-user-loki' subpackage
- Update to upstream version v2.0.0
* Wed Sep  2 2020 Stefano Torresi <stefano.torresi@suse.com>
- Install binaries in /usr/bin instead of /usr/sbin since they're supposed to be ran by an unprivileged user.
* Thu May 28 2020 dmaiocchi@suse.com
- Update to version 1.5.0:
  * Prep 1.5.0 release (#2098)
  * updates loki config examples (#2097)
  * Adds backtick for the quoted string token lexer. (#2095)
  * Fixes unit in stats request log. (#2093)
  * allow no encoding/compression on chunks (#2088)
  * Accept suffixes to pod name in instance labels (#2080)
  * removes yolostring (#2078)
  * fluentd plugin: support placeholders in tenant field (#2074)
  * Fixes a panic in dry-run when using external labels. (#2075)
  * Allows to pass inlined pipeline stages to the docker driver. (#2076)
  * Loki: Allow configuring query_store_max_look_back_period when running a filesystem store and boltdb-shipper (#2073)
  * expand the match_all to also optionally allow counting bytes per stream (#2066)
  * some metrics for measuring performance and failures in boltdb shipper (#2034)
  * output a debug log if the requested path in the scrape config doesn't match any files (#2069)
  * Targets not required in promtail config (#2026)
  * Update loki to cortex master (#2030)
  * Reverse entry iterator pool (#2064)
  * Improve protobuf serialization (#2031)
  * Recover from panic in http and grpc handlers. (#2059)
  * Docker driver: Allow to provision external pipeline files to plugin (#2054)
  * Fix a bug in range vector skipping data. (#2058)
  * Docs: update Loki Helm Chart document to support Helm 3 (#2038)
  * Fix promtail client default values (#2049)
  * Fix spelling of per second (#2055)
  * Update api.md (#2056)
  * Chore: Correct typo "per seconds" (#2050)
  * Fix bug in logql parsing that leads to crash. (#2046)
  * fixes the cpu usage graphs (#2044)
  * Add extraOutputs variable to support multiple outputs for fluent-bit (#2040)
  * Swapped to container restarts over terminated reasons (#2043)
  * Remove generated comment at top of .drone/drone.yaml (#2042)
  * Dashboard: Loki Operational improvements (#2041)
  * Support Post request in the frontend queryrange handler. (#2023)
  * fluent-plugin-loki: Restructuring and CI (#2006)
  * Revert "Update go from 1.13 to 1.14. (#2013)" (#2028)
  * Update go from 1.13 to 1.14. (#2013)
  * Adds :delegated flags to speed up build experience on MacOS. (#2009)
  * logcli: Query needs to be stored into url.RawQuery, and not url.Path (#2027)
  * more linter fixes (#2024)
  * I <3 you Linter (#2022)
  * Docs: Added labels content (#1999)
  * Loki: refactor validation and improve error messages (#2021)
  * Spelling (#2014)
  * Change image tag from 1.4.1 to 1.4.0 in Helm chart (#2015)
  * Update lz4 library to latest to ensure deterministic output. (#2010)
  * make `loki_ingester_memory_streams` Gauge per tenant. (#2019)
  * Loki: Improve logging and add metrics to streams dropped by stream limit (#2012)
  * Fix a bad rebase between #1970 and #1965. (#2011)
  * Adds config to disable HTTP and GRPC server in Promtail. (#2004)
  * Allow to aggregate binary operations. (#1970)
  * table client for boltdb shipper to enforce retention (#2001)
  * Improve URL building in the logcli to strip trailing /. (#2000)
  * Ensure trace propagation in our logs. (#1977)
  * Loki: Adds an `interval` paramater to query_range queries allowing a sampling of events to be returned based on the provided interval (#1965)
  * make boltdb shipper singleton and some other minor refactoring (#1995)
  * Update cortex to latest. (#1982)
  * Add a missing method to facade which is called by the metrics storage client in cortex (#1987)
  * added extraCommandlineArgs in values file (#1981)
  * Log error message for invalid checksum (#1713)
  * Log slow query from the frontend by default in ksonnet. (#1980)
  * incorporate some better defaults into table-manager configs (#1976)
  * Update cortex vendoring to latest master (#1975)
  * [Loki]: Cleanup dockerfile (#1949)
  * Convert Loki modules to services (#1804)
  * fix available stores for chunk and index in documentation for period config (#1974)
  * Improve the local config to work locally and inside docker. (#1963)
  * helm chart: add missing line feed (#1967)
  * Docs: Update docker.md (#1966)
  * chunk bounds metric now records 8h range in 1h increments (#1964)
  * flush boltdb to object store (#1837)
  * chunk lifespan histogram (#1958)
  * Workaround for broken etcd gomod import (#1961)
  * Go mod: explicit golang.org/x/net replace (#1953)
  * Move build from source instructions to root readme. (#1951)
  * update cortex to latest master (#1956)
  * Loki Update the cut block size counter when creating a memchunk from byte slice (#1946)
  * Fixes case handling in regex simplification. (#1950)
  * Log docker driver config map. (#1903)
  * version pin the docker image in docker-compose (#1945)
  * Reverting helm changes which were included in Cortex 1.0 vendor upgrade because it resulted in us pushing an unstable helm.
  * delete tag script filters by prefix instead of substring (#1942)
  * Support stdin target via flag instead of automatic detection. (#1935)
  * adds config validation, similar to cortex (#1939)
  * bumps helm to keepalive-master after cortex vendoring (#1937)
  * Update Cortex to latest master (#1869)
  * Add no-file and keep-file log option for docker driver. (#1906)
  * logcli: org-id/tls-skip-verify set via env var (#1922)
  * Clarified that the api push path needs to be specified. (#1925)
  * And the loki mixin
  * Put loki-mixin and promtail-mixin dashboards in a folder.
  * feat: tms readiness check bypass implementation
  * this Dockerfile is a remnant from a long time ago, not needed. (#1918)
  * only fetches one chunk per series in /series (#1914)
  * Add cap_net_bind_service linux capabilities to Loki. (#1916)
  * Fix fluent-bit metrics (#1915)
  * s/dashboards/grafanaDashboards.
  * fluentd loki plugin README: add note about labels (#1909)
  * push images for `k` branches
  * updating typo for end time parameter (#1905)
  * updating helm and ksonnet to 1.4.1 updating Fluent Bit to correct image
  * JSON encoding: avoid base64 encoding of []byte inside other slices (#1890)
  * [helm loki/promtail] make UpdateStrategy configurable (#1898)
  * Addition of a `/suspend` endpoint to Loki Canary (#1891)
  * Removes file size check for pipe, not provided by linux. (#1893)
  * Fixes possible panic in json pipeline stage. (#1894)
  * Fix flaky promtail test (#1865)
  * docs: cleaning up the comments for the cache_config, default_validity option (#1888)
  * Adding a config change in release 1.4 upgrade doc Updating readme with links to new docs
  * Sign helm package with GPG. (#1864)
  * Add precision about the range notation for LogQL. (#1881)
  * updating helm and ksonnet for 1.4.0 release
  * clear out some changelog entries to fix a merge conflict from the release branch
  * docs: update promtail docs for backoff (#1879)
  * Support series API in logcli (#1861)
  * support `match[]` encoding (#1875)
  * Keep plugin install command example in one line (#1870)
  * Add extraMount, extraVolumeMount to promtail helm chart for systemd-journal (#1871)
  * documents frontend worker (#1873)
  * clarify logcli commands and output (#1712)
  * Logcli remote storage. (#1814)
  * Sharding optimizations I: AST mapping (#1846)
  * docs: tweak the doc section of the readme a little (#1856)
  * Support configurable maximum of the limits parameter (#1798)
  * bump gem version (#1853)
  * throw exceptions on HTTPTooManyRequests and HTTPServerError so FluentD will retry (#1845)
  * logcli client: use OrgID in LiveTail (#1850)
  * remove a few places we recommend the schema version and consolidate in the configuration doc
  * Pin helm version in circle-ci helm testing workflow. (#1849)
  * Proposal: Promtail Push API (#1627)
  * promtail retry 429 rate limit errors, clarifying risks in the docs of configuring multiple client sections in promtail, also increased the backoff and retry settings in promtail.
  * Docs: Update configuration docs for redis (#1843)
  * Log error message when source does not exist in extracted values (#1815)
  * Helm/loki-stack: refresh default grafana.image.tag to 6.7.0 (#1825)
  * Move default port for Loki to 3100 everywhere. (#1838)
  * Change local storage directory to /loki/ and fix permissions (#1833) (#1834)
  * Use 8080 for Loki http port  binding in tanka. (#1823)
  * Adds a counter for total flushed chunks per reason. (#1819)
  * Prevent prometheus to scrap both services (#1817)
  * loki can not be started with loki-local-config.yaml (#1816)
  * Optimize empty filter queries. (#1810)
  * Improve fluentbit logfmt. (#1791)
  * Test stats memchunk (#1809)
  * Error handling: Show data stream at "debug" level, not "warn" (#1811)
  * loki: update Cortex to master (#1799)
  * Non-root user docker image for Loki. (#1706)
* Fri Apr 17 2020 Dario Maiocchi <dmaiocchi@suse.com>
- Update to version 1.4.1:
  * updating changelog and version numbers in docs for 1.4.1 release
  * JSON encoding: avoid base64 encoding of []byte inside other slices (#1890)
  * Removes file size check for pipe, not provided by linux. (#1893)
  * fixing release date
  * Updating some of the references to v1.3.0 Adding an entry in the changelog to reference image name changes
  * docs: update promtail docs for backoff (#1879)
  * bump gem version (#1853)
  * throw exceptions on HTTPTooManyRequests and HTTPServerError so FluentD will retry (#1845)
  * promtail retry 429 rate limit errors, clarifying risks in the docs of configuring multiple client sections in promtail, also increased the backoff and retry settings in promtail.
  * Adding upgrade doc and updating changelog for release
* Mon Jul  1 2019 JMC <jcavalheiro@suse.com>
- Add compat macro for _fillupdir to allow builds in SLE12
* Mon Jul  1 2019 João Cavalheiro <jcavalheiro@suse.com>
- Initial commit (v0.1.0)
